@@ -12,40 +12,48 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "stdinc.h"
 
 #include "ClientManager.h"
 
-#include "ShareManager.h"
-#include "SearchManager.h"
+#include "AdcHub.h"
 #include "ConnectionManager.h"
+#include "ConnectivityManager.h"
 #include "CryptoManager.h"
 #include "FavoriteManager.h"
+#include "FinishedManager.h"
+#include "File.h"
+#include "NmdcHub.h"
+#include "QueueManager.h"
+#include "SearchManager.h"
+#include "SearchResult.h"
+#include "ShareManager.h"
 #include "SimpleXML.h"
 #include "UserCommand.h"
-#include "SearchResult.h"
-
-#include "AdcHub.h"
-#include "NmdcHub.h"
 #ifdef WITH_DHT
 #include "dht/DHT.h"
 #endif
-#include "FinishedManager.h"//sdc
-#include "QueueManager.h"
 
 namespace dcpp {
 
+ClientManager::ClientManager() {
+    TimerManager::getInstance()->addListener(this);
+}
+
+ClientManager::~ClientManager() {
+    TimerManager::getInstance()->removeListener(this);
+}
+
 Client* ClientManager::getClient(const string& aHubURL) {
     Client* c;
-    if(strncmp("adc://", aHubURL.c_str(), 6) == 0) {
+    if(Util::strnicmp("adc://", aHubURL.c_str(), 6) == 0) {
         c = new AdcHub(aHubURL, false);
-    } else if(strncmp("adcs://", aHubURL.c_str(), 7) == 0) {
+    } else if(Util::strnicmp("adcs://", aHubURL.c_str(), 7) == 0) {
         c = new AdcHub(aHubURL, true);
-    } else if(strncmp("nmdcs://", aHubURL.c_str(), 8) == 0) {
+    } else if(Util::strnicmp("nmdcs://", aHubURL.c_str(), 8) == 0) {
         c = new NmdcHub(aHubURL, true);
     } else {
         c = new NmdcHub(aHubURL, false);
@@ -86,6 +94,16 @@ StringList ClientManager::getHubNames(const CID& cid, const string& hintUrl) {
     return getHubNames(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
 }
 
+StringList ClientManager::getHubUrls(const CID& cid) const {
+    Lock l(cs);
+    StringList lst;
+    OnlinePairC op = onlineUsers.equal_range(cid);
+    for(auto i = op.first; i != op.second; ++i) {
+        lst.push_back(i->second->getClient().getHubUrl());
+    }
+    return lst;
+}
+
 StringList ClientManager::getNicks(const CID& cid, const string& hintUrl) {
     return getNicks(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
 }
@@ -181,8 +199,8 @@ string ClientManager::getConnection(const CID& cid) const {
 int64_t ClientManager::getAvailable() const {
     Lock l(cs);
     int64_t bytes = 0;
-    for(auto i = onlineUsers.begin(); i != onlineUsers.end(); ++i) {
-        bytes += i->second->getIdentity().getBytesShared();
+    for(auto& i: onlineUsers) {
+        bytes += i.second->getIdentity().getBytesShared();
     }
 
     return bytes;
@@ -200,8 +218,8 @@ uint8_t ClientManager::getSlots(const CID& cid) const {
 bool ClientManager::isConnected(const string& aUrl) const {
     Lock l(cs);
 
-    for(auto i = clients.begin(); i != clients.end(); ++i) {
-        if((*i)->getHubUrl() == aUrl) {
+    for(auto i: clients) {
+        if(i->getHubUrl() == aUrl) {
             return true;
         }
     }
@@ -212,18 +230,12 @@ string ClientManager::findHub(const string& ipPort) const {
     Lock l(cs);
 
     string ip;
-    uint16_t port = 411;
-    string::size_type i = ipPort.find(':');
-    if(i == string::npos) {
-        ip = ipPort;
-    } else {
-        ip = ipPort.substr(0, i);
-        port = static_cast<uint16_t>(Util::toInt(ipPort.substr(i+1)));
-    }
+    string port = "411";
+    Util::parseIpPort(ipPort, ip, port);
 
     string url;
-    for(auto i = clients.begin(); i != clients.end(); ++i) {
-        const Client* c = *i;
+    for(auto i: clients) {
+        const Client* c = i;
         if(c->getIp() == ip) {
             // If exact match is found, return it
             if(c->getPort() == port)
@@ -240,9 +252,9 @@ string ClientManager::findHub(const string& ipPort) const {
 string ClientManager::findHubEncoding(const string& aUrl) const {
     Lock l(cs);
 
-    for(auto i = clients.begin(); i != clients.end(); ++i) {
-        if((*i)->getHubUrl() == aUrl) {
-            return (*i)->getEncoding();
+    for(auto i: clients) {
+        if(i->getHubUrl() == aUrl) {
+            return i->getEncoding();
         }
     }
     return Text::hubDefaultCharset;
@@ -253,8 +265,8 @@ UserPtr ClientManager::findLegacyUser(const string& aNick) const noexcept {
         return UserPtr();
     Lock l(cs);
 
-    for(auto i = onlineUsers.begin(); i != onlineUsers.end(); ++i) {
-        const OnlineUser* ou = i->second;
+    for(auto& i: onlineUsers) {
+        const OnlineUser* ou = i.second;
         if(ou->getUser()->isSet(User::NMDC) && Util::stricmp(ou->getIdentity().getNick(), aNick) == 0)
             return ou->getUser();
     }
@@ -273,7 +285,7 @@ UserPtr ClientManager::getUser(const string& aNick, const string& aHubUrl) noexc
 
     UserPtr p(new User(cid));
     p->setFlag(User::NMDC);
-    users.insert(make_pair(cid, p));
+    users.emplace(cid, p);
 
     return p;
 }
@@ -285,15 +297,19 @@ UserPtr ClientManager::getUser(const CID& cid) noexcept {
         return ui->second;
     }
 
+    if(cid == getMe()->getCID()) {
+        return getMe();
+    }
+
     UserPtr p(new User(cid));
-    users.insert(make_pair(cid, p));
+    users.emplace(cid, p);
     return p;
 }
 
 UserPtr ClientManager::findUser(const CID& cid) const noexcept {
     Lock l(cs);
     auto ui = users.find(cid);
-    return ui == users.end() ? 0 : ui->second;
+    return ui == users.end() ? nullptr : ui->second;
 }
 
 bool ClientManager::isOp(const UserPtr& user, const string& aHubUrl) const {
@@ -320,7 +336,7 @@ CID ClientManager::makeCid(const string& aNick, const string& aHubUrl) const noe
 void ClientManager::putOnline(OnlineUser* ou) noexcept {
     {
         Lock l(cs);
-        onlineUsers.insert(make_pair(ou->getUser()->getCID(), ou));
+        onlineUsers.emplace(ou->getUser()->getCID(), ou);
     }
 
     if(!ou->getUser()->isOnline()) {
@@ -330,33 +346,35 @@ void ClientManager::putOnline(OnlineUser* ou) noexcept {
 }
 
 void ClientManager::putOffline(OnlineUser* ou, bool disconnect) noexcept {
-    bool lastUser = false;
+    OnlineIter::difference_type diff = 0;
     {
         Lock l(cs);
-        OnlinePair op = onlineUsers.equal_range(ou->getUser()->getCID());
+        auto op = onlineUsers.equal_range(ou->getUser()->getCID());
         dcassert(op.first != op.second);
-        for(OnlineIter i = op.first; i != op.second; ++i) {
-            OnlineUser* ou2 = i->second;
+        for(auto i = op.first; i != op.second; ++i) {
+            auto ou2 = i->second;
             if(ou == ou2) {
-                lastUser = (distance(op.first, op.second) == 1);
+                diff = distance(op.first, op.second);
                 onlineUsers.erase(i);
                 break;
             }
         }
     }
 
-    if(lastUser) {
+    if(diff == 1) { //last user
         UserPtr& u = ou->getUser();
         u->unsetFlag(User::ONLINE);
         if(disconnect)
             ConnectionManager::getInstance()->disconnect(u);
         fire(ClientManagerListener::UserDisconnected(), u);
+    } else if(diff > 1) {
+        fire(ClientManagerListener::UserUpdated(), *ou);
     }
 }
 
 OnlineUser* ClientManager::findOnlineUserHint(const CID& cid, const string& hintUrl, OnlinePairC& p) const {
-        p = onlineUsers.equal_range(cid);
-        if(p.first == p.second) // no user found with the given CID.
+    p = onlineUsers.equal_range(cid);
+    if(p.first == p.second) // no user found with the given CID.
         return 0;
 
     if(!hintUrl.empty()) {
@@ -368,7 +386,7 @@ OnlineUser* ClientManager::findOnlineUserHint(const CID& cid, const string& hint
         }
     }
 
-        return 0;
+    return 0;
 }
 
 OnlineUser* ClientManager::findOnlineUser(const HintedUser& user, bool priv) {
@@ -414,7 +432,7 @@ void ClientManager::privateMessage(const HintedUser& user, const string& msg, bo
     }
 }
 
-void ClientManager::userCommand(const HintedUser& user, const UserCommand& uc, StringMap& params, bool compatibility) {
+void ClientManager::userCommand(const HintedUser& user, const UserCommand& uc, ParamMap& params, bool compatibility) {
     Lock l(cs);
     /** @todo we allow wrong hints for now ("false" param of findOnlineUser) because users
      * extracted from search results don't always have a correct hint; see
@@ -423,10 +441,10 @@ void ClientManager::userCommand(const HintedUser& user, const UserCommand& uc, S
      * change this call to findOnlineUserHint. */
     OnlineUser* ou = findOnlineUser(user.user->getCID(), user.hint.empty() ? uc.getHub() : user.hint, false);
     if(!ou
-#ifdef WITH_DHT
-       || ou->getClientBase().type == ClientBase::DHT
-#endif
-                                                             )
+        #ifdef WITH_DHT
+            || ou->getClientBase().type == ClientBase::DHT
+        #endif
+            )
         return;
 
     ou->getIdentity().getParams(params, "user", compatibility);
@@ -443,17 +461,17 @@ void ClientManager::send(AdcCommand& cmd, const CID& cid) {
         OnlineUser& u = *i->second;
         if(cmd.getType() == AdcCommand::TYPE_UDP && !u.getIdentity().isUdpActive()) {
             if(u.getUser()->isNMDC()
-#ifdef WITH_DHT
-                || u.getClientBase().getType() == Client::DHT
-#endif
-                                                              )
+        #ifdef WITH_DHT
+                    || u.getClientBase().getType() == Client::DHT
+        #endif
+                    )
                 return;
             cmd.setType(AdcCommand::TYPE_DIRECT);
             cmd.setTo(u.getIdentity().getSID());
             u.getClient().send(cmd);
         } else {
             try {
-                udp.writeTo(u.getIdentity().getIp(), static_cast<uint16_t>(Util::toInt(u.getIdentity().getUdpPort())), cmd.toString(getMe()->getCID()));
+                udp.writeTo(u.getIdentity().getIp(), u.getIdentity().getUdpPort(), cmd.toString(getMe()->getCID()));
             } catch(const SocketException&) {
                 dcdebug("Socket exception sending ADC UDP command\n");
             }
@@ -463,15 +481,15 @@ void ClientManager::send(AdcCommand& cmd, const CID& cid) {
 
 void ClientManager::infoUpdated() {
     Lock l(cs);
-    for(auto i = clients.begin(); i != clients.end(); ++i) {
-        if((*i)->isConnected()) {
-            (*i)->info(false);
+    for(auto i: clients) {
+        if(i->isConnected()) {
+            i->info(false);
         }
     }
 }
 
 void ClientManager::on(NmdcSearch, Client* aClient, const string& aSeeker, int aSearchType, int64_t aSize,
-                                    int aFileType, const string& aString) noexcept
+                       int aFileType, const string& aString) noexcept
 {
     Speaker<ClientManagerListener>::fire(ClientManagerListener::IncomingSearch(), aString);
 
@@ -485,17 +503,16 @@ void ClientManager::on(NmdcSearch, Client* aClient, const string& aSeeker, int a
 
     SearchResultList l;
     ShareManager::getInstance()->search(l, aString, aSearchType, aSize, aFileType, aClient, isPassive ? 5 : 10);
-//      dcdebug("Found %d items (%s)\n", l.size(), aString.c_str());
+    //      dcdebug("Found %d items (%s)\n", l.size(), aString.c_str());
     if(!l.empty()) {
         if(isPassive) {
             string name = aSeeker.substr(4);
             // Good, we have a passive seeker, those are easier...
             string str;
-            for(auto i = l.begin(); i != l.end(); ++i) {
-                const SearchResultPtr& sr = *i;
+            for(const auto& sr: l) {
                 str += sr->toSR(*aClient);
                 str[str.length()-1] = 5;
-                str += name;
+                str += Text::fromUtf8(name, aClient->getEncoding());
                 str += '|';
             }
 
@@ -504,16 +521,12 @@ void ClientManager::on(NmdcSearch, Client* aClient, const string& aSeeker, int a
 
         } else {
             try {
-                string ip, file, proto, query, fragment;
-                uint16_t port = 0;
-                Util::decodeUrl(aSeeker, proto, ip, port, file, query, fragment);
-                ip = Socket::resolve(ip);
-                if(static_cast<NmdcHub*>(aClient)->isProtectedIP(ip))
-                    return;
-                if(port == 0)
-                    port = 412;
-                for(auto i = l.begin(); i != l.end(); ++i) {
-                    const SearchResultPtr& sr = *i;
+                string ip;
+                string port;
+                Util::parseIpPort(aSeeker, ip, port);
+                if(port.empty())
+                    port = "412";
+                for(const SearchResultPtr& sr : l) {
                     udp.writeTo(ip, port, sr->toSR(*aClient));
                 }
             } catch(const SocketException& /* e */) {
@@ -530,14 +543,17 @@ void ClientManager::on(NmdcSearch, Client* aClient, const string& aSeeker, int a
             }
         }
 
-        string ip, file, proto, query, fragment;
-        uint16_t port = 0;
-        Util::decodeUrl(aSeeker, proto, ip, port, file, query, fragment);
+        string ip;
+        string port;
+        Util::parseIpPort(aSeeker, ip, port);
+        if (port.empty()) {
+            return;
+        }
 
         try {
             AdcCommand cmd = SearchManager::getInstance()->toPSR(true, aClient->getMyNick(), aClient->getIpPort(), aTTH.toBase32(), partialInfo);
             Socket s;
-            s.writeTo(Socket::resolve(ip), port, cmd.toString(ClientManager::getInstance()->getMe()->getCID()));
+            s.writeTo(ip, port, cmd.toString(ClientManager::getInstance()->getMe()->getCID()));
         } catch(...) {
             dcdebug("Partial search caught error\n");
         }
@@ -557,6 +573,27 @@ void ClientManager::on(AdcSearch, Client* c, const AdcCommand& adc, const CID& f
 
     }
     SearchManager::getInstance()->respond(adc, from, isUdpActive, c->getIpPort());
+
+    Speaker<ClientManagerListener>::fire(ClientManagerListener::IncomingSearch(), [&adc]() -> string
+    {
+                                             auto toCode = [](char a, char b) -> uint16_t {
+                                                 return (uint16_t)a | ((uint16_t)b)<<8;
+                                             };
+
+                                             string result;
+                                             const StringList &params = adc.getParameters();
+
+                                             for(const string &param: params) {
+                                                 if(param.length() <= 2)
+                                                 continue;
+                                                 uint16_t cmd = toCode(param[0], param[1]);
+                                                 if (toCode('T', 'R') == cmd)
+                                                 result = "TTH:" + param.substr(2);
+                                                 else if (toCode('A', 'N') == cmd)
+                                                 result += param.substr(2) + ' ';
+                                             }
+                                             return result;
+                                         }());
 }
 
 
@@ -566,9 +603,9 @@ void ClientManager::search(int aSizeMode, int64_t aSize, int aFileType, const st
         dht::DHT::getInstance()->findFile(aString);
 #endif
     Lock l(cs);
-    for(auto i = clients.begin(); i != clients.end(); ++i) {
-        if((*i)->isConnected()) {
-            (*i)->search(aSizeMode, aSize, aFileType, aString, aToken, StringList() /*ExtList*/, aOwner);
+    for(auto i: clients) {
+        if(i->isConnected()) {
+            i->search(aSizeMode, aSize, aFileType, aString, aToken, StringList() /*ExtList*/, aOwner);
         }
     }
 }
@@ -580,10 +617,8 @@ uint64_t ClientManager::search(StringList& who, int aSizeMode, int64_t aSize, in
 #endif
     Lock l(cs);
     uint64_t estimateSearchSpan = 0;
-    for(auto it = who.begin(); it != who.end(); ++it) {
-        string& client = *it;
-        for(auto j = clients.begin(); j != clients.end(); ++j) {
-            Client* c = *j;
+    for(auto& client: who) {
+        for(auto c: clients) {
             if(c->isConnected() && c->getHubUrl() == client) {
                 uint64_t ret = c->search(aSizeMode, aSize, aFileType, aString, aToken, aExtList, aOwner);
                 estimateSearchSpan = max(estimateSearchSpan, ret);
@@ -606,8 +641,8 @@ void ClientManager::on(TimerManagerListener::Minute, uint64_t /* aTick */) noexc
         }
     }
 
-    for(auto j = clients.begin(); j != clients.end(); ++j) {
-        (*j)->info(false);
+    for(auto client: clients) {
+        client->info(false);
     }
 }
 
@@ -616,14 +651,14 @@ UserPtr& ClientManager::getMe() {
         Lock l(cs);
         if(!me) {
             me = new User(getMyCID());
-            users.insert(make_pair(me->getCID(), me));
+            users.emplace(me->getCID(), me);
         }
     }
     return me;
 }
 
 const CID& ClientManager::getMyPID() {
-    if(pid.isZero())
+    if(!pid)
         pid = CID(SETTING(PRIVATE_ID));
     return pid;
 }
@@ -634,16 +669,18 @@ CID ClientManager::getMyCID() {
     return CID(tiger.finalize());
 }
 
-void ClientManager::updateNick(const OnlineUser& user) noexcept {
+void ClientManager::updateUser(const OnlineUser& user) noexcept {
     if(!user.getIdentity().getNick().empty()) {
         Lock l(cs);
         auto i = nicks.find(user.getUser()->getCID());
         if(i == nicks.end()) {
-                nicks[user.getUser()->getCID()] = std::make_pair(user.getIdentity().getNick(), false);
+            nicks[user.getUser()->getCID()] = std::make_pair(user.getIdentity().getNick(), false);
         } else {
-                i->second.first = user.getIdentity().getNick();
+            i->second.first = user.getIdentity().getNick();
         }
     }
+
+    fire(ClientManagerListener::UserUpdated(), user);
 }
 
 void ClientManager::loadUsers() {
@@ -674,11 +711,11 @@ void ClientManager::saveUsers() const {
 
         {
             Lock l(cs);
-            for(auto i = nicks.begin(), iend = nicks.end(); i != iend; ++i) {
-                if(i->second.second) {
+            for(auto& i: nicks) {
+                if(i.second.second) {
                     xml.addTag("User");
-                    xml.addChildAttrib("CID", i->first.toBase32());
-                    xml.addChildAttrib("Nick", i->second.first);
+                    xml.addChildAttrib("CID", i.first.toBase32());
+                    xml.addChildAttrib("Nick", i.second.first);
                 }
             }
         }
@@ -709,14 +746,12 @@ void ClientManager::on(Connected, Client* c) noexcept {
 }
 
 void ClientManager::on(UserUpdated, Client*, const OnlineUser& user) noexcept {
-    updateNick(user);
-    fire(ClientManagerListener::UserUpdated(), user);
+    updateUser(user);
 }
 
-void ClientManager::on(UsersUpdated, Client* c, const OnlineUserList& l) noexcept {
-    for(auto i = l.cbegin(), iend = l.cend(); i != iend; ++i) {
-        updateNick(*(*i));
-        fire(ClientManagerListener::UserUpdated(), *(*i));
+void ClientManager::on(UsersUpdated, Client*, const OnlineUserList& l) noexcept {
+    for(auto& i: l) {
+        updateUser(*i);
     }
 }
 
@@ -750,14 +785,14 @@ int ClientManager::getMode(const string& aHubUrl) const {
     const FavoriteHubEntry* hub = FavoriteManager::getInstance()->getFavoriteHubEntry(aHubUrl);
     if(hub) {
         switch(hub->getMode()) {
-            case 1 :
-                mode = SettingsManager::INCOMING_DIRECT;
-                break;
-            case 2 :
-                mode = SettingsManager::INCOMING_FIREWALL_PASSIVE;
-                break;
-            default:
-                mode = SETTING(INCOMING_CONNECTIONS);
+        case 1 :
+            mode = SettingsManager::INCOMING_DIRECT;
+            break;
+        case 2 :
+            mode = SettingsManager::INCOMING_FIREWALL_PASSIVE;
+            break;
+        default:
+            mode = SETTING(INCOMING_CONNECTIONS);
         }
     } else {
         mode = SETTING(INCOMING_CONNECTIONS);
@@ -768,8 +803,8 @@ int ClientManager::getMode(const string& aHubUrl) const {
 void ClientManager::cancelSearch(void* aOwner) {
     Lock l(cs);
 
-    for(auto i = clients.begin(); i != clients.end(); ++i) {
-        (*i)->cancelSearch(aOwner);
+    for(auto i: clients) {
+        i->cancelSearch(aOwner);
     }
 }
 
@@ -791,6 +826,7 @@ OnlineUserPtr ClientManager::findDHTNode(const CID& cid) const {
 
     return NULL;
 }
+
 #endif
 
 #ifdef LUA_SCRIPT
