@@ -12,15 +12,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
 
-namespace dcpp {
+#include "forward.h"
+#include "typedefs.h"
 
-class ConnectionQueueItem;
+namespace dcpp {
 
 class ConnectionManagerListener {
 public:
