@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2001-2012 Jacek Sieka, arnetheduck on gmail point com
+ * Copyright (C) 2009-2019 EiskaltDC++ developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,26 +13,28 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
 
+#include <list>
+
 #include "TimerManager.h"
 #include "SettingsManager.h"
 #include "forward.h"
 #include "CriticalSection.h"
 #include "Text.h"
 #include "Client.h"
-#include "BufferedSocket.h"
-#include "ClientManager.h"
 
 #ifdef LUA_SCRIPT
 #include "ScriptManager.h"
 #endif
+
 namespace dcpp {
 
+using std::list;
+
 #ifdef LUA_SCRIPT
 struct NmdcHubScriptInstance : public ScriptInstance {
     friend class ClientManager;
@@ -41,9 +44,10 @@ struct NmdcHubScriptInstance : public ScriptInstance {
 
 class ClientManager;
 
-class NmdcHub : public Client, private Flags
 #ifdef LUA_SCRIPT
-,public NmdcHubScriptInstance
+class NmdcHub : public Client, private Flags ,public NmdcHubScriptInstance
+#else
+class NmdcHub : public Client, private Flags
 #endif
 {
 public:
@@ -55,7 +59,7 @@ public:
 
     virtual void hubMessage(const string& aMessage, bool /*thirdPerson*/ = false);
     virtual void privateMessage(const OnlineUser& aUser, const string& aMessage, bool /*thirdPerson*/ = false);
-    virtual void sendUserCmd(const UserCommand& command, const StringMap& params);
+    virtual void sendUserCmd(const UserCommand& command, const ParamMap& params);
     virtual void search(int aSizeType, int64_t aSize, int aFileType, const string& aString, const string& aToken, const StringList& aExtList);
     virtual void password(const string& aPass) { send("$MyPass " + fromUtf8(aPass) + "|"); }
     virtual void info(bool force) { myInfo(force); }
@@ -63,15 +67,16 @@ public:
     virtual size_t getUserCount() const { Lock l(cs); return users.size(); }
     virtual int64_t getAvailable() const;
 
-    virtual string escape(string const& str) const { return validateMessage(str, false); }
+    static string escape(const string& str) { return validateMessage(str, false); }
     static string unescape(const string& str) { return validateMessage(str, true); }
 
+    void emulateCommand(const string& cmd) { onLine(cmd); }
     virtual void send(const AdcCommand&) { dcassert(0); }
 
     static string validateMessage(string tmp, bool reverse);
 
 private:
-friend class ClientManager;
+    friend class ClientManager;
     enum SupportFlags {
         SUPPORTS_USERCOMMAND = 0x01,
         SUPPORTS_NOGETINFO = 0x02,
@@ -80,10 +85,7 @@ friend class ClientManager;
 
     mutable CriticalSection cs;
 
-    typedef unordered_map<string, OnlineUser*, CaseStringHash, CaseStringEq> NickMap;
-    typedef NickMap::iterator NickIter;
-
-    NickMap users;
+    unordered_map<string, OnlineUser*, CaseStringHash, CaseStringEq> users;
 
     int supportFlags;
 
@@ -97,16 +99,10 @@ friend class ClientManager;
     typedef FloodMap::iterator FloodIter;
     FloodMap seekers;
     FloodMap flooders;
-    uint64_t lastProtectedIPsUpdate;
-    StringList protectedIPs;
 
     NmdcHub(const string& aHubURL, bool secure);
     virtual ~NmdcHub();
 
-    // Dummy
-    NmdcHub(const NmdcHub&);
-    NmdcHub& operator=(const NmdcHub&);
-
     void clearUsers();
 
     OnlineUser& getUser(const string& aNick);
@@ -125,7 +121,6 @@ friend class ClientManager;
     void myInfo(bool alwaysSend);
     void supports(const StringList& feat);
     void clearFlooders(uint64_t tick);
-    bool isProtectedIP(const string& ip);
 
     void updateFromTag(Identity& id, const string& tag);
 
@@ -133,7 +128,6 @@ friend class ClientManager;
 
     // TimerManagerListener
     virtual void on(Second, uint64_t aTick) noexcept;
-    virtual void on(Minute, uint64_t aTick) noexcept;
 
     virtual void on(Connected) noexcept;
     virtual void on(Line, const string& l) noexcept;
