@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "stdinc.h"
@@ -48,10 +47,11 @@ const string SettingsManager::settingTags[] =
     "TimeStampsFormat", "CID", "LogFileMainChat", "LogFilePrivateChat",
     "LogFileStatus", "LogFileUpload", "LogFileDownload", "LogFileFinishedDownload",
     "LogFileSystem",
-    "LogFormatSystem", "LogFormatStatus", "TLSPrivateKeyFile",
+    "LogFormatSystem", "LogFormatStatus", "LogFileSpy", "LogFormatSpy", "TLSPrivateKeyFile",
     "TLSCertificateFile", "TLSTrustedCertificatesPath",
     "Language", "SkipListShare", "InternetIp", "BindIfaceName",
     "DHTKey", "DynDNSServer", "MimeHandler",
+    "LogFileCmdDebug", "LogFormatCmdDebug",
     "SENTRY",
     // Ints
     "IncomingConnections", "InPort", "Slots", "AutoFollow",
@@ -83,7 +83,7 @@ const string SettingsManager::settingTags[] =
     "DontDlAlreadyQueued", "MaxCommandLength", "AllowUntrustedHubs",
     "AllowUntrustedClients", "TLSPort", "FastHash",
     "SegmentedDL", "FollowLinks", "SendBloom",
-    "Coral", "SearchFilterShared", "FinishedDLOnlyFull",
+    "SearchFilterShared", "FinishedDLOnlyFull",
     "SearchMerge", "HashBufferSize", "HashBufferPopulate",
     "HashBufferNoReserve", "HashBufferPrivate",
     "UseDHT", "DHTPort",
@@ -96,6 +96,9 @@ const string SettingsManager::settingTags[] =
     "IpFilter", "TextColor", "UseLua", "AllowNatt", "IpTOSValue", "SegmentSize",
     "BindIface", "MinimumSearchInterval", "EnableDynDNS", "AllowUploadOverMultiHubs",
     "UseADLOnlyOnOwnList", "AllowSimUploads", "CheckTargetsPathsOnStart", "NmdcDebug",
+    "ShareSkipZeroByte", "RequireTLS", "LogSpy", "AppUnitBase",
+    "LogCmdDebug",
+    "SENTRY",
     // Int64
     "TotalUpload", "TotalDownload",
     "SENTRY",
@@ -140,12 +143,14 @@ SettingsManager::SettingsManager()
 
     setDefault(DOWNLOAD_DIRECTORY, Util::getPath(Util::PATH_DOWNLOADS));
     setDefault(TEMP_DOWNLOAD_DIRECTORY, Util::getPath(Util::PATH_DOWNLOADS) + "Incomplete" PATH_SEPARATOR_STR);
+    setDefault(BIND_ADDRESS, "0.0.0.0");
     setDefault(SLOTS, 5);
     setDefault(TCP_PORT, 3000);
     setDefault(UDP_PORT, 3000);
     setDefault(TLS_PORT, 3001);
     setDefault(INCOMING_CONNECTIONS, INCOMING_DIRECT);
     setDefault(OUTGOING_CONNECTIONS, OUTGOING_DIRECT);
+    setDefault(AUTO_DETECT_CONNECTION, false);
     setDefault(AUTO_FOLLOW, true);
     setDefault(SHARE_HIDDEN, false);
     setDefault(FILTER_MESSAGES, true);
@@ -158,14 +163,13 @@ SettingsManager::SettingsManager()
     setDefault(LIST_DUPES, true);
     setDefault(BUFFER_SIZE, 64);
     setDefault(HUBLIST_SERVERS,
-               "http://hublist.openhublist.org/hublist.xml.bz2;"
-               "http://dchublist.com/hublist.xml.bz2;"
-               "http://adchublist.com/hublist.xml.bz2;"
-               "http://www.hublist.org/PublicHubList.xml.bz2;"
-               "http://dclist.eu/hublist.xml.bz2;"
-               "http://download.hublist.cz/hublist.xml.bz2;"
-               "http://hublist.awenet.info/PublicHubList.xml.bz2;"
-               "http://www.hublista.hu/hublist.xml.bz2"
+               "https://www.te-home.net/?do=hublist&get=hublist.xml.bz2;"
+               "https://tankafett.biz/?do=hublist&get=hublist.xml.bz2;"
+               "https://dchublist.org/hublist.xml.bz2;"
+               "https://dchublist.biz/hublist.xml.bz2;"
+               "https://dchublist.ru/hublist.xml.bz2;"
+               "https://dcnf.github.io/Hublist/hublist.xml.bz2;"
+               "https://dchublist.org/adchublist.xml.bz2;"
                );
     setDefault(DOWNLOAD_SLOTS, 3);
     setDefault(SKIPLIST_SHARE, "*.~*|*.*~");
@@ -176,6 +180,8 @@ SettingsManager::SettingsManager()
     setDefault(LOG_FINISHED_DOWNLOADS, false);
     setDefault(LOG_PRIVATE_CHAT, false);
     setDefault(LOG_MAIN_CHAT, false);
+    setDefault(LOG_SPY, false);
+    setDefault(LOG_CMD_DEBUG, false);
     setDefault(UPLOAD_SPEED, connectionSpeeds[11]);
     setDefault(MIN_UPLOAD_SPEED, 0);
     setDefault(LOG_FORMAT_POST_DOWNLOAD, "[%Y-%m-%d %H:%M:%S] %[target] downloaded from %[userNI] (%[userCID]), %[fileSI] (%[fileSIchunk]), %[speed], %[time], %[fileTR]");
@@ -185,6 +191,8 @@ SettingsManager::SettingsManager()
     setDefault(LOG_FORMAT_PRIVATE_CHAT,  "[%Y-%m-%d %H:%M:%S] %[message]");
     setDefault(LOG_FORMAT_STATUS,        "[%Y-%m-%d %H:%M:%S] %[message]");
     setDefault(LOG_FORMAT_SYSTEM,        "[%Y-%m-%d %H:%M:%S] %[message]");
+    setDefault(LOG_FORMAT_SPY,        "[%Y-%m-%d %H:%M:%S] %[message] (%[count])");
+    setDefault(LOG_FORMAT_CMD_DEBUG,  "[%Y-%m-%d %H:%M:%S] %[type] %[ip]: %[cmd]");
     setDefault(LOG_FILE_MAIN_CHAT,    "CHAT/%B - %Y/%[hubNI] (%[hubURL]).log");
     setDefault(LOG_FILE_STATUS,       "STATUS/%B - %Y/%[hubNI] (%[hubURL]).log");
     setDefault(LOG_FILE_PRIVATE_CHAT, "PM/%B - %Y/%[userNI] (%[userCID]).log");
@@ -192,8 +200,8 @@ SettingsManager::SettingsManager()
     setDefault(LOG_FILE_DOWNLOAD,     "Downloads.log");
     setDefault(LOG_FILE_FINISHED_DOWNLOAD, "Finished_downloads.log");
     setDefault(LOG_FILE_SYSTEM,       "System.log");
-    setDefault(AUTO_AWAY, false);
-    setDefault(BIND_ADDRESS, "0.0.0.0");
+    setDefault(LOG_FILE_SPY,          "Spy.log");
+    setDefault(LOG_FILE_CMD_DEBUG,    "CmdDebug.log");
     setDefault(SOCKS_PORT, 1080);
     setDefault(SOCKS_RESOLVE, 1);
     setDefault(CONFIG_VERSION, "0.181");        // 0.181 is the last version missing configversion
@@ -202,6 +210,7 @@ SettingsManager::SettingsManager()
     setDefault(COMPRESS_TRANSFERS, true);
     setDefault(SFV_CHECK, true);
     setDefault(DEFAULT_AWAY_MESSAGE, "I'm away. State your business and I might answer later if you're lucky.");
+    setDefault(AUTO_AWAY, false);
     setDefault(TIME_STAMPS_FORMAT, "%H:%M");
     setDefault(MAX_COMPRESSION, 6);
     setDefault(NO_AWAYMSG_TO_BOTS, true);
@@ -221,7 +230,7 @@ SettingsManager::SettingsManager()
     setDefault(ADC_DEBUG, false);
     setDefault(SEARCH_HISTORY, 10);
     setDefault(SET_MINISLOT_SIZE, 64);
-    setDefault(MAX_FILELIST_SIZE, 512);
+    setDefault(MAX_FILELIST_SIZE, 4*1024);
     setDefault(PRIO_HIGHEST_SIZE, 64);
     setDefault(PRIO_HIGH_SIZE, 0);
     setDefault(PRIO_NORMAL_SIZE, 0);
@@ -242,14 +251,14 @@ SettingsManager::SettingsManager()
     setDefault(SEARCH_ONLY_FREE_SLOTS, false);
     setDefault(SEARCH_FILTER_SHARED, true);
     setDefault(LAST_SEARCH_TYPE, 0);
-    setDefault(SOCKET_IN_BUFFER, 64*1024);
-    setDefault(SOCKET_OUT_BUFFER, 64*1024);
+    setDefault(SOCKET_IN_BUFFER, 0); // OS default
+    setDefault(SOCKET_OUT_BUFFER, 0); // OS default
     setDefault(TLS_TRUSTED_CERTIFICATES_PATH, Util::getPath(Util::PATH_USER_CONFIG) + "Certificates" PATH_SEPARATOR_STR);
     setDefault(TLS_PRIVATE_KEY_FILE, Util::getPath(Util::PATH_USER_CONFIG) + "Certificates" PATH_SEPARATOR_STR "client.key");
     setDefault(TLS_CERTIFICATE_FILE, Util::getPath(Util::PATH_USER_CONFIG) + "Certificates" PATH_SEPARATOR_STR "client.crt");
-    setDefault(AUTO_REFRESH_TIME, 60);  // minutes
-    setDefault(HASHING_START_DELAY, 60); // seconds
     setDefault(USE_TLS, true);
+    setDefault(HASHING_START_DELAY, 60); // seconds
+    setDefault(AUTO_REFRESH_TIME, 60);
     setDefault(AUTO_SEARCH_LIMIT, 5);
     setDefault(AUTO_KICK_NO_FAVS, false);
     setDefault(PROMPT_PASSWORD, false);
@@ -261,7 +270,6 @@ SettingsManager::SettingsManager()
     setDefault(SEGMENTED_DL, true);
     setDefault(FOLLOW_LINKS, false);
     setDefault(SEND_BLOOM, true);
-    setDefault(CORAL, true);
     setDefault(FINISHED_DL_ONLY_FULL, true);
     setDefault(SEARCH_MERGE, true);
     setDefault(HASH_BUFFER_SIZE_MB, 8);
@@ -270,19 +278,18 @@ SettingsManager::SettingsManager()
     setDefault(HASH_BUFFER_PRIVATE, true);
     setDefault(RECONNECT_DELAY, 15);
     setDefault(DHT_PORT, 6250);
-    setDefault(USE_DHT, false);
+    setDefault(USE_DHT, true);
     setDefault(SEARCH_PASSIVE, false);
-    setDefault(AUTO_DETECT_CONNECTION, false);
     setDefault(MAX_UPLOAD_SPEED_MAIN, 0);
     setDefault(MAX_DOWNLOAD_SPEED_MAIN, 0);
     setDefault(TIME_DEPENDENT_THROTTLE, false);
-    setDefault(THROTTLE_ENABLE, false);
     setDefault(MAX_DOWNLOAD_SPEED_ALTERNATE, 0);
     setDefault(MAX_UPLOAD_SPEED_ALTERNATE, 0);
     setDefault(BANDWIDTH_LIMIT_START, 1);
     setDefault(BANDWIDTH_LIMIT_END, 1);
     setDefault(SLOTS_ALTERNATE_LIMITING, 1);
     setDefault(SLOTS_PRIMARY, 3);
+    setDefault(THROTTLE_ENABLE, false);
     setDefault(KEEP_FINISHED_FILES, false);
     setDefault(USE_IP, true);
     setDefault(SHOW_FREE_SLOTS_DESC, false);
@@ -302,6 +309,10 @@ SettingsManager::SettingsManager()
     setDefault(USE_ADL_ONLY_OWN_LIST, false);
     setDefault(ALLOW_SIM_UPLOADS, true);
     setDefault(CHECK_TARGETS_PATHS_ON_START, false);
+    setDefault(SHARE_SKIP_ZERO_BYTE, false);
+    setDefault(APP_UNIT_BASE, 0);
+    setDefault(REQUIRE_TLS, true); // True by default: We assume TLS is commonplace enough among ADC clients.
+
     setSearchTypeDefaults();
 }
 
@@ -384,7 +395,7 @@ void SettingsManager::load(string const& aFileName)
             }
         }
 
-        if(SETTING(PRIVATE_ID).length() != 39 || CID(SETTING(PRIVATE_ID)).isZero()) {
+        if(SETTING(PRIVATE_ID).length() != 39 || !CID(SETTING(PRIVATE_ID))) {
             set(PRIVATE_ID, CID::generate().toBase32());
         }
 
@@ -418,6 +429,8 @@ void SettingsManager::load(string const& aFileName)
             set(AUTO_SEARCH_LIMIT, 5);
         else if(SETTING(AUTO_SEARCH_LIMIT) < 1)
             set(AUTO_SEARCH_LIMIT, 1);
+        if(SETTING(MAX_FILELIST_SIZE) < 1024)
+            set(MAX_FILELIST_SIZE, 1024);
 
 #ifdef _DEBUG
         set(PRIVATE_ID, CID::generate().toBase32());
@@ -431,10 +444,10 @@ void SettingsManager::load(string const& aFileName)
         xml.stepOut();
 
     } catch(const Exception&) {
-        if(CID(SETTING(PRIVATE_ID)).isZero())
+        if(!CID(SETTING(PRIVATE_ID)))
             set(PRIVATE_ID, CID::generate().toBase32());
     }
-    if (SETTING(DHT_KEY).length() != 39 || CID(SETTING(DHT_KEY)).isZero())
+    if (SETTING(DHT_KEY).length() != 39 || !CID(SETTING(DHT_KEY)))
         set(DHT_KEY, CID::generate().toBase32());
 }
 
@@ -488,9 +501,9 @@ void SettingsManager::save(string const& aFileName) {
 
     xml.addTag("SearchTypes");
     xml.stepIn();
-    for(SearchTypesIterC i = searchTypes.begin(); i != searchTypes.end(); ++i) {
-        xml.addTag("SearchType", Util::toString(";", i->second));
-        xml.addChildAttrib("Id", i->first);
+    for(auto& i: searchTypes) {
+        xml.addTag("SearchType", Util::toString(";", i.second));
+        xml.addChildAttrib("Id", i.first);
     }
     xml.stepOut();
 
@@ -525,7 +538,7 @@ void SettingsManager::setSearchTypeDefaults() {
     searchTypes.clear();
 
     // for conveniency, the default search exts will be the same as the ones defined by SEGA.
-    const vector<StringList>& searchExts = AdcHub::getSearchExts();
+    const auto& searchExts = AdcHub::getSearchExts();
     for(size_t i = 0, n = searchExts.size(); i < n; ++i)
         searchTypes[string(1, '1' + i)] = searchExts[i];
 
@@ -575,7 +588,7 @@ SettingsManager::SearchTypesIter SettingsManager::getSearchType(const string& na
     return ret;
 }
 
-bool SettingsManager::getType(const char* name, int& n, int& type) const {
+bool SettingsManager::getType(const char* name, int& n, Types &type) const {
     for(n = 0; n < INT64_LAST; n++) {
         if (strcmp(settingTags[n].c_str(), name) == 0) {
             if (n < STR_LAST) {
@@ -593,30 +606,44 @@ bool SettingsManager::getType(const char* name, int& n, int& type) const {
     return false;
 }
 
-const std::string SettingsManager::parseCoreCmd(const std::string& cmd) {
+const std::string SettingsManager::parseCoreCmd(const string& cmd) {
     StringTokenizer<string> sl(cmd, ' ');
-    if (sl.getTokens().size() == 1 || sl.getTokens().size() == 2) {
-        int n,type; string tmp;
-        getType(sl.getTokens().at(0).c_str(),n,type);
-        if (type == SettingsManager::TYPE_INT) {
-            if (sl.getTokens().size() == 2) {
-                int i = atoi(sl.getTokens().at(1).c_str());
-                set((SettingsManager::IntSetting)n,i);
-            } else if (sl.getTokens().size() == 1)
-                tmp = Util::toString(get((SettingsManager::IntSetting)n,false));
-        }
-        else if (type == SettingsManager::TYPE_STRING) {
-            if (sl.getTokens().size() == 2)
-                set((SettingsManager::StrSetting)n, sl.getTokens().at(1));
-            else if (sl.getTokens().size() == 1)
-                tmp = get((SettingsManager::StrSetting)n,false);
-         } else
-            return _("Error: setting not found!");
-        return !tmp.empty() ?
-        _("Core setting ") + string(sl.getTokens().at(0)) + ": " + tmp :
-        _("Change core setting ") + string(sl.getTokens().at(0)) + _(" to ") + string(sl.getTokens().at(1));
+    if (sl.getTokens().size() == 1) {
+        string ret;
+        bool b = parseCoreCmd(ret, sl.getTokens().at(0), Util::emptyString);
+        return (!b ? _("Error: setting not found!") : _("Core setting ") + sl.getTokens().at(0) + ": " + ret);
+    } else if (sl.getTokens().size() >= 2) {
+        string tmp = cmd.substr(sl.getTokens().at(0).size()+1);
+        string ret;
+        bool b = parseCoreCmd(ret, sl.getTokens().at(0), tmp);
+        return (!b ? _("Error: setting not found!") : _("Change core setting ") + sl.getTokens().at(0) + _(" to ") + tmp);
     }
-    return _("Error: segv parser :D");
+    return Util::emptyString;
+}
+
+bool SettingsManager::parseCoreCmd(string& ret, const string& key, const string& value) {
+    if (key.empty()) {
+        return false;
+    }
+
+    int n;
+    SettingsManager::Types type;
+    getType(key.c_str(), n, type);
+    if (type == SettingsManager::TYPE_INT) {
+        if (!value.empty()) {
+            int i = atoi(value.c_str());
+            set((SettingsManager::IntSetting)n,i);
+        } else if (value.empty())
+            ret = Util::toString(get((SettingsManager::IntSetting)n,false));
+    }
+    else if (type == SettingsManager::TYPE_STRING) {
+        if (!value.empty())
+            set((SettingsManager::StrSetting)n, value);
+        else if (value.empty())
+            ret = get((SettingsManager::StrSetting)n,false);
+    } else
+        return false;
+    return true;
 }
 
 } // namespace dcpp
