@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -49,104 +48,119 @@ public:
     typedef std::unordered_map<string, StringList> SearchTypes;
     typedef SearchTypes::iterator SearchTypesIter;
     typedef SearchTypes::const_iterator SearchTypesIterC;
+
+    enum Types {
+        TYPE_STRING,
+        TYPE_INT,
+        TYPE_INT64
+    };
+
     static StringList connectionSpeeds;
 
     enum StrSetting { STR_FIRST,
-        NICK = STR_FIRST, UPLOAD_SPEED, DESCRIPTION, DOWNLOAD_DIRECTORY,
-        EMAIL, EXTERNAL_IP, HUBLIST_SERVERS,
-        HTTP_PROXY, LOG_DIRECTORY, LOG_FORMAT_POST_DOWNLOAD, LOG_FORMAT_POST_FINISHED_DOWNLOAD,
-        LOG_FORMAT_POST_UPLOAD, LOG_FORMAT_MAIN_CHAT,
-        LOG_FORMAT_PRIVATE_CHAT, TEMP_DOWNLOAD_DIRECTORY,
-        BIND_ADDRESS, SOCKS_SERVER, SOCKS_USER, SOCKS_PASSWORD,
-        CONFIG_VERSION, DEFAULT_AWAY_MESSAGE, TIME_STAMPS_FORMAT,
-        PRIVATE_ID, LOG_FILE_MAIN_CHAT, LOG_FILE_PRIVATE_CHAT,
-        LOG_FILE_STATUS, LOG_FILE_UPLOAD,
-        LOG_FILE_DOWNLOAD, LOG_FILE_FINISHED_DOWNLOAD, LOG_FILE_SYSTEM, LOG_FORMAT_SYSTEM,
-        LOG_FORMAT_STATUS, TLS_PRIVATE_KEY_FILE,
-        TLS_CERTIFICATE_FILE, TLS_TRUSTED_CERTIFICATES_PATH,
-        LANGUAGE, SKIPLIST_SHARE, INTERNETIP, BIND_IFACE_NAME,
-        DHT_KEY, DYNDNS_SERVER, MIME_HANDLER,
-        STR_LAST };
+                      NICK = STR_FIRST, UPLOAD_SPEED, DESCRIPTION, DOWNLOAD_DIRECTORY,
+                      EMAIL, EXTERNAL_IP, HUBLIST_SERVERS,
+                      HTTP_PROXY, LOG_DIRECTORY, LOG_FORMAT_POST_DOWNLOAD, LOG_FORMAT_POST_FINISHED_DOWNLOAD,
+                      LOG_FORMAT_POST_UPLOAD, LOG_FORMAT_MAIN_CHAT,
+                      LOG_FORMAT_PRIVATE_CHAT, TEMP_DOWNLOAD_DIRECTORY,
+                      BIND_ADDRESS, SOCKS_SERVER, SOCKS_USER, SOCKS_PASSWORD,
+                      CONFIG_VERSION, DEFAULT_AWAY_MESSAGE, TIME_STAMPS_FORMAT,
+                      PRIVATE_ID, LOG_FILE_MAIN_CHAT, LOG_FILE_PRIVATE_CHAT,
+                      LOG_FILE_STATUS, LOG_FILE_UPLOAD,
+                      LOG_FILE_DOWNLOAD, LOG_FILE_FINISHED_DOWNLOAD, LOG_FILE_SYSTEM, LOG_FORMAT_SYSTEM,
+                      LOG_FORMAT_STATUS, LOG_FILE_SPY, LOG_FORMAT_SPY, TLS_PRIVATE_KEY_FILE,
+                      TLS_CERTIFICATE_FILE, TLS_TRUSTED_CERTIFICATES_PATH,
+                      LANGUAGE, SKIPLIST_SHARE, INTERNETIP, BIND_IFACE_NAME,
+                      DHT_KEY, DYNDNS_SERVER, MIME_HANDLER,
+                      LOG_FILE_CMD_DEBUG, LOG_FORMAT_CMD_DEBUG,
+                      STR_LAST };
 
     enum IntSetting { INT_FIRST = STR_LAST + 1,
-        INCOMING_CONNECTIONS = INT_FIRST, TCP_PORT, SLOTS,
-        AUTO_FOLLOW, SHARE_HIDDEN, FILTER_MESSAGES,
-        AUTO_SEARCH, AUTO_SEARCH_TIME,
-        REPORT_ALTERNATES, TIME_STAMPS,
-        IGNORE_HUB_PMS, IGNORE_BOT_PMS, LIST_DUPES, BUFFER_SIZE,
-        DOWNLOAD_SLOTS, MAX_DOWNLOAD_SPEED, LOG_MAIN_CHAT,
-        LOG_PRIVATE_CHAT, LOG_DOWNLOADS, LOG_FINISHED_DOWNLOADS,
-        LOG_UPLOADS, MIN_UPLOAD_SPEED,
-        AUTO_AWAY, SOCKS_PORT, SOCKS_RESOLVE,
-        KEEP_LISTS, AUTO_KICK, COMPRESS_TRANSFERS,
-        SFV_CHECK, MAX_COMPRESSION, NO_AWAYMSG_TO_BOTS, SKIP_ZERO_BYTE,
-        ADLS_BREAK_ON_FIRST, HUB_USER_COMMANDS, AUTO_SEARCH_AUTO_MATCH,
-        LOG_SYSTEM,
-        LOG_FILELIST_TRANSFERS, SEND_UNKNOWN_COMMANDS, MAX_HASH_SPEED,
-        GET_USER_COUNTRY, LOG_STATUS_MESSAGES,  SEARCH_PASSIVE,
-        ADD_FINISHED_INSTANTLY, DONT_DL_ALREADY_SHARED, UDP_PORT,
-        SHOW_LAST_LINES_LOG, ADC_DEBUG,
-        SEARCH_HISTORY, SET_MINISLOT_SIZE, MAX_FILELIST_SIZE,
-        PRIO_HIGHEST_SIZE, PRIO_HIGH_SIZE, PRIO_NORMAL_SIZE,
-        PRIO_LOW_SIZE, PRIO_LOWEST, AUTODROP_SPEED, AUTODROP_INTERVAL,
-        AUTODROP_ELAPSED, AUTODROP_INACTIVITY, AUTODROP_MINSOURCES,
-        AUTODROP_FILESIZE, AUTODROP_ALL, AUTODROP_FILELISTS,
-        AUTODROP_DISCONNECT, OUTGOING_CONNECTIONS, NO_IP_OVERRIDE,
-        NO_USE_TEMP_DIR, SHARE_TEMP_FILES, SEARCH_ONLY_FREE_SLOTS,
-        LAST_SEARCH_TYPE,
-        SOCKET_IN_BUFFER, SOCKET_OUT_BUFFER,
-        AUTO_REFRESH_TIME, HASHING_START_DELAY, USE_TLS, AUTO_SEARCH_LIMIT,
-        AUTO_KICK_NO_FAVS, PROMPT_PASSWORD,
-        DONT_DL_ALREADY_QUEUED,
-        MAX_COMMAND_LENGTH, ALLOW_UNTRUSTED_HUBS, ALLOW_UNTRUSTED_CLIENTS,
-        TLS_PORT, FAST_HASH, SEGMENTED_DL,
-        FOLLOW_LINKS, SEND_BLOOM, CORAL,
-        SEARCH_FILTER_SHARED, FINISHED_DL_ONLY_FULL,
-        SEARCH_MERGE, HASH_BUFFER_SIZE_MB, HASH_BUFFER_POPULATE,
-        HASH_BUFFER_NORESERVE, HASH_BUFFER_PRIVATE,
-        USE_DHT, DHT_PORT,
-        RECONNECT_DELAY, AUTO_DETECT_CONNECTION, BANDWIDTH_LIMIT_START,
-        BANDWIDTH_LIMIT_END, THROTTLE_ENABLE, TIME_DEPENDENT_THROTTLE,
-        MAX_DOWNLOAD_SPEED_ALTERNATE, MAX_UPLOAD_SPEED_ALTERNATE,
-        MAX_DOWNLOAD_SPEED_MAIN, MAX_UPLOAD_SPEED_MAIN,
-        SLOTS_ALTERNATE_LIMITING, SLOTS_PRIMARY, KEEP_FINISHED_FILES,
-        SHOW_FREE_SLOTS_DESC, USE_IP, OVERLAP_CHUNKS, CASESENSITIVE_FILELIST,
-        IPFILTER, TEXT_COLOR, USE_LUA, ALLOW_NATT, IP_TOS_VALUE, SEGMENT_SIZE,
-        BIND_IFACE, MINIMUM_SEARCH_INTERVAL, DYNDNS_ENABLE, ALLOW_UPLOAD_MULTI_HUB,
-        USE_ADL_ONLY_OWN_LIST, ALLOW_SIM_UPLOADS, CHECK_TARGETS_PATHS_ON_START,
-        NMDC_DEBUG,
-        INT_LAST };
+                      INCOMING_CONNECTIONS = INT_FIRST, TCP_PORT, SLOTS,
+                      AUTO_FOLLOW, SHARE_HIDDEN, FILTER_MESSAGES,
+                      AUTO_SEARCH, AUTO_SEARCH_TIME,
+                      REPORT_ALTERNATES, TIME_STAMPS,
+                      IGNORE_HUB_PMS, IGNORE_BOT_PMS, LIST_DUPES, BUFFER_SIZE,
+                      DOWNLOAD_SLOTS, MAX_DOWNLOAD_SPEED, LOG_MAIN_CHAT,
+                      LOG_PRIVATE_CHAT, LOG_DOWNLOADS, LOG_FINISHED_DOWNLOADS,
+                      LOG_UPLOADS, MIN_UPLOAD_SPEED,
+                      AUTO_AWAY, SOCKS_PORT, SOCKS_RESOLVE,
+                      KEEP_LISTS, AUTO_KICK, COMPRESS_TRANSFERS,
+                      SFV_CHECK, MAX_COMPRESSION, NO_AWAYMSG_TO_BOTS, SKIP_ZERO_BYTE,
+                      ADLS_BREAK_ON_FIRST, HUB_USER_COMMANDS, AUTO_SEARCH_AUTO_MATCH,
+                      LOG_SYSTEM,
+                      LOG_FILELIST_TRANSFERS, SEND_UNKNOWN_COMMANDS, MAX_HASH_SPEED,
+                      GET_USER_COUNTRY, LOG_STATUS_MESSAGES,  SEARCH_PASSIVE,
+                      ADD_FINISHED_INSTANTLY, DONT_DL_ALREADY_SHARED, UDP_PORT,
+                      SHOW_LAST_LINES_LOG, ADC_DEBUG,
+                      SEARCH_HISTORY, SET_MINISLOT_SIZE, MAX_FILELIST_SIZE,
+                      PRIO_HIGHEST_SIZE, PRIO_HIGH_SIZE, PRIO_NORMAL_SIZE,
+                      PRIO_LOW_SIZE, PRIO_LOWEST, AUTODROP_SPEED, AUTODROP_INTERVAL,
+                      AUTODROP_ELAPSED, AUTODROP_INACTIVITY, AUTODROP_MINSOURCES,
+                      AUTODROP_FILESIZE, AUTODROP_ALL, AUTODROP_FILELISTS,
+                      AUTODROP_DISCONNECT, OUTGOING_CONNECTIONS, NO_IP_OVERRIDE,
+                      NO_USE_TEMP_DIR, SHARE_TEMP_FILES, SEARCH_ONLY_FREE_SLOTS,
+                      LAST_SEARCH_TYPE,
+                      SOCKET_IN_BUFFER, SOCKET_OUT_BUFFER,
+                      AUTO_REFRESH_TIME, HASHING_START_DELAY, USE_TLS, AUTO_SEARCH_LIMIT,
+                      AUTO_KICK_NO_FAVS, PROMPT_PASSWORD,
+                      DONT_DL_ALREADY_QUEUED,
+                      MAX_COMMAND_LENGTH, ALLOW_UNTRUSTED_HUBS, ALLOW_UNTRUSTED_CLIENTS,
+                      TLS_PORT, FAST_HASH, SEGMENTED_DL,
+                      FOLLOW_LINKS, SEND_BLOOM,
+                      SEARCH_FILTER_SHARED, FINISHED_DL_ONLY_FULL,
+                      SEARCH_MERGE, HASH_BUFFER_SIZE_MB, HASH_BUFFER_POPULATE,
+                      HASH_BUFFER_NORESERVE, HASH_BUFFER_PRIVATE,
+                      USE_DHT, DHT_PORT,
+                      RECONNECT_DELAY, AUTO_DETECT_CONNECTION, BANDWIDTH_LIMIT_START,
+                      BANDWIDTH_LIMIT_END, THROTTLE_ENABLE, TIME_DEPENDENT_THROTTLE,
+                      MAX_DOWNLOAD_SPEED_ALTERNATE, MAX_UPLOAD_SPEED_ALTERNATE,
+                      MAX_DOWNLOAD_SPEED_MAIN, MAX_UPLOAD_SPEED_MAIN,
+                      SLOTS_ALTERNATE_LIMITING, SLOTS_PRIMARY, KEEP_FINISHED_FILES,
+                      SHOW_FREE_SLOTS_DESC, USE_IP, OVERLAP_CHUNKS, CASESENSITIVE_FILELIST,
+                      IPFILTER, TEXT_COLOR, USE_LUA, ALLOW_NATT, IP_TOS_VALUE, SEGMENT_SIZE,
+                      BIND_IFACE, MINIMUM_SEARCH_INTERVAL, DYNDNS_ENABLE, ALLOW_UPLOAD_MULTI_HUB,
+                      USE_ADL_ONLY_OWN_LIST, ALLOW_SIM_UPLOADS, CHECK_TARGETS_PATHS_ON_START,
+                      NMDC_DEBUG, SHARE_SKIP_ZERO_BYTE, REQUIRE_TLS, LOG_SPY,
+                      APP_UNIT_BASE,
+                      LOG_CMD_DEBUG,
+                      INT_LAST };
 
     enum Int64Setting { INT64_FIRST = INT_LAST + 1,
-        TOTAL_UPLOAD = INT64_FIRST, TOTAL_DOWNLOAD,
-        INT64_LAST };
+                        TOTAL_UPLOAD = INT64_FIRST, TOTAL_DOWNLOAD,
+                        INT64_LAST };
 
     enum FloatSetting { FLOAT_FIRST = INT64_LAST +1,
-        FLOAT_LAST, SETTINGS_LAST = FLOAT_LAST };
-    enum {  INCOMING_DIRECT, INCOMING_FIREWALL_UPNP, INCOMING_FIREWALL_NAT,
-        INCOMING_FIREWALL_PASSIVE };
+                        FLOAT_LAST, SETTINGS_LAST = FLOAT_LAST };
+
+    enum {
+        INCOMING_DIRECT,
+        INCOMING_FIREWALL_UPNP,
+        INCOMING_FIREWALL_NAT,
+        INCOMING_FIREWALL_PASSIVE
+    };
+
     enum {  OUTGOING_DIRECT, OUTGOING_SOCKS5 };
 
     enum {  MAGNET_AUTO_SEARCH, MAGNET_AUTO_DOWNLOAD };
 
     const string& get(StrSetting key, bool useDefault = true) const {
         return (isSet[key] || !useDefault) ? strSettings[key - STR_FIRST] : strDefaults[key - STR_FIRST];
-    }
+        }
 
-    int get(IntSetting key, bool useDefault = true) const {
+        int get(IntSetting key, bool useDefault = true) const {
         return (isSet[key] || !useDefault) ? intSettings[key - INT_FIRST] : intDefaults[key - INT_FIRST];
     }
+    bool getBool(IntSetting key, bool useDefault = true) const {
+        return (get(key, useDefault) != 0);
+    }
     int64_t get(Int64Setting key, bool useDefault = true) const {
         return (isSet[key] || !useDefault) ? int64Settings[key - INT64_FIRST] : int64Defaults[key - INT64_FIRST];
-    }
-    float get(FloatSetting key, bool useDefault = true) const {
+        }
+        float get(FloatSetting key, bool useDefault = true) const {
         return (isSet[key] || !useDefault) ? floatSettings[key - FLOAT_FIRST] : floatDefaults[key - FLOAT_FIRST];
     }
 
-    bool getBool(IntSetting key, bool useDefault = true) const {
-        return (get(key, useDefault) != 0);
-    }
-
     void set(StrSetting key, string const& value) {
         if(((key == DESCRIPTION) || (key == NICK)) && (value.size() > 35)) {
             strSettings[key - STR_FIRST] = value.substr(0, 35);
@@ -219,8 +233,6 @@ public:
 
     void unset(size_t key) { isSet[key] = false; }
 
-    const std::string parseCoreCmd(const std::string& cmd);
-
     void load() {
         Util::migrate(getConfigFile());
         load(getConfigFile());
@@ -232,13 +244,7 @@ public:
     void load(const string& aFileName);
     void save(const string& aFileName);
 
-    enum Types {
-        TYPE_STRING,
-        TYPE_INT,
-        TYPE_INT64
-    };
-
-    bool getType(const char* name, int& n, int& type) const;
+    bool getType(const char* name, int& n, Types& type) const;
     // Search types
     void validateSearchTypeName(const string& name) const;
     void setSearchTypeDefaults();
@@ -251,10 +257,14 @@ public:
         return searchTypes;
     }
     const StringList& getExtensions(const string& name);
+
+    const string parseCoreCmd(const string& cmd);
+    bool parseCoreCmd(string& ret, const string& key, const string& value);
+
 private:
     friend class Singleton<SettingsManager>;
     SettingsManager();
-    virtual ~SettingsManager() noexcept { }
+    virtual ~SettingsManager() { }
 
     static const string settingTags[SETTINGS_LAST+1];
 
@@ -270,7 +280,7 @@ private:
 
     bool isSet[SETTINGS_LAST];
 
-    string getConfigFile() { return Util::getPath(Util::PATH_USER_CONFIG) + "DCPlusPlus.xml"; }
+    static string getConfigFile() { return Util::getPath(Util::PATH_USER_CONFIG) + "DCPlusPlus.xml"; }
 
     // Search types
     SearchTypes searchTypes; // name, extlist
