@@ -1,18 +1,19 @@
 /*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
-* (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ * Copyright (C) 2001-2019 Jacek Sieka, arnetheduck on gmail point com
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ */
 
 #include "stdinc.h"
 
@@ -25,11 +26,11 @@
 namespace dcpp {
 
 static bool isSpace(int c) {
-        return c == 0x20 || c == 0x09 || c == 0x0d || c == 0x0a;
+    return c == 0x20 || c == 0x09 || c == 0x0d || c == 0x0a;
 }
 
 static bool inRange(int c, int a, int b) {
-        return c >= a && c <= b;
+    return c >= a && c <= b;
 }
 
 static bool isNameStartChar(int c) {
@@ -38,19 +39,19 @@ static bool isNameStartChar(int c) {
             || c == '_'
             || inRange(c, 'a', 'z')
             // Comment out some valid XML chars that we don't allow
-            || c == '+' //NOTE: freedcpp
-/*              || inRange(c, 0xC0, 0xD6)
-            || inRange(c, 0xD8, 0xF6)
-            || inRange(c, 0xF8, 0x2FF)
-            || inRange(c, 0x370, 0x37D)
-            || inRange(c, 0x37F, 0x1FFF)
-            || inRange(c, 0x200C, 0x200D)
-            || inRange(c, 0x2070, 0x218F)
-            || inRange(c, 0x2C00, 0x2FEF)
-            || inRange(c, 0x3001, 0xD7FF)
-            || inRange(c, 0xF900, 0xFDCF)
-            || inRange(c, 0xFDF0, 0xFFFD)
-            || inRange(c, 0x10000, 0xEFFFF) */
+            || c == '+' // NOTE: freedcpp
+            /*              || inRange(c, 0xC0, 0xD6)
+                                                                    || inRange(c, 0xD8, 0xF6)
+                                                                    || inRange(c, 0xF8, 0x2FF)
+                                                                    || inRange(c, 0x370, 0x37D)
+                                                                    || inRange(c, 0x37F, 0x1FFF)
+                                                                    || inRange(c, 0x200C, 0x200D)
+                                                                    || inRange(c, 0x2070, 0x218F)
+                                                                    || inRange(c, 0x2C00, 0x2FEF)
+                                                                    || inRange(c, 0x3001, 0xD7FF)
+                                                                    || inRange(c, 0xF900, 0xFDCF)
+                                                                    || inRange(c, 0xFDF0, 0xFFFD)
+                                                                    || inRange(c, 0x10000, 0xEFFFF) */
             ;
 }
 
@@ -60,9 +61,9 @@ static bool isNameChar(int c) {
             || c == '.'
             || inRange(c, '0', '9')
             // Again, real XML is more permissive
-/*              || c == 0xB7
-            || inRange(c, 0x0300, 0x036F)
-            || inRange(c, 0x203F, 0x2040) */
+            /*              || c == 0xB7
+                                                                    || inRange(c, 0x0300, 0x036F)
+                                                                    || inRange(c, 0x203F, 0x2040) */
             ;
 }
 
@@ -100,7 +101,7 @@ bool SimpleXMLReader::error(const char* e) {
 const string& SimpleXMLReader::CallBack::getAttrib(StringPairList& attribs, const string& name, size_t hint) {
     hint = min(hint, attribs.size());
 
-    StringPairIter i = find_if(attribs.begin() + hint, attribs.end(), CompareFirst<string, string>(name));
+    auto i = find_if(attribs.begin() + hint, attribs.end(), CompareFirst<string, string>(name));
     if(i == attribs.end()) {
         i = find_if(attribs.begin(), attribs.begin() + hint, CompareFirst<string, string>(name));
         return ((i == (attribs.begin() + hint)) ? Util::emptyString : i->second);
@@ -136,22 +137,22 @@ bool SimpleXMLReader::literal(const char* lit, size_t len, bool withSpace, Parse
 
 bool SimpleXMLReader::element() {
     if(!needChars(2)) {
-            return true;
+        return true;
     }
 
     int c = charAt(1);
-        if(charAt(0) == '<' && isNameStartChar(c)) {
-            if(elements.size() >= MAX_NESTING) {
-                error("Max nesting exceeded");
-            }
+    if(charAt(0) == '<' && isNameStartChar(c)) {
+        if(elements.size() >= MAX_NESTING) {
+            error("Max nesting exceeded");
+        }
 
-            state = STATE_ELEMENT_NAME;
-            elements.push_back(std::string());
-            append(elements.back(), MAX_NAME_SIZE, c);
+        state = STATE_ELEMENT_NAME;
+        elements.emplace_back();
+        append(elements.back(), MAX_NAME_SIZE, c);
 
-            advancePos(2);
+        advancePos(2);
 
-            return true;
+        return true;
     }
 
     return false;
@@ -201,7 +202,7 @@ bool SimpleXMLReader::elementAttr() {
 
     int c = charAt(0);
     if(isNameStartChar(c)) {
-        attribs.push_back(StringPair());
+        attribs.emplace_back();
         append(attribs.back().first, MAX_NAME_SIZE, c);
 
         state = STATE_ELEMENT_ATTR_NAME;
@@ -327,7 +328,7 @@ bool SimpleXMLReader::declVersionNum() {
     if((sep == '"' || sep == '\'') && charAt(1) == '1' && charAt(2) == '.') {
         // At least one more number
         if(!inRange(charAt(3), '0', '9')) {
-                return false;
+            return false;
         }
 
         // Now an unknown number of [0-9]
@@ -361,7 +362,7 @@ bool SimpleXMLReader::declEncodingValue() {
             return true;
         } else if(c == '&') {
             if(!entref(encoding)) {
-                    return false;
+                return false;
             }
         } else {
             append(encoding, MAX_VALUE_SIZE, c);
@@ -394,6 +395,28 @@ bool SimpleXMLReader::comment() {
     return true;
 }
 
+bool SimpleXMLReader::cdata() {
+    while(bufSize() > 0) {
+        int c = charAt(0);
+
+        if(c == ']') {
+            if(!needChars(3)) {
+                return true;
+            }
+            if(charAt(1) == ']' && charAt(2) == '>') {
+                state = STATE_CONTENT;
+                advancePos(3);
+                return true;
+            }
+        }
+
+        append(value, MAX_VALUE_SIZE, c);
+        advancePos(1);
+    }
+
+    return true;
+}
+
 bool SimpleXMLReader::entref(string& d) {
     if(d.size() + 1 >= MAX_VALUE_SIZE) {
         error("Buffer overflow");
@@ -421,7 +444,7 @@ bool SimpleXMLReader::entref(string& d) {
             advancePos(6);
             return true;
 
-        // Ignore &#00000 decimal and &#x0000 hex values to avoid error, they wouldn't be parsed anyway
+            // Ignore &#00000 decimal and &#x0000 hex values to avoid error, they wouldn't be parsed anyway
         } else if(charAt(1) == '#' && isdigit(charAt(2)) && charAt(3) == ';') {
             advancePos(4);
             return true;
@@ -464,12 +487,6 @@ bool SimpleXMLReader::content() {
     }
 
     int c = charAt(0);
-    if(c == '<') {
-        if(!value.empty()) {
-            error("Mixed content not supported");
-        }
-        return false;
-    }
 
     if(c == '&') {
         return entref(value);
@@ -507,11 +524,7 @@ bool SimpleXMLReader::elementEndEnd() {
     }
 
     if(charAt(0) == '>') {
-        if(!encoding.empty() && encoding != Text::utf8) {
-            value = Text::toUtf8(encoding);
-        }
-        cb->endTag(elements.back(), value);
-        value.clear();
+        cb->endTag(elements.back());
         elements.pop_back();
 
         state = STATE_CONTENT;
@@ -570,10 +583,15 @@ void SimpleXMLReader::parse(InputStream& stream, size_t maxSize) {
     } while(process());
 }
 
-bool SimpleXMLReader::parse(const char* data, size_t len, bool more) {
+bool SimpleXMLReader::parse(const char* data, size_t len) {
     buf.append(data, len);
     return process();
 }
+
+bool SimpleXMLReader::parse(const string& str) {
+    return parse(str.c_str(), str.size());
+}
+
 bool SimpleXMLReader::spaceOrError(const char* message) {
     if(!skipSpace()) {
         error(message);
@@ -588,119 +606,124 @@ bool SimpleXMLReader::process() {
     while(true) {
         switch(state) {
         case STATE_START:
-                literal(LITN("\xef\xbb\xbf"), false, STATE_START)       // Byte order mark
-                || literal(LITN("<?xml"), true, STATE_DECL_VERSION)
-                || literal(LITN("<!--"), false, STATE_COMMENT)
-                || element()
-                || spaceOrError("Expecting XML declaration, element or comment");
-                break;
+            literal(LITN("\xef\xbb\xbf"), false, STATE_START)       // Byte order mark
+                    || literal(LITN("<?xml"), true, STATE_DECL_VERSION)
+                    || literal(LITN("<!--"), false, STATE_COMMENT)
+                    || element()
+                    || spaceOrError("Expecting XML declaration, element or comment");
+            break;
         case STATE_DECL_VERSION:
-                skipSpace()
-                || literal(LITN("version"), false, STATE_DECL_VERSION_EQ)
-                || spaceOrError("Expecting version");
-                break;
+            skipSpace()
+                    || literal(LITN("version"), false, STATE_DECL_VERSION_EQ)
+                    || spaceOrError("Expecting version");
+            break;
         case STATE_DECL_VERSION_EQ:
-                character('=', STATE_DECL_VERSION_NUM)
-                || spaceOrError("Expecting =");
-                break;
+            character('=', STATE_DECL_VERSION_NUM)
+                    || spaceOrError("Expecting =");
+            break;
         case STATE_DECL_VERSION_NUM:
-                declVersionNum()
-                || spaceOrError("Expecting version number");
-                break;
+            declVersionNum()
+                    || spaceOrError("Expecting version number");
+            break;
         case STATE_DECL_ENCODING:
-                literal(LITN("encoding"), false, STATE_DECL_ENCODING_EQ)
-                || literal(LITN("standalone"), false, STATE_DECL_STANDALONE_EQ)
-                || literal(LITN("?>"), false, STATE_CONTENT)
-                || spaceOrError("Expecting encoding | standalone | ?>");
-                break;
+            literal(LITN("encoding"), false, STATE_DECL_ENCODING_EQ)
+                    || literal(LITN("standalone"), false, STATE_DECL_STANDALONE_EQ)
+                    || literal(LITN("?>"), false, STATE_CONTENT)
+                    || spaceOrError("Expecting encoding | standalone | ?>");
+            break;
         case STATE_DECL_ENCODING_EQ:
-                character('=', STATE_DECL_ENCODING_NAME)
-                || spaceOrError("Expecting =");
-                break;
+            character('=', STATE_DECL_ENCODING_NAME)
+                    || spaceOrError("Expecting =");
+            break;
         case STATE_DECL_ENCODING_NAME:
-                character('\'', STATE_DECL_ENCODING_NAME_APOS)
-                || character('"', STATE_DECL_ENCODING_NAME_QUOT)
-                || spaceOrError("Expecting encoding name start");
-                break;
+            character('\'', STATE_DECL_ENCODING_NAME_APOS)
+                    || character('"', STATE_DECL_ENCODING_NAME_QUOT)
+                    || spaceOrError("Expecting encoding name start");
+            break;
         case STATE_DECL_ENCODING_NAME_APOS:
         case STATE_DECL_ENCODING_NAME_QUOT:
-                declEncodingValue()
-                || spaceOrError("Expecting encoding value");
+            declEncodingValue()
+                    || spaceOrError("Expecting encoding value");
         case STATE_DECL_STANDALONE:
-                literal(LITN("standalone"), false, STATE_DECL_STANDALONE_EQ)
-                || literal(LITN("?>"), false, STATE_CONTENT)
-                || spaceOrError("Expecting standalone | ?>");
-                break;
+            literal(LITN("standalone"), false, STATE_DECL_STANDALONE_EQ)
+                    || literal(LITN("?>"), false, STATE_CONTENT)
+                    || spaceOrError("Expecting standalone | ?>");
+            break;
         case STATE_DECL_STANDALONE_EQ:
-                character('=', STATE_DECL_STANDALONE_YES)
-                || spaceOrError("Expecting =");
-                break;
+            character('=', STATE_DECL_STANDALONE_YES)
+                    || spaceOrError("Expecting =");
+            break;
         case STATE_DECL_STANDALONE_YES:
-                literal(LITN("\"yes\""), false, STATE_DECL_END)
-                || literal(LITN("'yes'"), false, STATE_DECL_END)
-                || spaceOrError("Expecting standalone=yes");
-                break;
+            literal(LITN("\"yes\""), false, STATE_DECL_END)
+                    || literal(LITN("'yes'"), false, STATE_DECL_END)
+                    || spaceOrError("Expecting standalone=yes");
+            break;
         case STATE_DECL_END:
-                literal(LITN("?>"), false, STATE_CONTENT)
-                || spaceOrError("Expecting ?>");
-                break;
+            literal(LITN("?>"), false, STATE_CONTENT)
+                    || spaceOrError("Expecting ?>");
+            break;
         case STATE_ELEMENT_NAME:
-                elementName()
-                || error("Error while parsing element start");
-                break;
+            elementName()
+                    || error("Error while parsing element start");
+            break;
         case STATE_ELEMENT_END_SIMPLE:
-                elementEndSimple()
-                || error("Expecting >");
-                break;
+            elementEndSimple()
+                    || error("Expecting >");
+            break;
         case STATE_ELEMENT_END:
-                elementEnd()
-                || spaceOrError("Expecting element end");
-                break;
+            elementEnd()
+                    || spaceOrError("Expecting element end");
+            break;
         case STATE_ELEMENT_END_END:
-                elementEndEnd()
-                || spaceOrError("Expecting >");
-                break;
+            elementEndEnd()
+                    || spaceOrError("Expecting >");
+            break;
         case STATE_ELEMENT_ATTR:
-                elementAttr()
-                || elementEndComplex()
-                || character('/', STATE_ELEMENT_END_SIMPLE)
-                || spaceOrError("Expecting attribute | /> | >");
-                break;
+            elementAttr()
+                    || elementEndComplex()
+                    || character('/', STATE_ELEMENT_END_SIMPLE)
+                    || spaceOrError("Expecting attribute | /> | >");
+            break;
         case STATE_ELEMENT_ATTR_NAME:
-                elementAttrName()
-                || error("Expecting attribute name");
-                break;
+            elementAttrName()
+                    || error("Expecting attribute name");
+            break;
         case STATE_ELEMENT_ATTR_EQ:
-                character('=', STATE_ELEMENT_ATTR_VALUE)
-                || spaceOrError("Expecting attribute =");
-                break;
+            character('=', STATE_ELEMENT_ATTR_VALUE)
+                    || spaceOrError("Expecting attribute =");
+            break;
         case STATE_ELEMENT_ATTR_VALUE:
-                character('\'', STATE_ELEMENT_ATTR_VALUE_APOS)
-                || character('"', STATE_ELEMENT_ATTR_VALUE_QUOT)
-                || spaceOrError("Expecting attribute value start");
-                break;
+            character('\'', STATE_ELEMENT_ATTR_VALUE_APOS)
+                    || character('"', STATE_ELEMENT_ATTR_VALUE_QUOT)
+                    || spaceOrError("Expecting attribute value start");
+            break;
         case STATE_ELEMENT_ATTR_VALUE_APOS:
         case STATE_ELEMENT_ATTR_VALUE_QUOT:
-                elementAttrValue()
-                || error("Expecting attribute value");
-                break;
+            elementAttrValue()
+                    || error("Expecting attribute value");
+            break;
         case STATE_COMMENT:
-                comment()
-                || error("Error while parsing comment");
-                break;
+            comment()
+                    || error("Error while parsing comment");
+            break;
+        case STATE_CDATA:
+            cdata()
+                    || error("Error while parsing CDATA");
+            break;
         case STATE_CONTENT:
-                skipSpace(true)
-                || literal(LITN("<!--"), false, STATE_COMMENT)
-                || element()
-                || literal(LITN("</"), false, STATE_ELEMENT_END)
-                || content()
-                || error("Expecting content, element or comment");
-                break;
+            skipSpace(true)
+                    || literal(LITN("<!--"), false, STATE_COMMENT)
+                    || literal(LITN("<![CDATA["), false, STATE_CDATA)
+                    || element()
+                    || literal(LITN("</"), false, STATE_ELEMENT_END)
+                    || content()
+                    || error("Expecting content, element or comment");
+            break;
         case STATE_END:
-                buf.clear();
-                return false;
+            buf.clear();
+            return false;
         default:
-                error("Unexpected state"); break;
+            error("Unexpected state"); break;
         }
 
         if(oldState == state && oldPos == bufPos) {
@@ -712,8 +735,11 @@ bool SimpleXMLReader::process() {
             return true;
         }
 
-        if(state == STATE_CONTENT && state != oldState) {
-            // might contain whitespace from previous unfruitful contents (that turned out to be elements / comments)
+        if(oldState == STATE_CONTENT && state != oldState && !value.empty()) {
+            if(!encoding.empty() && encoding != Text::utf8) {
+                value = Text::toUtf8(value, encoding);
+            }
+            cb->data(value);
             value.clear();
         }
 
@@ -723,6 +749,6 @@ bool SimpleXMLReader::process() {
 
     // should never happen
     return false;
-}
+};
 
 }
