@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2012 Jacek Sieka, arnetheduck on gmail point com
+ * Copyright (C) 2001-2019 Jacek Sieka, arnetheduck on gmail point com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "stdinc.h"
@@ -21,6 +20,7 @@
 #include "UserCommand.h"
 
 #include "StringTokenizer.h"
+#include "Util.h"
 
 namespace dcpp {
 
@@ -36,8 +36,8 @@ void UserCommand::setDisplayName() {
     string name_ = name;
     Util::replace("//", "\t", name_);
     StringTokenizer<string> t(name_, '/');
-    for(auto i = t.getTokens().begin(), iend = t.getTokens().end(); i != iend; ++i) {
-        displayName.push_back(*i);
+    for(auto& i: t.getTokens()) {
+        displayName.push_back(i);
         Util::replace("\t", "/", displayName.back());
     }
 }
