@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Big Muscle, http://strongdc.sf.net
+ * Copyright (C) 2009-2010 Big Muscle, http://strongdc.sourceforge.net/
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -34,13 +33,14 @@ namespace dht
         public FastAlloc<Search>
     {
 
-        Search() : partial(false), stopping(false)
-        {
-        }
-
+        Search() = default;
         ~Search();
 
-        enum SearchType { TYPE_FILE = 1, TYPE_NODE = 3, TYPE_STOREFILE = 4 };   // standard types should match ADC protocol
+        enum class SearchType : uint8_t { // standard types should match ADC protocol
+            TYPE_FILE = 1,
+            TYPE_NODE = 3,
+            TYPE_STOREFILE = 4
+        };
 
         Node::Map possibleNodes;    // nodes where send search request soon to
         Node::Map triedNodes;       // nodes where search request has already been sent to
@@ -48,11 +48,11 @@ namespace dht
 
         string token;               // search identificator
         string term;                // search term (TTH/CID)
-        uint64_t lifeTime;          // time when this search has been started
-        int64_t filesize;           // file size
-        SearchType type;            // search type
-        bool partial;               // is this partial file search?
-        bool stopping;              // search is being stopped
+        uint64_t lifeTime = 0;      // time when this search has been started
+        int64_t filesize = 0;       // file size
+        SearchType type = SearchType::TYPE_FILE; // search type
+        bool partial = false;       // is this partial file search?
+        bool stopping = false;      // search is being stopped
 
         /** Processes this search request */
         void process();
