@@ -1,6 +1,7 @@
 /***************************************************************************
 *                                                                         *
 *   Copyright (C) 2009-2010  Alexandr Tkachev <tka4ev@gmail.com>          *
+*   Copyright (C) 2020 Boris Pek <tehnick-8@yandex.ru>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -13,17 +14,18 @@
 
 #pragma once
 
-#include "dcpp/QueueManagerListener.h"
-#include "dcpp/TimerManager.h"
-#include "dcpp/LogManager.h"
 #include "dcpp/ClientListener.h"
-#include "dcpp/ShareManager.h"
-#include "dcpp/Thread.h"
+#include "dcpp/DirectoryListing.h"
+#include "dcpp/LogManager.h"
+#include "dcpp/QueueManagerListener.h"
 #include "dcpp/SearchManager.h"
 #include "dcpp/SearchManagerListener.h"
 #include "dcpp/SearchResult.h"
 #include "dcpp/Singleton.h"
+#include "dcpp/ShareManager.h"
 #include "dcpp/Socket.h"
+#include "dcpp/TimerManager.h"
+#include "dcpp/Thread.h"
 
 class ServerThread :
         private TimerManagerListener,
@@ -48,7 +50,7 @@ public:
     bool sendPrivateMessage(const string& hub, const string& nick, const string& message);
     bool getFileList(const string& hub, const string& nick, bool match);
     void getChatPubFromClient(string& chat, const string& hub, const string& separator);
-    bool sendSearchonHubs(const string& search, const int& mode, const int& sizemode, const int& sizetype, const double& size, const string& huburls);
+    bool sendSearchOnHubs(const string& search, const int& mode, const int& sizemode, const int& sizetype, const double& size, const string& huburls);
     void returnSearchResults(vector<StringMap>& resultarray, const string& huburl);
     bool clearSearchResults(const string& huburl);
     void listShare(string& listshare, const string& sseparator);
@@ -57,24 +59,36 @@ public:
     bool addDirInShare(const string& sdirectory, const string& svirtname);
     bool addInQueue(const string& sddir, const string& name, const int64_t& size, const string& tth);
     bool setPriorityQueueItem(const string& target, const unsigned int& priority);
-    void getQueueParams(QueueItem* item, StringMap& params);
     void listQueueTargets(string& listqueue, const string& sseparator);
     void listQueue(unordered_map<string,StringMap>& listqueue);
     bool moveQueueItem(const string& source, const string& target);
     bool removeQueueItem(const string& target);
-    void updatelistQueueTargets();
-    void getItemSources(QueueItem* item, const string& separator, string& sources, unsigned int& online);
     void getItemSourcesbyTarget(const string& target, const string& separator, string& sources, unsigned int& online);
-    void getHashStatus(string& target, int64_t& bytesLeft, size_t& filesLeft, string& status);
+    void getHashStatus(string& target, uint64_t &bytesLeft, size_t& filesLeft, string& status);
     bool pauseHash();
-    void getMethodList(string& tmp);
     void matchAllList();
     void listHubsFullDesc(unordered_map<string,StringMap>& listhubs);
     void getHubUserList(string& userlist, const string& huburl, const string& separator);
-    void getParamsUser(StringMap& params, Identity& id);
-    void updateUser(const StringMap& params, Client* cl);
-    void removeUser(const string& cid, Client* cl);
     bool getUserInfo(StringMap& userinfo, const string& nick, const string& huburl);
+    void showLocalLists(string& l, const string& separator);
+    bool getClientFileList(const string& filelist, string& ret);
+    bool openFileList(const string& filelist);
+    //void buildList(const string& filelist, const string& nick, DirectoryListing* listing, bool full);
+    bool closeFileList(const string& filelist);
+    void closeAllFileLists();
+    void showOpenedLists(string& l, const string& separator);
+    void lsDirInList(const string& directory, const string& filelist, unordered_map<string,StringMap>& ret);
+    bool downloadDirFromList(const string &target, const string &downloadto, const string &filelist);
+    bool downloadFileFromList(const string &file, const string &downloadto, const string &filelist);
+    void getItemDescbyTarget(const string &target, StringMap &sm);
+    void queueClear();
+    bool settingsGetSet(string &out, const string &param, const string &value);
+    void ipFilterList(string &out, const string &separator);
+    void ipFilterOnOff(bool on);
+    void ipFilterPurgeRules(const string &rules);
+    void ipFilterAddRules(const string &rules);
+    void ipFilterUpDownRule(bool up, const string &rule);
+    bool configReload();
 
 private:
     friend class Singleton<ServerThread>;
@@ -86,7 +100,8 @@ private:
     void startSocket(bool changed);
     void autoConnect();
     void showPortsError(const std::string& port);
-    bool disconnect_all();
+    bool disconnectAll();
+    bool ignoreSearchResult(SearchResultPtr result);
     void parseSearchResult(SearchResultPtr result, StringMap &resultMap);
     string revertSeparator(const string &ps);
     typedef struct {
@@ -103,7 +118,12 @@ private:
     typedef unordered_map <string, CurHub> ClientMap;
     typedef ClientMap::const_iterator ClientIter;
     static ClientMap clientsMap;
-    bool json_run;
+
+    struct SearchFilter;
+    static SearchFilter searchFilter;
+
+    typedef unordered_map <string, DirectoryListing*> FilelistMap;
+    FilelistMap listsMap;
 
     // TimerManagerListener
     virtual void on(TimerManagerListener::Second, uint64_t aTick) noexcept;
@@ -139,4 +159,13 @@ private:
     dcpp::Socket sock;
     CriticalSection shutcs;
     static const unsigned int maxLines = 50;
+
+    void getQueueParams(QueueItem* item, StringMap& params);
+    void getItemSources(QueueItem* item, const string& separator, string& sources, unsigned int& online);
+    void getParamsUser(StringMap& params, Identity& id);
+    void updateUser(const StringMap& params, Client* cl);
+    void removeUser(const string& cid, Client* cl);
+    void lsDirInList(DirectoryListing::Directory *dir, unordered_map<string,StringMap>& ret);
+    bool downloadDirFromList(DirectoryListing::Directory *dir, DirectoryListing* list, const string& downloadto);
+    bool downloadFileFromList(DirectoryListing::File *file, DirectoryListing *list, const string &downloadto);
 };
