@@ -180,11 +180,7 @@ public:
     execute(xmlrpc_c::paramList const& paramList,
             xmlrpc_c::value *   const  retvalP) {
 
-        string version(EISKALTDCPP_VERSION);
-        version.append(" (");
-        version.append(EISKALTDCPP_VERSION_SFX);
-        version.append(")");
-        *retvalP = xmlrpc_c::value_string(version);
+        *retvalP = xmlrpc_c::value_string(eiskaltdcppVersionString);
     }
 };
 
@@ -200,20 +196,19 @@ public:
     execute(xmlrpc_c::paramList const& paramList,
             xmlrpc_c::value *   const  retvalP) {
 
-        double ratio;
-        double up   = static_cast<double>(SETTING(TOTAL_UPLOAD));
-        double down = static_cast<double>(SETTING(TOTAL_DOWNLOAD));
+        auto up    = SETTING(TOTAL_UPLOAD);
+        auto down  = SETTING(TOTAL_DOWNLOAD);
+        auto ratio = (down > 0) ? up / down : 0;
 
-        if (down > 0)
-            ratio = up / down;
-        else
-            ratio = 0;
         string upload = Util::formatBytes(up);
         string download = Util::formatBytes(down);
+
         map<string, xmlrpc_c::value> tmp_struct_in;
         tmp_struct_in["ratio"] = xmlrpc_c::value_string(Util::toString(ratio));
         tmp_struct_in["up"] = xmlrpc_c::value_string(upload);
         tmp_struct_in["down"] = xmlrpc_c::value_string(download);
+        tmp_struct_in["up_bytes"] = xmlrpc_c::value_string(Util::toString(up));
+        tmp_struct_in["down_bytes"] = xmlrpc_c::value_string(Util::toString(down));
         xmlrpc_c::value_struct const tmp_struct_out(tmp_struct_in);
         *retvalP = tmp_struct_out;
     }
@@ -379,7 +374,7 @@ public:
 
         string const ssearch(paramList.getString(0));
         paramList.verifyEnd(1);
-        if (ServerThread::getInstance()->sendSearchonHubs(ssearch, 0, 0, 0, 0, ""))
+        if (ServerThread::getInstance()->sendSearchOnHubs(ssearch, 0, 0, 0, 0, ""))
             *retvalP = xmlrpc_c::value_int(0);
         else
             *retvalP = xmlrpc_c::value_int(1);
@@ -417,13 +412,13 @@ public:
             xmlrpc_c::value *   const  retvalP) {
 
         string const shuburl(paramList.getString(0));
-        vector<StringMap> tmp;
-        ServerThread::getInstance()->returnSearchResults(tmp, shuburl);
+        vector<StringMap> hublist;
+        ServerThread::getInstance()->returnSearchResults(hublist, shuburl);
         vector<xmlrpc_c::value> tmp_array_in;
-        for (auto i = tmp.begin(); i != tmp.end(); ++i) {
+        for (const auto& hub : hublist) {
             map<string, xmlrpc_c::value> tmp_struct_in;
-            for (auto kk = (*i).begin(); kk != (*i).end(); ++kk) {
-                pair<string, xmlrpc_c::value> member(kk->first, xmlrpc_c::value_string(kk->second));
+            for (const auto& rearchresult : hub) {
+                pair<string, xmlrpc_c::value> member(rearchresult.first, xmlrpc_c::value_string(rearchresult.second));
                 tmp_struct_in.insert(member);
             }
             xmlrpc_c::value_struct const tmp_struct_out(tmp_struct_in);
@@ -529,10 +524,10 @@ public:
         unordered_map<string,StringMap> listqueue;
         ServerThread::getInstance()->listQueue(listqueue);
         map<string, xmlrpc_c::value> tmp_struct1_in;
-        for (auto i = listqueue.begin(); i != listqueue.end(); ++i) {
+        for (const auto& item : listqueue) {
             map<string, xmlrpc_c::value> tmp_struct2_in;
-            for (auto kk = (*i).second.begin(); kk != (*i).second.end(); ++kk) {
-                pair<string, xmlrpc_c::value> member2(kk->first, xmlrpc_c::value_string(kk->second));
+            for (const auto& parameter : item.second) {
+                pair<string, xmlrpc_c::value> member2(parameter.first, xmlrpc_c::value_string(parameter.second));
                 tmp_struct2_in.insert(member2);
             }
             xmlrpc_c::value_struct const tmp_struct2_out(tmp_struct2_in);
@@ -661,11 +656,11 @@ public:
         string const snick(paramList.getString(0));;
         string const shuburl(paramList.getString(1));;
         paramList.verifyEnd(2);
-        StringMap tmp;
-        if (ServerThread::getInstance()->getUserInfo(tmp, snick, shuburl)) {
+        StringMap params;
+        if (ServerThread::getInstance()->getUserInfo(params, snick, shuburl)) {
             map<string, xmlrpc_c::value> tmp_struct_in;
-            for (auto kk = tmp.begin(); kk != tmp.end(); ++kk) {
-                pair<string, xmlrpc_c::value> member(kk->first, xmlrpc_c::value_string(kk->second));
+            for (const auto& parameter : params) {
+                pair<string, xmlrpc_c::value> member(parameter.first, xmlrpc_c::value_string(parameter.second));
                 tmp_struct_in.insert(member);
             }
             xmlrpc_c::value_struct const tmp_struct_out(tmp_struct_in);
@@ -705,14 +700,14 @@ public:
         unordered_map<string,StringMap> listhubs;
         ServerThread::getInstance()->listHubsFullDesc(listhubs);
         map<string, xmlrpc_c::value> tmp_struct1_in;
-        for (auto i = listhubs.begin(); i != listhubs.end(); ++i) {
+        for (const auto& hub : listhubs) {
             map<string, xmlrpc_c::value> tmp_struct2_in;
-            for (auto kk = (*i).second.begin(); kk != (*i).second.end(); ++kk) {
-                pair<string, xmlrpc_c::value> member2(kk->first, xmlrpc_c::value_string(kk->second));
+            for (const auto& parameter : hub.second) {
+                pair<string, xmlrpc_c::value> member2(parameter.first, xmlrpc_c::value_string(parameter.second));
                 tmp_struct2_in.insert(member2);
             }
             xmlrpc_c::value_struct const tmp_struct2_out(tmp_struct2_in);
-            pair<string, xmlrpc_c::value> member1(i->first, xmlrpc_c::value_struct(tmp_struct2_out));
+            pair<string, xmlrpc_c::value> member1(hub.first, xmlrpc_c::value_struct(tmp_struct2_out));
             tmp_struct1_in.insert(member1);
         }
         xmlrpc_c::value_struct tmp_struct1_out(tmp_struct1_in);
