@@ -22,7 +22,7 @@ class ActionCustomizer :
 {
 Q_OBJECT
 public:
-    explicit ActionCustomizer(const QList<QAction*> &available, const QList<QAction*> &enabled, QWidget *parent = 0);
+    explicit ActionCustomizer(const QList<QAction*> &available, const QList<QAction*> &enabled, QWidget *parent = nullptr);
 
 Q_SIGNALS:
     void done(const QList<QAction*> &enabled);
@@ -32,7 +32,7 @@ private Q_SLOTS:
     void moveUp();
     void moveToEnabled();
     void moveToAvailable();
-    void accepted();
+    void actionAccepted();
 
 private:
     QMap<QListWidgetItem*, QAction*> enabled_items;
