@@ -17,18 +17,19 @@
 
 #include <QApplication>
 
-ArenaWidgetManager::ArenaWidgetManager() : QObject(NULL) {
+ArenaWidgetManager::ArenaWidgetManager() : QObject(nullptr) {
     DEBUG_BLOCK
 }
 
 ArenaWidgetManager::~ArenaWidgetManager(){
     DEBUG_BLOCK
 
-    disconnect(this, 0, 0, 0);
-    
-    foreach ( ArenaWidget *awgt , widgets ) {
-        if (!dynamic_cast<QObject*>(awgt))
+    disconnect(this, nullptr, nullptr, nullptr);
+
+    for (const auto &awgt : widgets) {
+        if (!dynamic_cast<QObject*>(awgt)){
             continue;
+        }
         if (dcpp::ISingleton *isingleton = dynamic_cast<dcpp::ISingleton*>(awgt)){
             isingleton->release();
         }
@@ -104,11 +105,11 @@ void ArenaWidgetManager::activate ( ArenaWidget *awgt ) {
     DEBUG_BLOCK
     
     if (!awgt){
-        emit activated(NULL);
+        emit activated(nullptr);
         return;
     }
     else if (!widgets.contains(awgt)){
-        emit activated(NULL);
+        emit activated(nullptr);
         return;
     }
     
