@@ -30,16 +30,14 @@
 #include "dcpp/ClientManager.h"
 #include "dcpp/User.h"
 
-#define _DEBUG_ 1
-
-#if _DEBUG_
+#if _DEBUG_QT_UI
 #include <QtDebug>
 #endif
 
 using namespace dcpp;
 
 class DownloadQueuePrivate {
-    typedef QMap<QString, QVariant> VarMap;
+    typedef QVariantMap VarMap;
     typedef QMap<QString, QMap<QString, QString> > SourceMap;
 
 public:
@@ -55,8 +53,8 @@ public:
     SourceMap badSources;
 };
 
-DownloadQueue::Menu::Menu(){
-    menu = new QMenu();
+DownloadQueue::Menu::Menu() : menu(new QMenu(nullptr))
+{
     QMenu *menu_magnet = new QMenu(tr("Magnet"), DownloadQueue::getInstance());
 
     QAction *search_alt  = new QAction(tr("Search for alternates"), menu);
@@ -130,6 +128,7 @@ DownloadQueue::Menu::Menu(){
 
 DownloadQueue::Menu::~Menu(){
     delete menu;
+    menu = nullptr;
 }
 
 void DownloadQueue::Menu::clearMenu(QMenu *m){
@@ -138,8 +137,9 @@ void DownloadQueue::Menu::clearMenu(QMenu *m){
 
     QList<QAction*> actions = m->actions();
 
-   foreach (QAction *a, actions)
+   for (const auto &a : actions) {
        m->removeAction(a);
+   }
 
    qDeleteAll(actions);
 }
@@ -158,11 +158,10 @@ DownloadQueue::Menu::Action DownloadQueue::Menu::exec(const DownloadQueue::Sourc
     rem_usr->setDisabled(multiselect);
 
     QMap<QString, QString>  users = sources[target];
-    auto it = users.constBegin();
 
-    for (; it != users.constEnd(); ++it){
-        QAction *act = new QAction(it.key(), menu);
-        act->setStatusTip(it.value());
+    for (const auto &key : users.keys()){
+        QAction *act = new QAction(key, menu);
+        act->setStatusTip(users[key]);
 
         browse->addAction(act);
         send_pm->addAction(act);
@@ -241,7 +240,7 @@ void DownloadQueue::requestDelete(){
 
     QList<DownloadQueueItem*> items;
 
-    foreach (const QModelIndex &i, list){
+    for (const auto &i : list){
         DownloadQueueItem *item = reinterpret_cast<DownloadQueueItem*>(i.internalPointer());
 
         if (!item)
@@ -254,7 +253,7 @@ void DownloadQueue::requestDelete(){
     }
 
     QueueManager *QM = QueueManager::getInstance();
-    foreach (DownloadQueueItem *i, items){
+    for (const auto &i : items){
         QString target = i->data(COLUMN_DOWNLOADQUEUE_PATH).toString() + i->data(COLUMN_DOWNLOADQUEUE_NAME).toString();
 
         try {
@@ -337,10 +336,8 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
 
     QStringList user_list;
 
-    QueueItem::SourceConstIter it = item->getSources().begin();
-
-    for (; it != item->getSources().end(); ++it){
-        HintedUser usr = it->getUser();
+    for (const auto &src : item->getSources()){
+        HintedUser usr = src.getUser();
         const dcpp::CID &cid = usr.user->getCID();
 
         if (usr.user->isOnline())
@@ -376,32 +373,30 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
 
     params["ERRORS"] = QString("");
 
-    it = item->getBadSources().begin();
-
-    for (; it != item->getBadSources().end(); ++it){
+    for (const auto &src : item->getBadSources()){
         QString errors = params["ERRORS"].toString();
-        UserPtr usr = it->getUser();
+        UserPtr usr = src.getUser();
 
         nick = WulforUtil::getInstance()->getNicks(usr->getCID());
         source[nick] = _q(usr->getCID().toBase32());
 
-        if (!it->isSet(QueueItem::Source::FLAG_REMOVED)){
+        if (!src.isSet(QueueItem::Source::FLAG_REMOVED)){
             if (!errors.isEmpty())
                 errors += ", ";
 
             errors += nick + " (";
 
-            if (it->isSet(QueueItem::Source::FLAG_FILE_NOT_AVAILABLE))
+            if (src.isSet(QueueItem::Source::FLAG_FILE_NOT_AVAILABLE))
                 errors += tr("File not available");
-            else if (it->isSet(QueueItem::Source::FLAG_PASSIVE))
+            else if (src.isSet(QueueItem::Source::FLAG_PASSIVE))
                 errors += tr("Passive user");
-            else if (it->isSet(QueueItem::Source::FLAG_CRC_FAILED))
+            else if (src.isSet(QueueItem::Source::FLAG_CRC_FAILED))
                 errors += tr("Checksum mismatch");
-            else if (it->isSet(QueueItem::Source::FLAG_BAD_TREE))
+            else if (src.isSet(QueueItem::Source::FLAG_BAD_TREE))
                 errors += tr("Full tree does not match TTH root");
-            else if (it->isSet(QueueItem::Source::FLAG_SLOW_SOURCE))
+            else if (src.isSet(QueueItem::Source::FLAG_SLOW_SOURCE))
                 errors += tr("Source too slow");
-            else if (it->isSet(QueueItem::Source::FLAG_NO_TTHF))
+            else if (src.isSet(QueueItem::Source::FLAG_NO_TTHF))
                 errors += tr("Remote client does not fully support TTH - cannot download");
 
             params["ERRORS"] = errors + ")";
@@ -421,15 +416,12 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
 QStringList DownloadQueue::getSources(){
     Q_D(DownloadQueue);
 
-    auto s_it = d->sources.begin();
     QStringList ret;
 
-    for (; s_it != d->sources.end(); ++s_it){
-        QString target = s_it.key();
+    for (const QString &target : d->sources.keys()){
         QString users;
-        auto it = s_it.value().begin();
 
-        for (; it != s_it.value().end(); ++it){
+        for (auto it = d->sources[target].begin(); it != d->sources[target].end(); ++it){
             users += it.key() + "(" + it.value() + ") ";
         }
 
@@ -469,8 +461,8 @@ void DownloadQueue::loadList(){
 
     const QueueItem::StringMap &ll = QueueManager::getInstance()->lockQueue();
 
-    for (auto it = ll.begin(); it != ll.end(); ++it){
-        getParams(params, it->second);
+    for (const auto &k : ll) {
+        getParams(params, k.second);
 
         addFile(params);
     }
@@ -532,7 +524,7 @@ void DownloadQueue::getChilds(DownloadQueueItem *i, QList<DownloadQueueItem *> &
     if (i->childCount() < 1)
         return;
 
-    foreach(DownloadQueueItem *ii, i->childItems)
+    for (const auto &ii : i->childItems)
         getChilds(ii, list);
 }
 
@@ -542,7 +534,7 @@ void DownloadQueue::getItems(const QModelIndexList &list, QList<DownloadQueueIte
     if (list.isEmpty())
         return;
 
-    foreach (const QModelIndex &i, list){
+    for (const auto &i : list){
         DownloadQueueItem *item = reinterpret_cast<DownloadQueueItem*>(i.internalPointer());
 
         getChilds(item, items);
@@ -588,7 +580,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         {
             SearchFrame *sf = ArenaWidgetFactory().create<SearchFrame>();
 
-            foreach (DownloadQueueItem *i, items)
+            for (const auto &i : items)
                 sf->searchAlternates(i->data(COLUMN_DOWNLOADQUEUE_TTH).toString());
 
             break;
@@ -597,9 +589,9 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         {
             QString magnet = "";
 
-            foreach (DownloadQueueItem *i, items)
+            for (const auto &i : items)
                 magnet += WulforUtil::getInstance()->makeMagnet(
-                        i->data(COLUMN_DOWNLOADQUEUE_NAME).toString(),
+                        i->data(COLUMN_DOWNLOADQUEUE_NAME).toString().trimmed(),
                         i->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong(),
                         i->data(COLUMN_DOWNLOADQUEUE_TTH).toString()) + "\n";
 
@@ -612,13 +604,14 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         {
             QString magnet = "";
 
-            foreach (DownloadQueueItem *i, items)
+            for (const auto &i : items){
                 magnet += "[magnet=\"" +
                     WulforUtil::getInstance()->makeMagnet(
-                        i->data(COLUMN_DOWNLOADQUEUE_NAME).toString(),
+                        i->data(COLUMN_DOWNLOADQUEUE_NAME).toString().trimmed(),
                         i->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong(),
                         i->data(COLUMN_DOWNLOADQUEUE_TTH).toString()) +
-                    "\"]"+i->data(COLUMN_DOWNLOADQUEUE_NAME).toString()+"[/magnet]\n";
+                    "\"]"+i->data(COLUMN_DOWNLOADQUEUE_NAME).toString().trimmed()+"[/magnet]\n";
+            }
 
             if (!magnet.isEmpty())
                 qApp->clipboard()->setText(magnet, QClipboard::Clipboard);
@@ -627,17 +620,15 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         }
         case Menu::MagnetInfo:
         {
-            QString magnet = "";
-
-            foreach (DownloadQueueItem *i, items){
-                magnet = WulforUtil::getInstance()->makeMagnet(
-                    i->data(COLUMN_DOWNLOADQUEUE_NAME).toString(),
-                    i->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong(),
-                    i->data(COLUMN_DOWNLOADQUEUE_TTH).toString()) + "\n";
+            for (const auto &i : items){
+                const QString &&magnet = WulforUtil::getInstance()->makeMagnet(
+                            i->data(COLUMN_DOWNLOADQUEUE_NAME).toString().trimmed(),
+                            i->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong(),
+                            i->data(COLUMN_DOWNLOADQUEUE_TTH).toString());
 
                 if (!magnet.isEmpty()){
                     Magnet m(this);
-                    m.setLink(magnet);
+                    m.setLink(magnet, Magnet::MAGNET_ACTION_SHOW_UI);
                     m.exec();
                 }
             }
@@ -646,7 +637,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         }
         case Menu::RenameMove:
         {
-            foreach (DownloadQueueItem *i, items){
+            for (const auto &i : items){
                 QString target = i->data(COLUMN_DOWNLOADQUEUE_PATH).toString() +
                                  i->data(COLUMN_DOWNLOADQUEUE_NAME).toString();
                 QString new_target = QFileDialog::getSaveFileName(this, tr("Choose filename"), target, tr("All files (*.*)"));
@@ -664,7 +655,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         }
         case Menu::SetPriority:
         {
-            foreach (DownloadQueueItem *i, items){
+            for (const auto &i : items){
                 QString target = i->data(COLUMN_DOWNLOADQUEUE_PATH).toString() + i->data(COLUMN_DOWNLOADQUEUE_NAME).toString();
 
                 try {
@@ -701,7 +692,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
             QString nick = ((++it).key());
             QList<QObject*> list = HubManager::getInstance()->getHubs();
 
-            foreach (QObject *obj, list){
+            for (const auto &obj : list){
                 HubFrame *fr = qobject_cast<HubFrame*>(obj);
 
                 if (!fr)
@@ -754,7 +745,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
         }
         case Menu::Remove:
         {
-            foreach (DownloadQueueItem *i, items){
+            for (const auto &i : items){
                 QString target = i->data(COLUMN_DOWNLOADQUEUE_PATH).toString() + i->data(COLUMN_DOWNLOADQUEUE_NAME).toString();
 
                 try {
@@ -793,6 +784,7 @@ void DownloadQueue::slotUpdateStats(quint64 files, quint64 size){
 }
 
 void DownloadQueue::slotSettingsChanged(const QString &key, const QString &value){
+    Q_UNUSED(value)
     if (key == WS_TRANSLATION_FILE)
         retranslateUi(this);
 }
