@@ -10,7 +10,12 @@
 #include "DownloadQueueModel.h"
 #include "WulforUtil.h"
 
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
+
 #include <QFileInfo>
 #include <QList>
 #include <QStringList>
@@ -25,22 +30,20 @@
 #include <dcpp/stdinc.h>
 #include <dcpp/QueueManager.h>
 
-#define _DEBUG_ 1
-
-#if _DEBUG_
+#if _DEBUG_QT_UI
 #include <QtDebug>
 #endif
 
 #include <set>
 
-#if _DEBUG_
+#if _DEBUG_QT_UI
 static inline void printRoot(DownloadQueueItem *i, const QString &dlmtr){
     if (!i)
         return;
 
-    qDebug() << dlmtr.toAscii().constData() << i->data(COLUMN_DOWNLOADQUEUE_NAME).toString().toAscii().constData();
+	qDebug() << dlmtr.toUtf8().constData() << i->data(COLUMN_DOWNLOADQUEUE_NAME).toString().toUtf8().constData();
 
-    foreach (DownloadQueueItem *child, i->childItems)
+    for (const auto &child : i->childItems)
         printRoot(child, dlmtr + "-");
 }
 #endif
@@ -75,9 +78,9 @@ DownloadQueueModel::DownloadQueueModel(QObject *parent)
     QList<QVariant> rootData;
     rootData << tr("Name") << tr("Status") << tr("Size") << tr("Downloaded")
              << tr("Priority") << tr("User") << tr("Path") << tr("Exact size")
-             << tr("Errors") << tr("Added") << tr("TTH");
+             << tr("Errors") << tr("Added") << QString("TTH");
 
-    d->rootItem = new DownloadQueueItem(rootData, NULL);
+    d->rootItem = new DownloadQueueItem(rootData, nullptr);
 
     d->sortColumn = COLUMN_DOWNLOADQUEUE_NAME;
     d->sortOrder = Qt::DescendingOrder;
@@ -207,7 +210,7 @@ struct Compare {
         if (column > COLUMN_DOWNLOADQUEUE_TTH)
             return;
 
-        qStableSort(items.begin(), items.end(), attrs[column]);
+        std::stable_sort(items.begin(), items.end(), attrs[column]);
     }
 
     void static insertSorted(unsigned column, QList<DownloadQueueItem*>& items, DownloadQueueItem* item) {
@@ -217,7 +220,7 @@ struct Compare {
             return;
         }
 
-        auto it = qLowerBound(items.begin(),
+        auto it = std::lower_bound(items.begin(),
                                                              items.end(),
                                                              item,
                                                              attrs[column]
@@ -277,7 +280,7 @@ QVariant DownloadQueueModel::headerData(int section, Qt::Orientation orientation
     QList<QVariant> rootData;
     rootData << tr("Name") << tr("Status") << tr("Size") << tr("Downloaded")
              << tr("Priority") << tr("User") << tr("Path") << tr("Exact size")
-             << tr("Errors") << tr("Added") << tr("TTH");
+             << tr("Errors") << tr("Added") << QString("TTH");
 
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole)
         return rootData.at(section);
@@ -350,7 +353,7 @@ static void sortRecursive(int column, Qt::SortOrder order, DownloadQueueItem *i)
     else if (order == Qt::DescendingOrder)
         dcomp.sort(column, i->childItems);
 
-    foreach(DownloadQueueItem *ii, i->childItems)
+    for (const auto &ii : i->childItems)
         sortRecursive(column, order, ii);
 }
 
@@ -370,15 +373,15 @@ void DownloadQueueModel::sort(int column, Qt::SortOrder order) {
     emit layoutChanged();
 }
 
-DownloadQueueItem *DownloadQueueModel::addItem(const QMap<QString, QVariant> &map){
+DownloadQueueItem *DownloadQueueModel::addItem(const QVariantMap &map){
     static quint64 counter = 0;
 
     DownloadQueueItem *droot = createPath(map["PATH"].toString());
 
     if (!droot)
-        return NULL;
+        return nullptr;
 
-    DownloadQueueItem *child = NULL;
+    DownloadQueueItem *child = nullptr;
     QList<QVariant> childData;
 
     childData << map["FNAME"]
@@ -413,7 +416,7 @@ DownloadQueueItem *DownloadQueueModel::addItem(const QMap<QString, QVariant> &ma
     return child;
 }
 
-void DownloadQueueModel::updItem(const QMap<QString, QVariant> &map){
+void DownloadQueueModel::updItem(const QVariantMap &map){
     DownloadQueueItem *item = createPath(map["PATH"].toString());
     Q_D(static DownloadQueueModel);
 
@@ -441,8 +444,8 @@ void DownloadQueueModel::updItem(const QMap<QString, QVariant> &map){
     emit layoutChanged();
 }
 
-bool DownloadQueueModel::remItem(const QMap<QString, QVariant> &map){
-    DownloadQueueItem *item = createPath(map["PATH"].toString());;
+bool DownloadQueueModel::remItem(const QVariantMap &map){
+    DownloadQueueItem *item = createPath(map["PATH"].toString());
 
     if (item->childItems.size() < 1)
         return false;
@@ -472,9 +475,9 @@ bool DownloadQueueModel::remItem(const QMap<QString, QVariant> &map){
     else {
 
         DownloadQueueItem *p = item;
-        DownloadQueueItem *_t = NULL;
+        DownloadQueueItem *_t = nullptr;
 
-        while (true){
+        while (true) {
             if ((p == d->rootItem) || (p->childCount() > 1) || !p->parent())
                 break;
 
@@ -500,22 +503,6 @@ bool DownloadQueueModel::remItem(const QMap<QString, QVariant> &map){
     return true;
 }
 
-void DownloadQueueModel::setRootElem(DownloadQueueItem *root, bool del_old, bool controlNull){
-    if (controlNull && !root)
-        return;
-
-    Q_D(DownloadQueueModel);
-
-    if (del_old && root != d->rootItem){//prevent deleting own root element
-        delete d->rootItem;
-
-        d->rootItem = NULL;
-    }
-
-    if (d->rootItem == root)
-        emit layoutChanged();
-}
-
 DownloadQueueItem *DownloadQueueModel::getRootElem() const{
     Q_D(const DownloadQueueModel);
 
@@ -566,7 +553,7 @@ DownloadQueueItem *DownloadQueueModel::createPath(const QString & path){
     Q_D(static DownloadQueueModel);
 
     if (!d->rootItem)
-        return NULL;
+        return nullptr;
 
     QString _path = path;
     _path.replace("\\", "/");
@@ -580,7 +567,7 @@ DownloadQueueItem *DownloadQueueModel::createPath(const QString & path){
     for (int i = 0; i < list.size(); i++){
         found = false;
 
-        foreach(DownloadQueueItem *item, root->childItems){
+        for (const auto &item : root->childItems){
             if (!item->dir)
                 continue;
 
@@ -638,9 +625,9 @@ void DownloadQueueModel::repaint(){
 }
 
 DownloadQueueItem *DownloadQueueModel::findTarget(const DownloadQueueItem *item, const QString &name){
-    DownloadQueueItem *target = NULL;
+    DownloadQueueItem *target = nullptr;
 
-    foreach(DownloadQueueItem *i, item->childItems){
+    for (const auto &i : item->childItems){
         if (i->data(COLUMN_DOWNLOADQUEUE_NAME).toString() == name){
             target = i;
 
@@ -651,28 +638,31 @@ DownloadQueueItem *DownloadQueueModel::findTarget(const DownloadQueueItem *item,
     return target;
 }
 
-DownloadQueueItem::DownloadQueueItem(const QList<QVariant> &data, DownloadQueueItem *parent) :
-    dir(false), itemData(data), parentItem(parent)
+DownloadQueueItem::DownloadQueueItem(const QList<QVariant> &data, DownloadQueueItem *parent)
+    : dir(false)
+    , itemData(data)
+    , parentItem(parent)
 {
 }
 
-DownloadQueueItem::DownloadQueueItem(const DownloadQueueItem &item){
-    itemData = item.itemData;
-    dir = item.dir;
-    parentItem = NULL;
-    childItems = QList<DownloadQueueItem*> ();
+DownloadQueueItem::DownloadQueueItem(const DownloadQueueItem &in)
+    : dir(in.dir)
+    , itemData(in.itemData)
+    , parentItem(nullptr)
+{
 }
-void DownloadQueueItem::operator=(const DownloadQueueItem &item){
-    parentItem = item.parentItem;
-    childItems = item.childItems;
-    itemData = item.itemData;
-    dir = item.dir;
+
+void DownloadQueueItem::operator=(const DownloadQueueItem &in){
+    parentItem = in.parentItem;
+    childItems = in.childItems;
+    itemData = in.itemData;
+    dir = in.dir;
 }
 
 DownloadQueueItem::~DownloadQueueItem()
 {
-    if (!childItems.isEmpty())
-        qDeleteAll(childItems);
+    qDeleteAll(childItems);
+    childItems.clear();
 }
 
 void DownloadQueueItem::appendChild(DownloadQueueItem *item) {
@@ -717,10 +707,10 @@ void DownloadQueueItem::updateColumn(int column, QVariant var){
 
 DownloadQueueItem *DownloadQueueItem::nextSibling(){
     if (!parent())
-        return NULL;
+        return nullptr;
 
     if (row() == (parent()->childCount()-1))
-        return NULL;
+        return nullptr;
 
     return parent()->child(row()+1);
 }
@@ -740,7 +730,20 @@ void DownloadQueueDelegate::paint(QPainter *painter, const QStyleOptionViewItem
         return;
     }
 
-    QStyleOptionProgressBarV2 progressBarOption;
+    DownloadQueueItem *item = reinterpret_cast<DownloadQueueItem*>(index.internalPointer());
+
+    if (!item || item->dir) {
+        QStyledItemDelegate::paint(painter, option, index);
+        return;
+    }
+
+#if defined(USE_PROGRESS_BARS)
+    const qulonglong esize = item->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong();
+    double percent = ((double)item->data(COLUMN_DOWNLOADQUEUE_DOWN).toLongLong() * 100.0);
+    percent = (esize > 0) ? (percent/(double)esize) : 0.0;
+    const QString status = QString("%1%").arg(percent, 0, 'f', 1);
+
+    QStyleOptionProgressBar progressBarOption;
     progressBarOption.state = QStyle::State_Enabled;
     progressBarOption.direction = QApplication::layoutDirection();
     progressBarOption.rect = option.rect;
@@ -749,21 +752,6 @@ void DownloadQueueDelegate::paint(QPainter *painter, const QStyleOptionViewItem
     progressBarOption.maximum = 100;
     progressBarOption.textAlignment = Qt::AlignCenter;
     progressBarOption.textVisible = true;
-
-    DownloadQueueItem *item = reinterpret_cast<DownloadQueueItem*>(index.internalPointer());
-
-    if (!item || item->dir){
-        QStyledItemDelegate::paint(painter, option, index);
-        return;
-    }
-
-    qulonglong esize = item->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong();
-    double percent = ((double)item->data(COLUMN_DOWNLOADQUEUE_DOWN).toLongLong() * 100.0);
-
-    percent = esize > 0? (percent/(double)esize) : 0.0;
-
-    QString status = QString("%1%").arg(percent, 0, 'f', 1);
-
     progressBarOption.text = status;
     progressBarOption.progress = static_cast<int>(percent);
 
@@ -771,4 +759,16 @@ void DownloadQueueDelegate::paint(QPainter *painter, const QStyleOptionViewItem
         painter->fillRect(option.rect, option.palette.highlight());
 
     QApplication::style()->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
+#else
+    const qulonglong esize = item->data(COLUMN_DOWNLOADQUEUE_ESIZE).toLongLong();
+    double percent = ((double)item->data(COLUMN_DOWNLOADQUEUE_DOWN).toLongLong() * 100.0);
+    percent = (esize > 0) ? (percent/(double)esize) : 0.0;
+    const QString status = QString("%1%").arg(percent, 0, 'f', 1);
+
+    QStyleOptionViewItem plainTextOption = option;
+    plainTextOption.text = status;
+    plainTextOption.displayAlignment = Qt::AlignCenter;
+
+    QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &plainTextOption, painter);
+#endif
 }
