@@ -9,6 +9,7 @@
 
 #include "EmoticonFactory.h"
 #include "WulforSettings.h"
+#include "WulforUtil.h"
 
 #include <QDir>
 #include <QFile>
@@ -19,27 +20,13 @@
 
 #include <math.h>
 
-#ifndef CLIENT_ICONS_DIR
-#define CLIENT_ICONS_DIR ""
-#endif
-
 static const QString EmoticonSectionName = "emoticons-map";
 static const QString EmoticonSubsectionName = "emoticon";
 static const QString EmoticonTextSectionName = "name";
 
-#if !defined (Q_WS_WIN)
-static const QString EmotionPath = CLIENT_DATA_DIR "/emoticons/";
-#else
-static QString EmotionPath = "";
-#endif
-
 EmoticonFactory::EmoticonFactory() :
-    QObject(NULL)
+    QObject(nullptr)
 {
-#if defined (Q_WS_WIN)
-    EmotionPath = qApp->applicationDirPath() + QDir::separator() + CLIENT_DATA_DIR "/emoticons/";
-#endif
-    currentTheme = "";
 }
 
 EmoticonFactory::~EmoticonFactory(){
@@ -47,15 +34,15 @@ EmoticonFactory::~EmoticonFactory(){
 }
 
 void EmoticonFactory::load(){
-    QString emoTheme = WSGET(WS_APP_EMOTICON_THEME, "default");
+    const QString emoTheme = WSGET(WS_APP_EMOTICON_THEME, "default");
 
     if (emoTheme.isEmpty() || (currentTheme == emoTheme))
         return;
 
-    if (!QDir(EmotionPath+emoTheme).exists())
+    if (!QDir(WulforUtil::getInstance()->getEmoticonsPath() + emoTheme).exists())
         return;
 
-    QString xmlFile = EmotionPath+emoTheme+".xml";
+    const QString xmlFile = WulforUtil::getInstance()->getEmoticonsPath() + emoTheme + ".xml";
 
     if (!QFile::exists(xmlFile))
         return;
@@ -79,9 +66,9 @@ void EmoticonFactory::load(){
 
     f.close();
 
-    foreach(QTextDocument *d, docs)
+    for (const auto &d : docs)
         addEmoticons(d);
-    
+
     currentTheme = emoTheme;
 }
 
@@ -91,7 +78,7 @@ void EmoticonFactory::addEmoticons(QTextDocument *to){
 
     QString emoTheme = WSGET(WS_APP_EMOTICON_THEME);
 
-    foreach(EmoticonObject *i, list){
+    for (const auto &i : list){
         to->addResource( QTextDocument::ImageResource,
                          QUrl(emoTheme + "/emoticon" + QString().setNum(i->id)),
                          i->pixmap.toImage()
@@ -221,7 +208,7 @@ void EmoticonFactory::createEmoticonMap(const QDomNode &root){
 
     clear();
 
-    foreach(QDomNode node, emoNodes){
+    for (const auto &node : emoNodes){
         QString emoTheme = WSGET(WS_APP_EMOTICON_THEME);
 
         EmoticonObject *emot = new EmoticonObject();
@@ -230,7 +217,8 @@ void EmoticonFactory::createEmoticonMap(const QDomNode &root){
         emot->fileName  = el.attribute("file").toUtf8();
         emot->id        = list.size();
         emot->pixmap    = QPixmap();
-        emot->pixmap.load(EmotionPath+emoTheme+QDir::separator()+emot->fileName);
+        emot->pixmap.load(WulforUtil::getInstance()->getEmoticonsPath() +
+                          emoTheme + QDir::separator() + emot->fileName);
 
         DomNodeList emoTexts;
         getSubSectionsByName(node, emoTexts, EmoticonTextSectionName);
@@ -242,7 +230,7 @@ void EmoticonFactory::createEmoticonMap(const QDomNode &root){
         }
 
         int registered = 0;
-        foreach (QDomNode node, emoTexts){
+        for (const auto &node : emoTexts){
             QDomElement el = node.toElement();
 
             if (el.isNull())
@@ -276,7 +264,7 @@ void EmoticonFactory::fillLayout(QLayout *l, QSize &recommendedSize){
         return;
     }
 
-    foreach (EmoticonObject *i, list){
+    for (const auto &i : list){
         EmoticonLabel *lbl = new EmoticonLabel();
 
         lbl->setPixmap(i->pixmap);
@@ -323,6 +311,8 @@ QDomNode EmoticonFactory::findSectionByName(const QDomNode &node, const QString
     return QDomNode();
 }
 void EmoticonFactory::getSubSectionsByName(const QDomNode &node, EmoticonFactory::DomNodeList &list, const QString &name){
+    Q_UNUSED(name)
+
     QDomNode domNode = node.firstChild();
 
     while (!domNode.isNull()){
