@@ -40,7 +40,7 @@ using namespace dcpp;
 
 class FinishedTransferProxy: public QWidget{
 Q_OBJECT
-typedef QMap<QString, QVariant> VarMap;
+typedef QVariantMap VarMap;
 public:
     FinishedTransferProxy(QWidget *parent):QWidget(parent){}
     ~FinishedTransferProxy(){}
@@ -76,14 +76,14 @@ class FinishedTransfers :
 {
 Q_INTERFACES(ArenaWidget)
 
-typedef QMap<QString, QVariant> VarMap;
+typedef QVariantMap VarMap;
 friend class dcpp::Singleton< FinishedTransfers<isUpload> >;
 
 public:
     QWidget *getWidget() { return this;}
     QString getArenaTitle(){ return (isUpload? uploadTitle() : downloadTitle()); }
     QString getArenaShortTitle(){ return getArenaTitle(); }
-    QMenu *getMenu() { return NULL; }
+    QMenu *getMenu() { return nullptr; }
     ArenaWidget::Role role() const;
 
     const QPixmap &getPixmap(){
@@ -99,7 +99,7 @@ protected:
     }
 
 private:
-    FinishedTransfers(QWidget *parent = NULL) :
+    FinishedTransfers(QWidget *parent = nullptr) :
         FinishedTransferProxy(parent), db_opened(false)
     {
         setupUi(this);
@@ -126,6 +126,8 @@ private:
 
             q.exec("CREATE TABLE IF NOT EXISTS users (NICK TEXT PRIMARY KEY, "
                    "TIME TEXT, FILES TEXT, TR TEXT, SPEED TEXT, CID TEXT, ELAP TEXT, FULL INTEGER);");
+
+            q.exec("VACUUM;");
         }
 #endif
 
@@ -153,8 +155,8 @@ private:
         QObject::connect(treeView->header(), SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotHeaderMenu()));
         QObject::connect(checkBox_FULL, SIGNAL(toggled(bool)), this, SLOT(slotSwitchOnlyFull(bool)));
 
-        slotSwitchOnlyFull(false);
-        slotTypeChanged(0);
+        FinishedTransfers::slotSwitchOnlyFull(false);
+        FinishedTransfers::slotTypeChanged(0);
 
         ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
     }
@@ -178,15 +180,11 @@ private:
     void loadList(){
         VarMap params;
 
-#ifdef DO_NOT_USE_MUTEX
-        FinishedManager::getInstance()->lockLists();
-#else // DO_NOT_USE_MUTEX
-        auto lock = FinishedManager::getInstance()->lockLists();
-#endif // DO_NOT_USE_MUTEX
+        auto lock = FinishedManager::getInstance()->lock();
         const FinishedManager::MapByFile &list = FinishedManager::getInstance()->getMapByFile(isUpload);
         const FinishedManager::MapByUser &user = FinishedManager::getInstance()->getMapByUser(isUpload);
 
-        for (auto it = list.begin(); it != list.end(); ++it){
+        for (auto it = list.begin(); it != list.end(); ++it) {
             params.clear();
 
             getParams(it->second, it->first, params);
@@ -194,18 +192,14 @@ private:
             model->addFile(params);
         }
 
-        for (auto uit = user.begin(); uit != user.end(); ++uit){
+        for (auto uit = user.begin(); uit != user.end(); ++uit) {
             params.clear();
 
             getParams(uit->second, uit->first, params);
 
-            model->addUser(params);;
+            model->addUser(params);
         }
 
-#ifdef DO_NOT_USE_MUTEX
-        FinishedManager::getInstance()->unlockLists();
-#endif // DO_NOT_USE_MUTEX
-
         AsyncRunner *runner = new AsyncRunner(this);
 
         runner->setRunFunction([this]() { this->loadListFromDB(); });
@@ -277,8 +271,9 @@ private:
         params["TIME"]  = _q(Util::formatTime("%Y-%m-%d %H:%M:%S", item->getTime()));
         params["PATH"]  = _q(Util::getFilePath(file));
 
-        for (auto it = item->getUsers().begin(); it != item->getUsers().end(); ++it)
-                nicks += WulforUtil::getInstance()->getNicks(it->user->getCID()) + " ";
+        for (const auto &user : item->getUsers()) {
+            nicks += WulforUtil::getInstance()->getNicks(user.user->getCID()) + " ";
+        }
 
         params["USERS"] = nicks;
         params["TR"]    = (qlonglong)item->getTransferred();
@@ -317,8 +312,9 @@ private:
         params["TIME"]  = _q(Util::formatTime("%Y-%m-%d %H:%M:%S", item->getTime()));
         params["NICK"]  = WulforUtil::getInstance()->getNicks(user->getCID());
 
-        for (auto it = item->getFiles().begin(); it != item->getFiles().end(); ++it)
-                files += _q(*it) + " ";
+        for (const auto &file: item->getFiles()) {
+                files += _q(file) + " ";
+        }
 
         params["FILES"] = files;
         params["TR"]    = (qlonglong)item->getTransferred();
@@ -387,7 +383,7 @@ private:
     }
 
     void openFile(QString file){
-        if (!file.startsWith("/"))
+        if (!file.startsWith(QChar('/')))
             file.prepend("/");
 
         int sep = file.lastIndexOf(QDir::separator());
@@ -402,12 +398,7 @@ private:
                 file = path + QDir::separator() + files.first();
         }
 
-        if (file.startsWith("/"))
-            file.prepend("file://");
-        else
-            file.prepend("file:///");
-
-        QDesktopServices::openUrl(QUrl(file));
+        QDesktopServices::openUrl(QUrl::fromLocalFile(file));
     }
 
     void slotItemDoubleClicked(const QModelIndex &proxyIndex){
@@ -420,18 +411,18 @@ private:
         QModelIndexList p_indexes = s_model->selectedRows(0);
         QModelIndexList indexes;
 
-        foreach (const QModelIndex &i, p_indexes)
+        for (const auto &i : p_indexes)
             indexes.push_back(proxy->mapToSource(i));
 
         if (indexes.size() < 1)
             return;
 
         QStringList files;
-        FinishedTransfersItem *item = NULL;
+        FinishedTransfersItem *item = nullptr;
         QString file;
         bool full;
 
-        foreach (const QModelIndex &i, indexes){
+        for (const auto &i : indexes){
             item = reinterpret_cast<FinishedTransfersItem*>(i.internalPointer());
             file = item->data(COLUMN_FINISHED_TARGET).toString();
             full = item->data(COLUMN_FINISHED_FULL).toBool();
@@ -440,7 +431,7 @@ private:
                 files.push_back(file);
         }
 
-        foreach (QString f, files)
+        for (const auto &f : files)
             openFile(f);
     }
 
@@ -451,7 +442,7 @@ private:
         QModelIndexList p_indexes = s_model->selectedRows(0);
         QModelIndexList indexes;
 
-        foreach (const QModelIndex &i, p_indexes)
+        for (const auto &i : p_indexes)
             indexes.push_back(proxy->mapToSource(i));
 
         if (indexes.size() < 1)
@@ -460,10 +451,10 @@ private:
         QStringList files;
 
         if (comboBox->currentIndex() == 0){
-            FinishedTransfersItem *item = NULL;
+            FinishedTransfersItem *item = nullptr;
             QString file;
 
-            foreach (const QModelIndex &i, indexes){
+            for (const auto &i : indexes){
                 item = reinterpret_cast<FinishedTransfersItem*>(i.internalPointer());
                 file = item->data(COLUMN_FINISHED_TARGET).toString();
 
@@ -472,10 +463,10 @@ private:
             }
         }
         else {
-            FinishedTransfersItem *item = NULL;
+            FinishedTransfersItem *item = nullptr;
             QString file_list;
 
-            foreach (const QModelIndex &i, indexes){
+            for (const auto &i : indexes){
                 item = reinterpret_cast<FinishedTransfersItem*>(i.internalPointer());
                 file_list = item->data(COLUMN_FINISHED_PATH).toString();
 
@@ -498,14 +489,14 @@ private:
         delete m;
 
         if (ret == open_f){
-            foreach (QString f, files)
+            for (const auto &f : files)
                 openFile(f);
         }
         else if (ret == open_dir){
-            foreach (QString f, files){
+            for (auto &f : files){
                 f = f.left(f.lastIndexOf(QDir::separator())) + QDir::separator();
 
-                if (f.startsWith("/"))
+                if (f.startsWith(QChar('/')))
                     f.prepend("file://");
                 else
                     f.prepend("file:///");
