@@ -9,7 +9,12 @@
 
 #include "FinishedTransfersModel.h"
 
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
+
 #include <QFileInfo>
 #include <QList>
 #include <QStringList>
@@ -27,17 +32,12 @@
 #include "dcpp/CID.h"
 #include "dcpp/ShareManager.h"
 
-//#define _DEBUG_MODEL_
-
-
-#include <QtDebug>
-
-using namespace dcpp;
-
-#ifdef _DEBUG_MODEL_
+#ifdef _DEBUG_QT_UI
 #include <QtDebug>
 #endif
 
+using namespace dcpp;
+
 FinishedTransfersModel::FinishedTransfersModel(QObject *parent):
         QAbstractItemModel(parent), sortColumn(0), sortOrder(Qt::AscendingOrder)
 {
@@ -152,7 +152,7 @@ QVariant FinishedTransfersModel::data(const QModelIndex &index, int role) const
 Qt::ItemFlags FinishedTransfersModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
@@ -188,6 +188,7 @@ QModelIndex FinishedTransfersModel::index(int row, int column, const QModelIndex
 
 QModelIndex FinishedTransfersModel::parent(const QModelIndex &index) const
 {
+    Q_UNUSED(index)
     return QModelIndex();
 }
 
@@ -210,11 +211,11 @@ namespace {
 template <Qt::SortOrder order>
 struct FileCompare {
     void static sort(int col, QList<FinishedTransfersItem*>& items) {
-        qStableSort(items.begin(), items.end(), getAttrComp(col));
+        std::stable_sort(items.begin(), items.end(), getAttrComp(col));
     }
 
     void static insertSorted(int col, QList<FinishedTransfersItem*>& items, FinishedTransfersItem* item) {
-        auto it = qLowerBound(items.begin(), items.end(), item, getAttrComp(col));
+        auto it = std::lower_bound(items.begin(), items.end(), item, getAttrComp(col));
         items.insert(it, item);
     }
 
@@ -244,7 +245,7 @@ struct FileCompare {
                     return NumCmp<COLUMN_FINISHED_ELAPS>;
             }
 
-            return NULL;
+            return nullptr;
         }
         template <int i>
         bool static AttrCmp(const FinishedTransfersItem * l, const FinishedTransfersItem * r) {
@@ -275,11 +276,11 @@ bool inline FileCompare<Qt::DescendingOrder>::Cmp(const T& l, const T& r) {
 template <Qt::SortOrder order>
 struct UserCompare {
     void static sort(int col, QList<FinishedTransfersItem*>& items) {
-        qStableSort(items.begin(), items.end(), getAttrComp(col));
+        std::stable_sort(items.begin(), items.end(), getAttrComp(col));
     }
 
     void static insertSorted(int col, QList<FinishedTransfersItem*>& items, FinishedTransfersItem* item) {
-        auto it = qLowerBound(items.begin(), items.end(), item, getAttrComp(col));
+        auto it = std::lower_bound(items.begin(), items.end(), item, getAttrComp(col));
         items.insert(it, item);
     }
 
@@ -303,7 +304,7 @@ struct UserCompare {
                     return AttrCmp<COLUMN_FINISHED_ELAPS>;
             }
 
-            return NULL;
+            return nullptr;
         }
         template <int i>
         bool static AttrCmp(const FinishedTransfersItem * l, const FinishedTransfersItem * r) {
@@ -370,7 +371,7 @@ void FinishedTransfersModel::clearModel(){
     endResetModel();
 }
 
-void FinishedTransfersModel::addFile(const QMap<QString, QVariant> &params){
+void FinishedTransfersModel::addFile(const QVariantMap &params){
     FinishedTransfersItem *item = findFile(params["TARGET"].toString());
 
     if (!item)
@@ -384,7 +385,7 @@ void FinishedTransfersModel::addFile(const QMap<QString, QVariant> &params){
             if (users.isEmpty())
                 continue;
             else{
-                foreach (QString nick, users){
+                for (const auto nick : users){
                     if (!old_users.contains(nick))
                         old_users.push_back(nick);
                 }
@@ -399,7 +400,7 @@ void FinishedTransfersModel::addFile(const QMap<QString, QVariant> &params){
     emit dataChanged(createIndex(item->row(), COLUMN_FINISHED_NAME, item), createIndex(item->row(), COLUMN_FINISHED_FULL, item));
 }
 
-void FinishedTransfersModel::addUser(const QMap<QString, QVariant> &params){
+void FinishedTransfersModel::addUser(const QVariantMap &params){
     FinishedTransfersItem *item = findUser(params["CID"].toString());
 
     if (!item)
@@ -471,7 +472,7 @@ void FinishedTransfersModel::switchViewType(FinishedTransfersModel::ViewType t){
 
 FinishedTransfersItem *FinishedTransfersModel::findFile(const QString &fname){
     if (fname.isEmpty())
-        return NULL;
+        return nullptr;
 
     auto it = file_hash.find(fname);
 
@@ -502,7 +503,7 @@ FinishedTransfersItem *FinishedTransfersModel::findFile(const QString &fname){
 
 FinishedTransfersItem *FinishedTransfersModel::findUser(const QString &cid){
     if (cid.isEmpty())
-        return NULL;
+        return nullptr;
 
     auto it = user_hash.find(cid);
 
@@ -544,6 +545,7 @@ FinishedTransfersItem::FinishedTransfersItem(const QList<QVariant> &data, Finish
 FinishedTransfersItem::~FinishedTransfersItem()
 {
     qDeleteAll(childItems);
+    childItems.clear();
 }
 
 void FinishedTransfersItem::appendChild(FinishedTransfersItem *item) {
@@ -551,7 +553,7 @@ void FinishedTransfersItem::appendChild(FinishedTransfersItem *item) {
 }
 
 FinishedTransfersItem *FinishedTransfersItem::child(int row) {
-    return ((row >= 0 && row <= childItems.count()-1)? childItems.value(row) : NULL);
+    return ((row >= 0 && row <= childItems.count()-1)? childItems.value(row) : nullptr);
 }
 
 int FinishedTransfersItem::childCount() const {
