@@ -11,7 +11,7 @@
 
 #include <QTimer>
 
-GlobalTimer::GlobalTimer() : QObject(NULL), timer(new QTimer()), tickCount(0) {
+GlobalTimer::GlobalTimer() : QObject(nullptr), timer(new QTimer()), tickCount(0) {
     timer->setInterval(1000);
     timer->setSingleShot(false);
     
@@ -23,7 +23,7 @@ GlobalTimer::GlobalTimer() : QObject(NULL), timer(new QTimer()), tickCount(0) {
 GlobalTimer::~GlobalTimer() {
     timer->stop();
 
-    disconnect(this, 0, 0, 0);
+    disconnect(this, nullptr, nullptr, nullptr);
 }
 
 void GlobalTimer::slotTick() {
@@ -31,7 +31,7 @@ void GlobalTimer::slotTick() {
     
     emit second();
     
-    if (tickCount % 60 == 0)
+    if ((tickCount % 60) == 0)
         emit minute();
 }
 
