@@ -21,6 +21,7 @@
 #include <QSortFilterProxyModel>
 #include <QCompleter>
 #include <QMetaType>
+#include <QTextBlockUserData>
 
 #include "ui_HubFrame.h"
 
@@ -29,7 +30,6 @@
 #include "dcpp/ClientListener.h"
 #include "dcpp/ClientManager.h"
 #include "dcpp/ClientManagerListener.h"
-#include "dcpp/TaskQueue.h"
 #include "dcpp/User.h"
 #include "dcpp/Client.h"
 #include "dcpp/FavoriteManagerListener.h"
@@ -43,6 +43,13 @@ class HubFramePrivate;
 
 using namespace dcpp;
 
+class UserListUserData : public QTextBlockUserData
+{
+public:
+    UserListUserData(const QString& nick) : data(nick) { }
+    QString data;
+};
+
 class HubFrame :
         public  QWidget,
         private Ui::UIHubFrame,
@@ -83,9 +90,11 @@ class HubFrame :
             None,
 
             /** Additional actions for userlist */
+            CopyComment,
             CopyIP,
             CopyShare,
             CopyTag,
+            CopyEmail,
 
             /** Additional actions for AntiSpam */
             AntiSpamWhite,
@@ -95,6 +104,9 @@ class HubFrame :
         Menu();
         virtual ~Menu();
 
+        Menu(const Menu&) = delete;
+        Menu& operator=(const Menu&) = delete;
+
         static void newInstance();
         static void deleteInstance();
         static Menu *getInstance();
@@ -125,12 +137,15 @@ public:
     };
 
     typedef QMap<QString, PMWindow*> PMMap;
-    typedef QMap<QString, QVariant> VarMap;
+    typedef QVariantMap VarMap;
     typedef QList<ShellCommandRunner*> ShellList;
 
     HubFrame(QWidget *parent, QString, QString);
     ~HubFrame();
 
+    HubFrame(const HubFrame&) = delete;
+    HubFrame& operator=(const HubFrame&) = delete;
+
     bool parseForCmd(QString, QWidget *);
 
     void createPMWindow(const QString&);
@@ -141,7 +156,7 @@ public:
     inline void reconnect() { slotReconnect(); }
 
     // PM functions
-    void addPM(QString, QString, bool keepfocus = true);
+    void addPM(QString, QString, bool keepfocus = true, QString nick = QString());
 
     // Arena Widget interface
     QWidget *getWidget();
@@ -149,7 +164,8 @@ public:
     QString getArenaShortTitle();
     QMenu *getMenu();
     const QPixmap &getPixmap();
-    void requestFilter() { slotHideFindFrame(); }
+    void requestClear() { clearChat(); }
+    void requestFilter() { slotShowSearchBar(); }
     void requestFocus() { plainTextEdit_INPUT->setFocus(); }
     ArenaWidget::Role role() const { return ArenaWidget::Hub; }
 
@@ -171,6 +187,7 @@ Q_SIGNALS:
     void coreFavoriteUserRemoved(QString);
     void closeRequest();
     void highlighted(const VarMap&);
+    void new_msg(const VarMap&);
 
 public Q_SLOTS:
     void disableChat();
@@ -183,7 +200,8 @@ public Q_SLOTS:
     void disablePrivateMessages(bool disable);//disconnect corePrivateMsg from this
 
     void reloadSomeSettings();
-    void slotHideFindFrame();
+    void slotShowSearchBar();
+    void slotHideSearchBar();
     void slotActivate();
     void nextMsg();
     void prevMsg();
@@ -200,9 +218,9 @@ protected:
     virtual void showEvent(QShowEvent *);
     virtual void hideEvent(QHideEvent *);
 
-    virtual void sendChat(QString, bool, bool);
-    virtual void save();
-    virtual void load();
+    void sendChat(QString, bool, bool);
+    void save();
+    void load();
 
 private Q_SLOTS:
     void slotUsersUpdated();
@@ -216,7 +234,7 @@ private Q_SLOTS:
     void slotShowWnd();
     void slotShellFinished(bool, QString);
     void slotFilterTextChanged();
-    void slotFindForward() { findText(0); }
+    void slotFindForward() { findText(nullptr); }
     void slotFindBackward(){ findText(QTextDocument::FindBackward); }
     void slotFindTextEdited(const QString & text);
     void slotInputTextChanged();
@@ -251,6 +269,7 @@ private Q_SLOTS:
 private:
     // Chat functions
     void addOutput(QString);
+    void addUserData(const QString&);
 
     // GUI setup functions
     void init();
@@ -258,8 +277,8 @@ private:
 
     QString getUserInfo(UserListItem *item);
 
-    void pmUserOffline(QString);
-    void pmUserEvent(QString, QString);
+    void pmUserOffline(const QString &);
+    void pmUserEvent(const QString &, const QString &);
 
     void findText(QTextDocument::FindFlags );
 
@@ -287,8 +306,7 @@ private:
     virtual void on(ClientListener::NickTaken, Client*) noexcept;
     virtual void on(ClientListener::SearchFlood, Client*, const string&) noexcept;
 
-    Q_DECLARE_PRIVATE(HubFrame);
-
+    Q_DECLARE_PRIVATE(HubFrame)
     HubFramePrivate *d_ptr;
 };
 
