@@ -23,19 +23,25 @@ class Magnet :
 {
 Q_OBJECT
 public:
-    explicit Magnet(QWidget *parent = 0);
+    explicit Magnet(QWidget *parent = nullptr);
     virtual ~Magnet();
 
-    void setLink(const QString&);
-    enum {
+    void setLink(const QString &);
+    enum MagnetAction {
       MAGNET_ACTION_SHOW_UI = 0,
       MAGNET_ACTION_SEARCH = 1,
       MAGNET_ACTION_DOWNLOAD = 2
     };
-
+    void setLink(const QString &, MagnetAction action);
+    virtual int exec();
+private:
+    MagnetAction currentAction;
 private slots:
+    void saveWindowSize();
     void search();
     void download();
+    void slotCopyMagnet();
+    void slotCopySearchString();
     void slotBrowse();
     void showUI(const QString &, const qulonglong &, const QString &);
     void search(const QString &, const qulonglong &, const QString &);
