@@ -30,7 +30,7 @@ static int getBitPos(unsigned eventId){
 }
 
 Notification::Notification(QObject *parent) :
-    QObject(parent), tray(NULL), notify(NULL), supressSnd(false), supressTxt(false)
+    QObject(parent), tray(nullptr), notify(nullptr), suppressSnd(false), suppressTxt(false)
 {
     switchModule(static_cast<unsigned>(WIGET(WI_NOTIFY_MODULE)));
 
@@ -55,20 +55,20 @@ void Notification::enableTray(bool enable){
 
         delete tray;
 
-        tray = NULL;
+        tray = nullptr;
 
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
         MainWindow::getInstance()->setUnload(false);
-#else // defined(Q_WS_MAC)
+#else // defined(Q_OS_MAC)
         MainWindow::getInstance()->setUnload(true);
-#endif // defined(Q_WS_MAC)
+#endif // defined(Q_OS_MAC)
 
         //WBSET(WB_TRAY_ENABLED, false);
     }
     else {
         delete tray;
 
-        tray = NULL;
+        tray = nullptr;
 
         if (!QSystemTrayIcon::isSystemTrayAvailable() && checkSystemTrayCounter < 12){
             QTimer *timer = new QTimer(this);
@@ -99,16 +99,16 @@ void Notification::enableTray(bool enable){
         menu->setTitle("EiskaltDC++");
 
         QMenu *menuAdditional = new QMenu(tr("Additional"), MainWindow::getInstance());
-        QAction *actSupressSnd = new QAction(tr("Supress sound notifications"), menuAdditional);
-        QAction *actSupressTxt = new QAction(tr("Supress text notifications"), menuAdditional);
+        QAction *actSuppressSnd = new QAction(tr("Suppress sound notifications"), menuAdditional);
+        QAction *actSuppressTxt = new QAction(tr("Suppress text notifications"), menuAdditional);
 
-        actSupressSnd->setCheckable(true);
-        actSupressSnd->setChecked(false);
+        actSuppressSnd->setCheckable(true);
+        actSuppressSnd->setChecked(false);
 
-        actSupressTxt->setCheckable(true);
-        actSupressTxt->setChecked(false);
+        actSuppressTxt->setCheckable(true);
+        actSuppressTxt->setChecked(false);
 
-        menuAdditional->addActions(QList<QAction*>() << actSupressTxt << actSupressSnd);
+        menuAdditional->addActions(QList<QAction*>() << actSuppressTxt << actSuppressSnd);
 
         QAction *show_hide = new QAction(tr("Show/Hide window"), menu);
         QAction *setup_speed_lim = new QAction(tr("Setup speed limits"), menu);
@@ -124,8 +124,8 @@ void Notification::enableTray(bool enable){
         connect(close_app, SIGNAL(triggered()), this, SLOT(slotExit()));
         connect(tray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
                 this, SLOT(slotTrayMenuTriggered(QSystemTrayIcon::ActivationReason)));
-        connect(actSupressTxt, SIGNAL(triggered()), this, SLOT(slotSupressTxt()));
-        connect(actSupressSnd, SIGNAL(triggered()), this, SLOT(slotSupressSnd()));
+        connect(actSuppressTxt, SIGNAL(triggered()), this, SLOT(slotSuppressTxt()));
+        connect(actSuppressSnd, SIGNAL(triggered()), this, SLOT(slotSuppressSnd()));
         connect(setup_speed_lim, SIGNAL(triggered()), this, SLOT(slotShowSpeedLimits()));
 
         menu->addAction(show_hide);
@@ -161,7 +161,7 @@ void Notification::switchModule(int m){
 
 void Notification::showMessage(int t, const QString &title, const QString &msg){
     // On Mac OS X, the Growl notification system must be installed for this function to display messages.
-    if (WBGET(WB_NOTIFY_ENABLED) && !supressTxt){
+    if (WBGET(WB_NOTIFY_ENABLED) && !suppressTxt){
         do {
             if (title.isEmpty() || msg.isEmpty())
                 break;
@@ -173,24 +173,24 @@ void Notification::showMessage(int t, const QString &title, const QString &msg){
             if (!(static_cast<unsigned>(WIGET(WI_NOTIFY_EVENTMAP)) & static_cast<unsigned>(t)))
                 break;
 
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
             qApp->setWindowIcon(WICON(WulforUtil::eiMESSAGE_TRAY_ICON));
             qApp->alert(MainWindow::getInstance(), 0);
-#else // defined(Q_WS_MAC)
+#else // defined(Q_OS_MAC)
             if (tray && t == PM && (!MainWindow::getInstance()->isVisible() || WBGET(WB_NOTIFY_CH_ICON_ALWAYS))){
                 tray->setIcon(WICON(WulforUtil::eiMESSAGE_TRAY_ICON));
 
                 if (MainWindow::getInstance()->isVisible())
                     QApplication::alert(MainWindow::getInstance(), 0);
             }
-#endif // defined(Q_WS_MAC)
+#endif // defined(Q_OS_MAC)
 
             if (notify)
                 notify->showMessage(title, msg, tray);
-        } while (0);
+        } while (false);
     }
 
-    if (WBGET(WB_NOTIFY_SND_ENABLED) && !supressSnd){
+    if (WBGET(WB_NOTIFY_SND_ENABLED) && !suppressSnd){
         do {
             if (!(static_cast<unsigned>(WIGET(WI_NOTIFY_SNDMAP)) & static_cast<unsigned>(t)))
                 break;
@@ -217,7 +217,7 @@ void Notification::showMessage(int t, const QString &title, const QString &msg){
                     r->start();
                 }
             }
-        } while (0);
+        } while (false);
     }
 }
 
@@ -225,33 +225,20 @@ void Notification::setToolTip(const QString &DSPEED, const QString &USPEED, cons
     if (!WBGET(WB_TRAY_ENABLED) || !tray)
         return;
 
-#if defined(Q_WS_X11)
-    QString out = tr("<b>Speed</b><br/>"
-                     "Download: <font_color=\"green\">%1</font> "
-                     "Upload: <font_color=\"red\">%2</font><br/>"
-                     "<b>Statistics</b><br/>"
-                     "Downloaded: <font_color=\"green\">%3</font> "
-                     "Uploaded: <font_color=\"red\">%4</font>")
-            .arg(DSPEED).arg(USPEED).arg(DOWN).arg(UP);
-
-    out.replace(" ","&nbsp;");
-    out.replace("_"," ");
-#else
-    QString out = tr("Speed\n"
+    const QString &&out = tr("Speed\n"
                      "Download: %1 "
                      "Upload: %2\n"
                      "Statistics\n"
                      "Downloaded: %3 "
                      "Uploaded: %4")
             .arg(DSPEED).arg(USPEED).arg(DOWN).arg(UP);
-#endif
 
     tray->setToolTip(out);
 }
 
 void Notification::reloadSounds(){
     QString encoded = WSGET(WS_NOTIFY_SOUNDS);
-    QString decoded = QByteArray::fromBase64(encoded.toAscii());
+    QString decoded = QByteArray::fromBase64(encoded.toUtf8());
 
     sounds = decoded.split("\n");
 }
@@ -268,9 +255,9 @@ void Notification::slotShowHide(){
     MainWindow *MW = MainWindow::getInstance();
 
     if (MW->isVisible()){
-#if defined(Q_WS_WIN)
+#if defined(Q_OS_WIN)
         MW->hide();
-#elif defined(Q_WS_MAC)
+#elif defined(Q_OS_MAC)
         if (!MW->isActiveWindow()){
             MW->activateWindow();
             MW->raise();
@@ -290,13 +277,17 @@ void Notification::slotShowHide(){
     }
     else{
         MW->show();
+#if !defined(Q_OS_WIN)
+        MW->activateWindow();
+#endif
         MW->raise();
-#if defined(Q_WS_MAC)
+
+#if defined(Q_OS_MAC)
         MW->redrawToolPanel();
-#else // defined(Q_WS_MAC)
+#else // defined(Q_OS_MAC)
         if (tray)
             MW->redrawToolPanel();
-#endif // defined(Q_WS_MAC)
+#endif // defined(Q_OS_MAC)
     }
 }
 
@@ -338,16 +329,16 @@ void Notification::slotCheckTray(){
     timer->deleteLater();
 }
 
-void Notification::slotSupressTxt(){
+void Notification::slotSuppressTxt(){
     QAction *act = qobject_cast<QAction*>(sender());
     if (act)
-        setSupressTxt(act->isChecked());
+        setSuppressTxt(act->isChecked());
 }
 
-void Notification::slotSupressSnd(){
+void Notification::slotSuppressSnd(){
     QAction *act = qobject_cast<QAction*>(sender());
     if (act)
-        setSupressSnd(act->isChecked());
+        setSuppressSnd(act->isChecked());
 }
 
 void Notification::resetTrayIcon(){
@@ -370,7 +361,7 @@ void DBusNotifyModule::showMessage(const QString &title, const QString &msg, QOb
     QVariantList args;
     args << QString("EiskaltDC++");
     args << QVariant(QVariant::UInt);
-    args << QVariant(WulforUtil::getInstance()->getIconsPath() + "/" + "icon_appl_big.png");
+    args << QVariant(WulforUtil::getInstance()->getAppIconsPath() + "/" + "icon_appl_big.png");
     args << QString(title);
     args << QString(msg);
     args << QStringList();
