@@ -63,8 +63,8 @@ enum Type{
     void reloadSounds();
     void resetTrayIcon();
 
-    void setSupressTxt(bool supressTxt_ = false) { supressTxt = supressTxt_; }
-    void setSupressSnd(bool supressSnd_ = false) { supressSnd = supressSnd_; }
+    void setSuppressTxt(bool suppressTxt_ = false) { suppressTxt = suppressTxt_; }
+    void setSuppressSnd(bool suppressSnd_ = false) { suppressSnd = suppressSnd_; }
 
 
 public Q_SLOTS:
@@ -79,11 +79,11 @@ private Q_SLOTS:
     void slotTrayMenuTriggered(QSystemTrayIcon::ActivationReason);
     void slotCmdFinished(bool, QString);
     void slotCheckTray();
-    void slotSupressTxt();
-    void slotSupressSnd();
+    void slotSuppressTxt();
+    void slotSuppressSnd();
 
 private:
-    explicit Notification(QObject *parent = 0);
+    explicit Notification(QObject *parent = nullptr);
     virtual ~Notification();
 
     QStringList sounds;
@@ -91,13 +91,11 @@ private:
     QSystemTrayIcon *tray;
     NotifyModule *notify;
 
-    bool supressSnd;
-    bool supressTxt;
+    bool suppressSnd;
+    bool suppressTxt;
 
     int checkSystemTrayCounter;
 };
 
-#define Notify Notification::getInstance()
-
 Q_DECLARE_METATYPE(Notification*)
 Q_DECLARE_METATYPE(Notification::Type)
