@@ -24,6 +24,7 @@
 #include "dcpp/User.h"
 
 #include <QTextBlock>
+#include <QTextDocument>
 #include <QKeyEvent>
 #include <QMouseEvent>
 #include <QEvent>
@@ -38,23 +39,21 @@ static inline void clearLayout(QLayout *l){
     if (!l)
         return;
 
-    QLayoutItem *item = NULL;
-    while (item = l->takeAt(0)){
+    for (QLayoutItem *item = l->takeAt(0); item; item = l->takeAt(0)) {
         l->removeWidget(item->widget());
         item->widget()->deleteLater();
-
         delete item;
     }
 
     l->invalidate();
 }
 
-PMWindow::PMWindow(QString cid, QString hubUrl):
+PMWindow::PMWindow(const QString &cid_, const QString &hubUrl_):
         hasMessages(false),
         hasHighlightMessages(false),
-        cid(cid),
-        hubUrl(hubUrl),
-        arena_menu(NULL)
+        cid(cid_),
+        hubUrl(hubUrl_),
+        arena_menu(nullptr)
 {
     setupUi(this);
 
@@ -68,7 +67,7 @@ PMWindow::PMWindow(QString cid, QString hubUrl):
     if (EmoticonFactory::getInstance())
         EmoticonFactory::getInstance()->fillLayout(frame_SMILES->layout(), sz);
 
-    foreach(EmoticonLabel *l, frame_SMILES->findChildren<EmoticonLabel*>())
+    for (const auto &l : frame_SMILES->findChildren<EmoticonLabel*>())
         connect(l, SIGNAL(clicked()), this, SLOT(slotSmileClicked()));
 
     setAttribute(Qt::WA_DeleteOnClose);
@@ -128,9 +127,10 @@ PMWindow::PMWindow(QString cid, QString hubUrl):
     connect(plainTextEdit_INPUT, SIGNAL(customContextMenuRequested(QPoint)), this, SIGNAL(inputTextMenu()));
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingChanged(QString,QString)));
     connect(lineEdit_FIND, SIGNAL(textChanged(QString)), this, SLOT(slotFindTextEdited(QString)));
-    connect(toolButton_HIDE, SIGNAL(clicked()), this, SLOT(slotHideFindFrame()));
+    connect(toolButton_HIDE, SIGNAL(clicked()), this, SLOT(slotHideSearchBar()));
     connect(toolButton_BACK, SIGNAL(clicked()), this, SLOT(slotFindBackward()));
     connect(toolButton_FORWARD, SIGNAL(clicked()), this, SLOT(slotFindForward()));
+    connect(toolButton_ALL, SIGNAL(clicked()), this, SLOT(slotFindAll()));
 
     out_messages_index = 0;
     out_messages_unsent = false;
@@ -162,37 +162,43 @@ bool PMWindow::eventFilter(QObject *obj, QEvent *e){
         }
         else if (static_cast<LineEdit*>(obj) == lineEdit_FIND && k_e->key() == Qt::Key_Escape){
             lineEdit_FIND->clear();
-
-            requestFilter();
-
+            slotHideSearchBar();
             return true;
         }
     }
     else if (e->type() == QEvent::KeyPress){
         QKeyEvent *k_e = reinterpret_cast<QKeyEvent*>(e);
 
-        if ((static_cast<QTextEdit*>(obj) == plainTextEdit_INPUT) &&
-            (!WBGET(WB_USE_CTRL_ENTER) || k_e->modifiers() == Qt::ControlModifier) &&
-            ((k_e->key() == Qt::Key_Enter || k_e->key() == Qt::Key_Return) && k_e->modifiers() != Qt::ShiftModifier) ||
-            (k_e->key() == Qt::Key_Enter && k_e->modifiers() == Qt::KeypadModifier))
+        const bool controlModifier = (k_e->modifiers() == Qt::ControlModifier);
+
+        if (static_cast<QTextEdit*>(obj) == plainTextEdit_INPUT)
         {
-            QString msg = plainTextEdit_INPUT->toPlainText();
+            const bool useCtrlEnter = WBGET(WB_USE_CTRL_ENTER);
+            const bool keyEnter = (k_e->key() == Qt::Key_Enter || k_e->key() == Qt::Key_Return);
+            const bool shiftModifier = (k_e->modifiers() == Qt::ShiftModifier);
 
-            HubFrame *fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
+            if ((useCtrlEnter && keyEnter && controlModifier) ||
+                (!useCtrlEnter && keyEnter && !controlModifier && !shiftModifier))
+            {
+                const QString msg = plainTextEdit_INPUT->toPlainText();
 
-            if (fr){
-                if (!fr->parseForCmd(msg, this))
+                HubFrame *fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
+
+                if (fr) {
+                    if (!fr->parseForCmd(msg, this))
+                        sendMessage(msg, false, false);
+                }
+                else {
                     sendMessage(msg, false, false);
+                }
+
+                plainTextEdit_INPUT->setPlainText("");
+
+                return true;
             }
-            else
-                sendMessage(msg, false, false);
-
-            plainTextEdit_INPUT->setPlainText("");
-
-            return true;
         }
 
-        if (k_e->modifiers() == Qt::ControlModifier){
+        if (controlModifier){
             if (k_e->key() == Qt::Key_Equal || k_e->key() == Qt::Key_Plus){
                 textEdit_CHAT->zoomIn();
 
@@ -300,7 +306,7 @@ void PMWindow::slotActivate(){
 }
 
 QString PMWindow::getArenaTitle(){
-    QString nick = (cid.length() > 24)? _q(ClientManager::getInstance()->getNicks(CID(cid.toStdString()), _tq(hubUrl)).at(0)) : cid;
+    QString nick = (cid.length() > 24)? WulforUtil::getInstance()->getNickViaOnlineUser(cid, hubUrl) : cid;
 
     nick_ = nick.isEmpty()? nick_ : nick;
 
@@ -308,7 +314,7 @@ QString PMWindow::getArenaTitle(){
 }
 
 QString PMWindow::getArenaShortTitle(){
-    QString nick = (cid.length() > 24)? _q(ClientManager::getInstance()->getNicks(CID(cid.toStdString()), _tq(hubUrl)).at(0)) : cid;
+    QString nick = (cid.length() > 24)? WulforUtil::getInstance()->getNickViaOnlineUser(cid, hubUrl) : cid;
 
     nick_ = nick.isEmpty()? nick_ : nick;
 
@@ -332,6 +338,22 @@ const QPixmap &PMWindow::getPixmap(){
         return WICON(WulforUtil::eiUSERS);
 }
 
+ArenaWidget::Role PMWindow::role() const {
+    return ArenaWidget::PrivateMessage;
+}
+
+void PMWindow::requestClear(){
+    clearChat();
+}
+
+void PMWindow::requestFilter() {
+    slotShowSearchBar();
+}
+
+void PMWindow::requestFocus() {
+    plainTextEdit_INPUT->setFocus();
+}
+
 void PMWindow::clearChat(){
     textEdit_CHAT->setHtml("");
     addStatus(tr("Chat cleared."));
@@ -360,7 +382,7 @@ void PMWindow::updateStyles(){
     }
 }
 
-void PMWindow::addStatusMessage(QString msg){
+void PMWindow::addStatusMessage(const QString &msg){
     QString status = " * ";
 
     QString nick = "";
@@ -402,13 +424,23 @@ void PMWindow::addOutput(QString msg){
     msg = "<pre>" + msg + "</pre>";
     textEdit_CHAT->append(msg);
 
-    if (!isVisible()){
+    if (!isVisible()) {
         hasMessages = true;
         MainWindow::getInstance()->redrawToolPanel();
     }
 }
 
-void PMWindow::sendMessage(QString msg, bool thirdPerson, bool stripNewLines){
+void PMWindow::addUserData(const QString &nick){
+    QTextDocument *chatDoc = textEdit_CHAT->document();
+    for (QTextBlock itu = chatDoc->lastBlock(); itu.isValid(); itu = itu.previous()){
+        if (!itu.userData())
+            itu.setUserData(new UserListUserData(nick));
+        else
+            break;
+    }
+}
+
+void PMWindow::sendMessage(QString msg, const bool thirdPerson, const bool stripNewLines){
     UserPtr user = ClientManager::getInstance()->findUser(CID(cid.toStdString()));
 
     if (user && user->isOnline()){
@@ -438,6 +470,18 @@ void PMWindow::sendMessage(QString msg, bool thirdPerson, bool stripNewLines){
     out_messages_index = out_messages.size()-1;
 }
 
+QWidget *PMWindow::inputWidget() const {
+    return plainTextEdit_INPUT;
+}
+
+void PMWindow::setHasHighlightMessages(bool h) {
+    hasHighlightMessages = (h && !isVisible());
+}
+
+bool PMWindow::hasNewMessages() {
+    return (hasMessages || hasHighlightMessages);
+}
+
 void PMWindow::nextMsg(){
     if (!plainTextEdit_INPUT->hasFocus())
         return;
@@ -572,16 +616,11 @@ void PMWindow::slotSmileClicked(){
 
 
 void PMWindow::slotSmileContextMenu(){
-#if !defined(Q_WS_WIN)
-    QString emot = CLIENT_DATA_DIR "/emoticons/";
-#else
-    QString emot = qApp->applicationDirPath()+QDir::separator()+CLIENT_DATA_DIR "/emoticons/";
-#endif
-
     QMenu *m = new QMenu(this);
-    QAction * a = NULL;
+    QAction * a = nullptr;
 
-    foreach (const QString &f, QDir(emot).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
+    for (const auto &f : QDir(WulforUtil::getInstance()->getEmoticonsPath())
+                              .entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
         if (!f.isEmpty()){
             QAction * act = m->addAction(f);
             act->setCheckable(true);
@@ -615,7 +654,7 @@ void PMWindow::slotSettingChanged(const QString &key, const QString &value){
 
             EmoticonFactory::getInstance()->fillLayout(frame_SMILES->layout(), sz);
 
-            foreach(EmoticonLabel *l, frame_SMILES->findChildren<EmoticonLabel*>())
+            for (const auto &l : frame_SMILES->findChildren<EmoticonLabel*>())
                 connect(l, SIGNAL(clicked()), this, SLOT(slotSmileClicked()));
         }
 
@@ -637,28 +676,21 @@ void PMWindow::slotSettingChanged(const QString &key, const QString &value){
         retranslateUi(this);
 }
 
-void PMWindow::slotHideFindFrame(){
-    frame_2->setVisible(!frame_2->isVisible());
+void PMWindow::slotShowSearchBar(){
+    frame_2->setVisible(true);
+    QString stext = textEdit_CHAT->textCursor().selectedText();
+    if (!stext.isEmpty())
+        lineEdit_FIND->setText(stext);
+    lineEdit_FIND->selectAll();
+    lineEdit_FIND->setFocus();
+}
 
-    if (frame_2->isVisible()){
-        QString stext = textEdit_CHAT->textCursor().selectedText();
-
-        if (!stext.isEmpty()){
-            lineEdit_FIND->setText(stext);
-            lineEdit_FIND->selectAll();
-        }
-
-        lineEdit_FIND->setFocus();
-    }
-    else{
-        QTextCursor c = textEdit_CHAT->textCursor();
-
-        c.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor,1);
-
-        textEdit_CHAT->setExtraSelections(QList<QTextEdit::ExtraSelection>());
-
-        textEdit_CHAT->setTextCursor(c);
-    }
+void PMWindow::slotHideSearchBar(){
+    frame_2->setVisible(false);
+    QTextCursor c = textEdit_CHAT->textCursor();
+    c.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor,1);
+    textEdit_CHAT->setExtraSelections(QList<QTextEdit::ExtraSelection>());
+    textEdit_CHAT->setTextCursor(c);
 }
 
 void PMWindow::slotFindTextEdited(const QString & text){
@@ -672,13 +704,12 @@ void PMWindow::slotFindTextEdited(const QString & text){
     QTextCursor c = textEdit_CHAT->textCursor();
 
     c.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor,1);
-    c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), c, 0);
-
-    textEdit_CHAT->setExtraSelections(QList<QTextEdit::ExtraSelection>());
-
-    textEdit_CHAT->setTextCursor(c);
-
-    slotFindAll();
+    c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), c, nullptr);
+    if (!c.isNull()) {
+        textEdit_CHAT->setExtraSelections(QList<QTextEdit::ExtraSelection>());
+        textEdit_CHAT->setTextCursor(c);
+        slotFindAll();
+    }
 }
 
 void PMWindow::slotFindAll(){
@@ -699,13 +730,13 @@ void PMWindow::slotFindAll(){
 
         selection.format.setBackground(color);
 
-        QTextCursor c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), 0, 0);
+        QTextCursor c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), 0, nullptr);
 
         while (!c.isNull()){
             selection.cursor = c;
             extraSelections.append(selection);
 
-            c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), c, 0);
+            c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), c, nullptr);
         }
     }
 
@@ -729,7 +760,8 @@ void PMWindow::findText(QTextDocument::FindFlags flag){
 
     c = textEdit_CHAT->document()->find(lineEdit_FIND->text(), c, flag);
 
-    textEdit_CHAT->setTextCursor(c);
-
-    slotFindAll();
+    if (!c.isNull()) {
+        textEdit_CHAT->setTextCursor(c);
+        slotFindAll();
+    }
 }
