@@ -10,6 +10,7 @@
 #include "PublicHubs.h"
 #include "MainWindow.h"
 #include "WulforSettings.h"
+#include "AutoToolTip.h"
 
 #include <QApplication>
 #include <QClipboard>
@@ -20,7 +21,7 @@
 using namespace dcpp;
 
 PublicHubs::PublicHubs(QWidget *parent) :
-    QWidget(parent), proxy(NULL)
+    QWidget(parent), proxy(nullptr)
 {
     setupUi(this);
 
@@ -29,6 +30,7 @@ PublicHubs::PublicHubs(QWidget *parent) :
     model = new PublicHubModel();
 
     treeView->setModel(model);
+    treeView->setItemDelegate(new AutoToolTipDelegate(treeView));
     treeView->header()->restoreState(WVGET(WS_PUBLICHUBS_STATE, QByteArray()).toByteArray());
 
     lineEdit_FILTER->installEventFilter(this);
@@ -37,7 +39,7 @@ PublicHubs::PublicHubs(QWidget *parent) :
 
     QString hubs = _q(SettingsManager::getInstance()->get(SettingsManager::HUBLIST_SERVERS));
 
-    comboBox_HUBS->addItems(hubs.split(";"));
+    comboBox_HUBS->addItems(hubs.split(";", QString::SkipEmptyParts));
     comboBox_HUBS->setCurrentIndex(FavoriteManager::getInstance()->getSelectedHubList());
 
     for (int i = 0; i < model->columnCount(); i++)
@@ -75,6 +77,8 @@ PublicHubs::PublicHubs(QWidget *parent) :
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
     
     ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
+    if (comboBox_HUBS->count())
+        slotHubChanged(comboBox_HUBS->currentIndex());
 }
 
 PublicHubs::~PublicHubs(){
@@ -117,8 +121,8 @@ void PublicHubs::updateList(){
     model->clearModel();
     QList<QVariant> data;
 
-    for (auto i = entries.begin(); i != entries.end(); ++i) {
-        HubEntry *entry = const_cast<HubEntry*>(&(*i));
+    for (auto &i : entries) {
+        HubEntry *entry = const_cast<HubEntry*>(&i);
         data.clear();
 
         data << _q(entry->getName())         << _q(entry->getDescription())  << entry->getUsers()
@@ -162,22 +166,22 @@ void PublicHubs::slotContextMenu(){
     m->deleteLater();
 
     if (ret == connect){
-        PublicHubItem * item = NULL;
+        PublicHubItem * item = nullptr;
         MainWindow *MW = MainWindow::getInstance();
 
-        foreach (const QModelIndex &i, indexes){
+        for (const auto &i : indexes){
             item = reinterpret_cast<PublicHubItem*>(i.internalPointer());
 
             if (item)
                 MW->newHubFrame(item->data(COLUMN_PHUB_ADDRESS).toString(), "");
 
-            item = NULL;
+            item = nullptr;
         }
     }
     else if (ret == add_fav){
-        PublicHubItem * item = NULL;
+        PublicHubItem * item = nullptr;
 
-        foreach (const QModelIndex &i, indexes){
+        for (const auto &i : indexes){
             item = reinterpret_cast<PublicHubItem*>(i.internalPointer());
 
             if (item && item->entry){
@@ -187,20 +191,20 @@ void PublicHubs::slotContextMenu(){
                 catch (const std::exception&){}
             }
 
-            item = NULL;
+            item = nullptr;
         }
     }
     else if (ret == copy){
-        PublicHubItem * item = NULL;
+        PublicHubItem * item = nullptr;
         QString out = "";
 
-        foreach (const QModelIndex &i, indexes){
+        for (const auto &i : indexes){
             item = reinterpret_cast<PublicHubItem*>(i.internalPointer());
 
             if (item)
                 out += item->data(COLUMN_PHUB_ADDRESS).toString() + "\n";
 
-            item = NULL;
+            item = nullptr;
         }
 
         if (!out.isEmpty())
@@ -232,7 +236,7 @@ void PublicHubs::slotFilter(){
         disconnect(lineEdit_FILTER, SIGNAL(textChanged(QString)), proxy, SLOT(setFilterFixedString(QString)));
 
         delete proxy;
-        proxy = NULL;
+        proxy = nullptr;
     }
     else {
         proxy = new PublicHubProxyModel();
@@ -282,8 +286,8 @@ void PublicHubs::on(DownloadFailed, const std::string& l) noexcept{
     emit coreDownloadFailed(tr("Download failed: %1").arg(_q(l)));
 }
 
-void PublicHubs::on(DownloadFinished, const std::string& l, bool fromCoral) noexcept{
-    emit coreDownloadFinished(tr("Hub list downloaded... (%1 %2) ").arg(_q(l)).arg(fromCoral? tr("from Coral") : ""));
+void PublicHubs::on(DownloadFinished, const std::string& l) noexcept{
+    emit coreDownloadFinished(tr("Hub list downloaded... (%1)").arg(_q(l)));
 }
 
 void PublicHubs::on(LoadedFromCache, const std::string& l, const std::string& d) noexcept{
