@@ -55,8 +55,8 @@ void SearchBlackListDialog::slotContextMenu(){
     QModelIndexList indexes = s_m->selectedRows(0);
 
     QMenu *menu = new QMenu(this);
-    QAction *add = new QAction(WICON(WulforUtil::eiEDITADD), tr("Add new"), NULL);
-    QAction *rem = new QAction(WICON(WulforUtil::eiEDITDELETE), tr("Remove"), NULL);
+    QAction *add = new QAction(WICON(WulforUtil::eiEDITADD), tr("Add new"), nullptr);
+    QAction *rem = new QAction(WICON(WulforUtil::eiEDITDELETE), tr("Remove"), nullptr);
 
     menu->addActions(QList<QAction*>() << add << rem);
 
@@ -68,7 +68,7 @@ void SearchBlackListDialog::slotContextMenu(){
         s_m->select(model->addEmptyItem(), QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
     }
     else if (ret && !indexes.isEmpty()){
-        foreach (const QModelIndex &index, indexes){
+        for (const auto &index : indexes){
             SearchBlackListItem *i = reinterpret_cast<SearchBlackListItem*>(index.internalPointer());
 
             if (!i)
@@ -85,14 +85,14 @@ SearchBlackListModel::SearchBlackListModel(QObject * parent) :
         QAbstractItemModel(parent),
         sortColumn(COLUMN_SBL_KEY)
 {
-    rootItem = new SearchBlackListItem(NULL);
+    rootItem = new SearchBlackListItem(nullptr);
 
     SearchBlacklist *SB = SearchBlacklist::getInstance();
 
     QList<QString> names = SB->getList(SearchBlacklist::NAME);
     QList<QString> tths  = SB->getList(SearchBlacklist::TTH);
 
-    foreach (const QString &name, names){
+    for (const auto &name : names){
         SearchBlackListItem * item = new SearchBlackListItem(rootItem);
         item->title = name;
         item->argument = SearchBlacklist::NAME;
@@ -100,7 +100,7 @@ SearchBlackListModel::SearchBlackListModel(QObject * parent) :
         rootItem->appendChild(item);
     }
 
-    foreach (const QString &tth, tths){
+    for (const auto &tth : tths){
         SearchBlackListItem * item = new SearchBlackListItem(rootItem);
         item->title = tth;
         item->argument = SearchBlacklist::TTH;
@@ -120,7 +120,7 @@ void SearchBlackListModel::save(){
     QList<QString> names;
     QList<QString> tths;
 
-    foreach (SearchBlackListItem *item, rootItem->childItems){
+    for (const auto &item : rootItem->childItems){
         QList<QString> &l = (item->argument == SearchBlacklist::NAME? names : tths);
 
         l.push_back(item->title);
@@ -141,7 +141,7 @@ int SearchBlackListModel::columnCount(const QModelIndex & ) const {
 
 Qt::ItemFlags SearchBlackListModel::flags(const QModelIndex &index) const {
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     return Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
@@ -161,7 +161,7 @@ QVariant SearchBlackListModel::data(const QModelIndex & index, int role) const {
             if (!index.column())
                 return item->title;
             else
-                return (item->argument == SearchBlacklist::NAME? tr("Filename") : tr("TTH"));
+                return (item->argument == SearchBlacklist::NAME? tr("Filename") : QString("TTH"));
 
             break;
         }
@@ -200,11 +200,11 @@ namespace {
     template <Qt::SortOrder order>
     struct Compare {
         void static sort(int col, QList<SearchBlackListItem*>& items) {
-            qStableSort(items.begin(), items.end(), getAttrComp(col));
+            std::stable_sort(items.begin(), items.end(), getAttrComp(col));
         }
 
         void static insertSorted(int col, QList<SearchBlackListItem*>& items, SearchBlackListItem* item) {
-            auto it = qLowerBound(items.begin(), items.end(), item, getAttrComp(col));
+            auto it = std::lower_bound(items.begin(), items.end(), item, getAttrComp(col));
             items.insert(it, item);
         }
 
@@ -300,6 +300,7 @@ SearchBlackListItem::SearchBlackListItem(SearchBlackListItem *parent) : argument
 SearchBlackListItem::~SearchBlackListItem()
 {
     qDeleteAll(childItems);
+    childItems.clear();
 }
 
 void SearchBlackListItem::appendChild(SearchBlackListItem *item) {
@@ -338,11 +339,12 @@ SearchBlackListDelegate::~SearchBlackListDelegate(){
 }
 
 QWidget *SearchBlackListDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const{
+    Q_UNUSED(option)
     if (index.column() == 1){
         QComboBox *edit = new QComboBox(parent);
 
         edit->addItem(tr("Filename"));
-        edit->addItem(tr("TTH"));
+        edit->addItem(QString("TTH"));
 
         return edit;
     }
@@ -356,6 +358,7 @@ QWidget *SearchBlackListDelegate::createEditor(QWidget *parent, const QStyleOpti
 }
 
 void SearchBlackListDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const{
+    Q_UNUSED(index)
     editor->setGeometry(option.rect);
 }
 
