@@ -113,20 +113,19 @@ bool SearchStringListModel::setData(const QModelIndex &index, const QVariant &va
     return true;
 }
 
-SearchFrame::Menu::Menu(){
+SearchFrame::Menu::Menu() : menu(new QMenu(nullptr))
+{
     WulforUtil *WU = WulforUtil::getInstance();
 
-    menu = new QMenu();
-
     magnet_menu = new QMenu(tr("Magnet"));
 
-    QAction *down       = new QAction(tr("Download"), NULL);
+    QAction *down       = new QAction(tr("Download"), nullptr);
     down->setIcon(WU->getPixmap(WulforUtil::eiDOWNLOAD));
 
     down_to             = new QMenu(tr("Download to..."));
     down_to->setIcon(WU->getPixmap(WulforUtil::eiDOWNLOAD_AS));
 
-    QAction *down_wh    = new QAction(tr("Download Whole Directory"), NULL);
+    QAction *down_wh    = new QAction(tr("Download Whole Directory"), nullptr);
     down_wh->setIcon(WU->getPixmap(WulforUtil::eiDOWNLOAD));
 
     down_wh_to          = new QMenu(tr("Download Whole Directory to..."));
@@ -135,31 +134,31 @@ SearchFrame::Menu::Menu(){
     QAction *sep        = new QAction(menu);
     sep->setSeparator(true);
 
-    QAction *find_tth   = new QAction(tr("Search TTH"), NULL);
+    QAction *find_tth   = new QAction(tr("Search TTH"), nullptr);
     find_tth->setIcon(WU->getPixmap(WulforUtil::eiFILEFIND));
 
-    QAction *magnet     = new QAction(tr("Copy magnet"), NULL);
+    QAction *magnet     = new QAction(tr("Copy magnet"), nullptr);
     magnet->setIcon(WU->getPixmap(WulforUtil::eiEDITCOPY));
 
-    QAction *magnet_web     = new QAction(tr("Copy web-magnet"), NULL);
+    QAction *magnet_web     = new QAction(tr("Copy web-magnet"), nullptr);
     magnet_web->setIcon(WU->getPixmap(WulforUtil::eiEDITCOPY));
 
-    QAction *magnet_info    = new QAction(tr("Properties of magnet"), NULL);
+    QAction *magnet_info    = new QAction(tr("Properties of magnet"), nullptr);
     magnet_info->setIcon(WU->getPixmap(WulforUtil::eiDOWNLOAD));
 
-    QAction *browse     = new QAction(tr("Browse files"), NULL);
+    QAction *browse     = new QAction(tr("Browse files"), nullptr);
     browse->setIcon(WU->getPixmap(WulforUtil::eiFOLDER_BLUE));
 
-    QAction *match      = new QAction(tr("Match Queue"), NULL);
+    QAction *match      = new QAction(tr("Match Queue"), nullptr);
     match->setIcon(WU->getPixmap(WulforUtil::eiDOWN));
 
-    QAction *send_pm    = new QAction(tr("Send Private Message"), NULL);
+    QAction *send_pm    = new QAction(tr("Send Private Message"), nullptr);
     send_pm->setIcon(WU->getPixmap(WulforUtil::eiMESSAGE));
 
-    QAction *add_to_fav = new QAction(tr("Add to favorites"), NULL);
+    QAction *add_to_fav = new QAction(tr("Add to favorites"), nullptr);
     add_to_fav->setIcon(WU->getPixmap(WulforUtil::eiBOOKMARK_ADD));
 
-    QAction *grant      = new QAction(tr("Grant extra slot"), NULL);
+    QAction *grant      = new QAction(tr("Grant extra slot"), nullptr);
     grant->setIcon(WU->getPixmap(WulforUtil::eiEDITADD));
 
     QAction *sep1       = new QAction(menu);
@@ -171,19 +170,19 @@ SearchFrame::Menu::Menu(){
     QAction *sep3       = new QAction(menu);
     sep3->setSeparator(true);
 
-    QAction *rem_queue  = new QAction(tr("Remove from Queue"), NULL);
+    QAction *rem_queue  = new QAction(tr("Remove from Queue"), nullptr);
     rem_queue->setIcon(WU->getPixmap(WulforUtil::eiEDITDELETE));
 
-    QAction *rem        = new QAction(tr("Remove"), NULL);
+    QAction *rem        = new QAction(tr("Remove"), nullptr);
     rem->setIcon(WU->getPixmap(WulforUtil::eiEDITDELETE));
 
     black_list_menu     = new QMenu(tr("Blacklist..."));
     black_list_menu->setIcon(WU->getPixmap(WulforUtil::eiFILTER));
 
-    QAction *blacklist = new QAction(tr("Blacklist"), NULL);
+    QAction *blacklist = new QAction(tr("Blacklist"), nullptr);
     blacklist->setIcon(WU->getPixmap(WulforUtil::eiFILTER));
 
-    QAction *add_to_blacklist = new QAction(tr("Add to Blacklist"), NULL);
+    QAction *add_to_blacklist = new QAction(tr("Add to Blacklist"), nullptr);
     add_to_blacklist->setIcon(WU->getPixmap(WulforUtil::eiEDITADD));
 
     black_list_menu->addActions(QList<QAction*>()
@@ -225,6 +224,7 @@ SearchFrame::Menu::Menu(){
 
 SearchFrame::Menu::~Menu(){
     qDeleteAll(action_list);
+    action_list.clear();
 
     magnet_menu->deleteLater();
     menu->deleteLater();
@@ -233,9 +233,9 @@ SearchFrame::Menu::~Menu(){
     black_list_menu->deleteLater();
 }
 
-SearchFrame::Menu::Action SearchFrame::Menu::exec(QStringList list = QStringList()){
-    foreach(QAction *a, action_list)
-        a->setParent(NULL);
+SearchFrame::Menu::Action SearchFrame::Menu::exec(const QStringList &list = QStringList()){
+    for (const auto &a : action_list)
+        a->setParent(nullptr);
 
     qDeleteAll(down_to->actions());
     qDeleteAll(down_wh_to->actions());
@@ -244,8 +244,8 @@ SearchFrame::Menu::Action SearchFrame::Menu::exec(QStringList list = QStringList
 
     QString aliases, paths;
 
-    aliases = QByteArray::fromBase64(WSGET(WS_DOWNLOADTO_ALIASES).toAscii());
-    paths   = QByteArray::fromBase64(WSGET(WS_DOWNLOADTO_PATHS).toAscii());
+    aliases = QByteArray::fromBase64(WSGET(WS_DOWNLOADTO_ALIASES).toUtf8());
+    paths   = QByteArray::fromBase64(WSGET(WS_DOWNLOADTO_PATHS).toUtf8());
 
     QStringList a = aliases.split("\n", QString::SkipEmptyParts);
     QStringList p = paths.split("\n", QString::SkipEmptyParts);
@@ -253,7 +253,7 @@ SearchFrame::Menu::Action SearchFrame::Menu::exec(QStringList list = QStringList
     QStringList temp_pathes = DownloadToDirHistory::get();
 
     if (!temp_pathes.isEmpty()){
-        foreach (const QString &t, temp_pathes){
+        for (const auto &t : temp_pathes){
             QAction *act = new QAction(WICON(WulforUtil::eiFOLDER_BLUE), QDir(t).dirName(), down_to);
             act->setToolTip(t);
             act->setData(t);
@@ -304,48 +304,32 @@ SearchFrame::Menu::Action SearchFrame::Menu::exec(QStringList list = QStringList
     menu->insertMenu(action_list.at(5), magnet_menu);
     menu->insertMenu(action_list.at(12),black_list_menu);
 
-    QMenu *userm = buildUserCmdMenu(list);
+    QScopedPointer<QMenu> userm(buildUserCmdMenu(list));
 
-    if (userm)
-        if (!userm->actions().isEmpty())
-            menu->addMenu(userm);
+    if (!userm.isNull() && !userm->actions().isEmpty())
+        menu->addMenu(userm.data());
 
     QAction *ret = menu->exec(QCursor::pos());
 
-    if (actions.contains(ret)){
-        delete userm;
-
+    if (actions.contains(ret)) {
         return actions.value(ret);
-    }
-    else if (down_to->actions().contains(ret)){
+    } else if (down_to->actions().contains(ret)) {
         downToPath = ret->data().toString();
-
         return DownloadTo;
-    }
-    else if (down_wh_to->actions().contains(ret)){
+    } else if (down_wh_to->actions().contains(ret)) {
         downToPath = ret->data().toString();
-
         return DownloadWholeDirTo;
-    }
-    else if (ret){
-        ucParams["LAST"] = ret->toolTip();
-        ucParams["NAME"] = ret->statusTip();
-        ucParams["HOST"] =  ret->data().toString();
-
-        delete userm;
-
+    } else if (ret && ret->data().canConvert(QVariant::Int)) {
+        uc_cmd_id = ret->data().toInt();
         return UserCommands;
-    }
-    else{
-        delete userm;
-
+    } else {
         return None;
     }
 }
 
 QMenu *SearchFrame::Menu::buildUserCmdMenu(QList<QString> hub_list){
     if (hub_list.empty())
-        return NULL;
+        return nullptr;
 
     return WulforUtil::getInstance()->buildUserCmdMenu(hub_list, UserCommand::CONTEXT_SEARCH);
 }
@@ -365,15 +349,15 @@ SearchFrame::SearchFrame(QWidget *parent): QWidget(parent), d_ptr(new SearchFram
     Q_D(SearchFrame);
 
     d->isHash = false;
-    d->arena_menu = NULL;
-    d->timer = NULL;
+    d->arena_menu = nullptr;
+    d->timer = nullptr;
     d->dropped = 0L;
     d->results = 0L;
     d->filterShared = SearchFrame::None;
     d->withFreeSlots = false;
     d->saveFileType = true;
-    d->proxy = NULL;
-    d->completer = NULL;
+    d->proxy = nullptr;
+    d->completer = nullptr;
     d->stop = false;
     d->arena_title = tr("Search");
     d->searchStartTime = 0;
@@ -386,17 +370,11 @@ SearchFrame::SearchFrame(QWidget *parent): QWidget(parent), d_ptr(new SearchFram
 
     ClientManager* clientMgr = ClientManager::getInstance();
 
-#ifdef DO_NOT_USE_MUTEX
-    clientMgr->lock();
-#else // DO_NOT_USE_MUTEX
     auto lock = clientMgr->lock();
-#endif // DO_NOT_USE_MUTEX
     clientMgr->addListener(this);
     Client::List& clients = clientMgr->getClients();
 
-    for (auto it = clients.begin(); it != clients.end(); ++it) {
-        Client* client = *it;
-
+    for (const auto &client : clients) {
         if(!client->isConnected())
             continue;
 
@@ -404,9 +382,13 @@ SearchFrame::SearchFrame(QWidget *parent): QWidget(parent), d_ptr(new SearchFram
         d->client_list.push_back(client);
     }
 
-#ifdef DO_NOT_USE_MUTEX
-    clientMgr->unlock();
-#endif // DO_NOT_USE_MUTEX
+#if defined(USE_PROGRESS_BARS)
+    progressBar->show();
+    progressIndicator->hide();
+#else
+    progressBar->hide();
+    progressIndicator->show();
+#endif
 
     d->str_model->setStringList(d->hubs);
 
@@ -422,7 +404,7 @@ SearchFrame::~SearchFrame(){
 
     Q_D(SearchFrame);
 
-    treeView_RESULTS->setModel(NULL);
+    treeView_RESULTS->setModel(nullptr);
 
     if (d->completer)
         d->completer->deleteLater();
@@ -451,7 +433,7 @@ void SearchFrame::closeEvent(QCloseEvent *e){
 
     setAttribute(Qt::WA_DeleteOnClose);
 
-    QWidget::disconnect(this, NULL, this, NULL);
+    QWidget::disconnect(this, nullptr, this, nullptr);
 
     e->accept();
 }
@@ -475,7 +457,7 @@ bool SearchFrame::eventFilter(QObject *obj, QEvent *e){
 void SearchFrame::init(){
     Q_D(SearchFrame);
 
-    d->model = new SearchModel(NULL);
+    d->model = new SearchModel(nullptr);
     d->str_model = new SearchStringListModel(this);
 
     for (int i = 0; i < d->model->columnCount(); i++)
@@ -507,9 +489,9 @@ void SearchFrame::init(){
     }
 
     // Customs
-    for (SettingsManager::SearchTypesIterC i = searchTypes.begin(), iend = searchTypes.end(); i != iend; ++i)
+    for (const auto &i : searchTypes)
     {
-        string type = i->first;
+        string type = i.first;
         if (!(type.size() == 1 && type[0] >= '1' && type[0] <= '7'))
         {
                 filetypes << _q(type);
@@ -527,12 +509,12 @@ void SearchFrame::init(){
     for (int i = 0; i < icons.size(); i++)
         comboBox_FILETYPES->setItemIcon(i, WICON(icons.at(i)));
 
-    QString     raw  = QByteArray::fromBase64(WSGET(WS_SEARCH_HISTORY).toAscii());
+    QString     raw  = QByteArray::fromBase64(WSGET(WS_SEARCH_HISTORY).toUtf8());
     d->searchHistory = raw.replace("\r","").split('\n', QString::SkipEmptyParts);
 
     QMenu *m = new QMenu();
 
-    foreach (const QString &s, d->searchHistory)
+    for (const auto &s : d->searchHistory)
         m->addAction(s);
 
     d->focusShortcut = new QShortcut(QKeySequence(Qt::Key_F6), this);
@@ -582,7 +564,7 @@ void SearchFrame::init(){
 void SearchFrame::load(){
     Q_D(SearchFrame);
 
-    treeView_RESULTS->header()->restoreState(QByteArray::fromBase64(WSGET(WS_SEARCH_STATE).toAscii()));
+    treeView_RESULTS->header()->restoreState(QByteArray::fromBase64(WSGET(WS_SEARCH_STATE).toUtf8()));
     treeView_RESULTS->setSortingEnabled(true);
 
     d->filterShared = static_cast<SearchFrame::AlreadySharedAction>(WIGET(WI_SEARCH_SHARED_ACTION));
@@ -596,7 +578,7 @@ void SearchFrame::load(){
 
     treeView_RESULTS->sortByColumn(WIGET(WI_SEARCH_SORT_COLUMN), WulforUtil::getInstance()->intToSortOrder(WIGET(WI_SEARCH_SORT_ORDER)));
 
-    QString raw = QByteArray::fromBase64(WSGET(WS_SEARCH_HISTORY).toAscii());
+    QString raw = QByteArray::fromBase64(WSGET(WS_SEARCH_HISTORY).toUtf8());
     QStringList list = raw.replace("\r","").split('\n', QString::SkipEmptyParts);
 
     d->completer = new QCompleter(list, lineEdit_SEARCHSTR);
@@ -876,7 +858,7 @@ bool SearchFrame::getWholeDirParams(SearchFrame::VarMap &params, SearchItem *ite
     return true;
 }
 
-void SearchFrame::addResult(const QMap<QString, QVariant> &map){
+void SearchFrame::addResult(const QVariantMap &map){
     Q_D(SearchFrame);
     static SearchBlacklist *SB = SearchBlacklist::getInstance();
 
@@ -994,7 +976,10 @@ void SearchFrame::slotStartSearch(){
 
     quint64 llsize = (quint64)lsize;
 
-    if (!d->searchHistory.contains(s)){
+    {
+        if (d->searchHistory.contains(s))
+            d->searchHistory.removeAt(d->searchHistory.indexOf(s));
+
         bool isTTH = WulforUtil::isTTH(s);
 
         if ((WBGET("memorize-tth-search-phrases", false) && isTTH) || !isTTH)
@@ -1002,24 +987,24 @@ void SearchFrame::slotStartSearch(){
 
         QMenu *m = new QMenu();
 
-        foreach (const QString &s, d->searchHistory)
+        for (const auto &s : d->searchHistory)
             m->addAction(s);
 
         lineEdit_SEARCHSTR->setMenu(m);
 
-        uint maxItemsNumber = WIGET("search-history-items-number", 10);
+        const int maxItemsNumber = WIGET("search-history-items-number", 10);
         while (d->searchHistory.count() > maxItemsNumber)
-                d->searchHistory.removeLast();
+            d->searchHistory.removeLast();
 
         QString hist = d->searchHistory.join("\n");
-        WSSET(WS_SEARCH_HISTORY, hist.toAscii().toBase64());
+        WSSET(WS_SEARCH_HISTORY, hist.toUtf8().toBase64());
     }
 
     {
-        d->currentSearch = StringTokenizer<tstring>(s.toStdString(), ' ').getTokens();
+        d->currentSearch = StringTokenizer<string>(s.toStdString(), ' ').getTokens();
         s = "";
 
-        //strip out terms beginning with -
+        // strip out terms beginning with -
         for (auto si = d->currentSearch.begin(); si != d->currentSearch.end(); ) {
             if(si->empty()) {
                 si = d->currentSearch.erase(si);
@@ -1037,7 +1022,7 @@ void SearchFrame::slotStartSearch(){
 
     SearchManager::SizeModes searchMode((SearchManager::SizeModes)comboBox_SIZETYPE->currentIndex());
 
-    if(!llsize || lineEdit_SIZE->text() == "")
+    if(!llsize || lineEdit_SIZE->text().isEmpty())
         searchMode = SearchManager::SIZE_DONTCARE;
 
     int ftype = comboBox_FILETYPES->currentIndex();
@@ -1078,7 +1063,7 @@ void SearchFrame::slotStartSearch(){
     d->target = s;
     d->searchStartTime = GlobalTimer::getInstance()->getTicks()*1000;
 
-    uint64_t maxDelayBeforeSearch = SearchManager::getInstance()->search(clients, s.toStdString(), llsize, (SearchManager::TypeModes)ftype, searchMode, d->token.toStdString(), exts, (void*)this);
+    uint64_t maxDelayBeforeSearch = SearchManager::getInstance()->search(clients, s.toStdString(), llsize, SearchManager::TypeModes(ftype), searchMode, d->token.toStdString(), exts, (void*)this);
     uint64_t waitingResultsTime = 20000; // just assumption that user receives most of results in 20 seconds
 
     d->searchEndTime = d->searchStartTime + maxDelayBeforeSearch + waitingResultsTime;
@@ -1131,7 +1116,7 @@ void SearchFrame::slotResultDoubleClicked(const QModelIndex &index){
         if (item->childCount() > 0 && !SETTING(DONT_DL_ALREADY_QUEUED)){//download all child items
             QString fname = params["FNAME"].toString();
 
-            foreach (SearchItem *i, item->childItems){
+            for (const auto &i : item->childItems){
                 if (getDownloadParams(params, i)){
                     params["FNAME"] = fname;
 
@@ -1158,7 +1143,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
     QStringList hubs;
 
-    foreach (const QModelIndex &i, list){
+    for (const auto &i : list){
         SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
         QString host = item->data(COLUMN_SF_HOST).toString();
 
@@ -1175,7 +1160,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::Download:
         {
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1185,7 +1170,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
                     if (item->childCount() > 0 && !SETTING(DONT_DL_ALREADY_QUEUED)){//download all child items
                         QString fname = params["FNAME"].toString();
 
-                        foreach (SearchItem *i, item->childItems){
+                        for (const auto &i : item->childItems){
                             if (getDownloadParams(params, i)){
                                 params["FNAME"] = fname;
 
@@ -1219,7 +1204,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
             old_target = target;
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1230,7 +1215,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
                     if (item->childCount() > 0 && !SETTING(DONT_DL_ALREADY_QUEUED)){//download all child items
                         QString fname = params["FNAME"].toString();
 
-                        foreach (SearchItem *i, item->childItems){
+                        for (const auto  &i : item->childItems){
                             if (getDownloadParams(params, i)){
                                 params["FNAME"]  = fname;
                                 params["TARGET"] = target;
@@ -1246,7 +1231,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::DownloadWholeDir:
         {
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1277,7 +1262,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
             old_target = target;
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1291,7 +1276,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::SearchTTH:
         {
-            foreach (QModelIndex i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only one file
@@ -1310,13 +1295,13 @@ void SearchFrame::slotContextMenu(const QPoint &){
             QString magnets = "";
             WulforUtil *WU = WulforUtil::getInstance();
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only files
-                    qlonglong size = item->data(COLUMN_SF_ESIZE).toLongLong();
-                    QString tth = item->data(COLUMN_SF_TTH).toString();
-                    QString name = item->data(COLUMN_SF_FILENAME).toString();
+                    const qlonglong size = item->data(COLUMN_SF_ESIZE).toLongLong();
+                    const QString tth = item->data(COLUMN_SF_TTH).toString();
+                    const QString name = item->data(COLUMN_SF_FILENAME).toString().trimmed();
 
                     QString magnet = WU->makeMagnet(name, size, tth);
 
@@ -1337,13 +1322,13 @@ void SearchFrame::slotContextMenu(const QPoint &){
             QString magnets = "";
             WulforUtil *WU = WulforUtil::getInstance();
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only files
-                    qlonglong size = item->data(COLUMN_SF_ESIZE).toLongLong();
-                    QString tth = item->data(COLUMN_SF_TTH).toString();
-                    QString name = item->data(COLUMN_SF_FILENAME).toString();
+                    const qlonglong size = item->data(COLUMN_SF_ESIZE).toLongLong();
+                    const QString tth = item->data(COLUMN_SF_TTH).toString();
+                    const QString name = item->data(COLUMN_SF_FILENAME).toString().trimmed();
 
                     QString magnet = "[magnet=\"" + WU->makeMagnet(name, size, tth) + "\"]"+name+"[/magnet]";
 
@@ -1363,19 +1348,18 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
             WulforUtil *WU = WulforUtil::getInstance();
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only files
-                    qlonglong size = item->data(COLUMN_SF_ESIZE).toLongLong();
-                    QString tth = item->data(COLUMN_SF_TTH).toString();
-                    QString name = item->data(COLUMN_SF_FILENAME).toString();
-
-                    QString magnet = WU->makeMagnet(name, size, tth);
+                    const qlonglong size = item->data(COLUMN_SF_ESIZE).toLongLong();
+                    const QString &&tth = item->data(COLUMN_SF_TTH).toString();
+                    const QString &&name = item->data(COLUMN_SF_FILENAME).toString().trimmed();
+                    const QString &&magnet = WU->makeMagnet(name, size, tth);
 
                     if (!magnet.isEmpty()){
                         Magnet m(this);
-                        m.setLink(magnet + "\n");
+                        m.setLink(magnet, Magnet::MAGNET_ACTION_SHOW_UI);
                         m.exec();
                     }
                 }
@@ -1385,7 +1369,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::Browse:
         {
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1397,7 +1381,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::MatchQueue:
         {
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1411,9 +1395,9 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::SendPM:
         {
-            HubFrame *fr = NULL;
+            HubFrame *fr = nullptr;
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 QString hubUrl = item->data(COLUMN_SF_HOST).toString();
@@ -1429,7 +1413,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::AddToFav:
         {
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1442,7 +1426,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::GrantExtraSlot:
         {
-             foreach (const QModelIndex &i, list){
+             for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1455,7 +1439,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::RemoveFromQueue:
         {
-             foreach (const QModelIndex &i, list){
+             for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1470,7 +1454,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
              selection_model->clearSelection();
 
-             foreach (const QModelIndex &i, list){
+             for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 d->model->removeItem(item);
@@ -1482,15 +1466,12 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::UserCommands:
         {
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
-                QString cmd_name = Menu::getInstance()->ucParams["NAME"];
-                QString hub      = Menu::getInstance()->ucParams["HOST"];
-                QString last_user_cmd = Menu::getInstance()->ucParams["LAST"];
 
-                int id = FavoriteManager::getInstance()->findUserCommand(cmd_name.toStdString(), hub.toStdString());
+                int id = Menu::getInstance()->getCommandId();
+
                 UserCommand uc;
-
                 if (id == -1 || !FavoriteManager::getInstance()->getUserCommand(id, uc))
                     break;
 
@@ -1513,7 +1494,9 @@ void SearchFrame::slotContextMenu(const QPoint &){
                         params["filesizeshort"] = params["fileSIshort"];
                         params["tth"] = params["fileTR"];
 
-                        ClientManager::getInstance()->userCommand(HintedUser(user, _tq(hub)), uc, params, true);
+                        string hubUrl = _tq(i.data(COLUMN_SF_HOST).toString());
+
+                        ClientManager::getInstance()->userCommand(HintedUser(user, hubUrl), uc, params, true);
                     }
 
                 }
@@ -1533,7 +1516,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
             QList <QString> new_inst;
 
-            foreach (const QModelIndex &i, list){
+            for (const auto &i : list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1570,13 +1553,24 @@ void SearchFrame::slotTimer(){
             fraction = 100.0;
             d->waitingResults = false;
         }
-        QString msg = tr("Searching for %1 ...").arg(d->target);
+#if defined(USE_PROGRESS_BARS)
+        const QString msg = tr("Searching for %1 ...").arg(d->target);
         progressBar->setFormat(msg);
         progressBar->setValue(static_cast<unsigned>(fraction));
-    } else {
-        QString msg = "";
-        progressBar->setFormat(msg);
+#else
+        const QString msg = tr("Search progress of \"%1\" is %2\%")
+                .arg(d->target)
+                .arg(QString::number(fraction, 'f', 1));
+        progressIndicator->setText(msg);
+#endif
+    }
+    else {
+#if defined(USE_PROGRESS_BARS)
+        progressBar->setFormat(QString());
         progressBar->setValue(0);
+#else
+        progressIndicator->clear();
+#endif
         lineEdit_SEARCHSTR->setEnabled(true);
     }
 
@@ -1661,6 +1655,7 @@ void SearchFrame::slotChangeProxyColumn(int col){
 }
 
 void SearchFrame::slotSettingsChanged(const QString &key, const QString &value){
+    Q_UNUSED(value)
     if (key == WS_TRANSLATION_FILE)
         retranslateUi(this);
 }
@@ -1685,9 +1680,9 @@ void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aRe
         }
     }
     else {
-        for(TStringIter j = d->currentSearch.begin(); j != d->currentSearch.end(); ++j) {
-            if((*j->begin() != ('-') && Util::findSubString(aResult->getFile(), *j) == tstring::npos) ||
-               (*j->begin() == ('-') && j->size() != 1 && Util::findSubString(aResult->getFile(), j->substr(1)) != tstring::npos)
+        for (const auto &j : d->currentSearch) {
+            if((*j.begin() != ('-') && Util::findSubString(aResult->getFile(), j) == string::npos) ||
+               (*j.begin() == ('-') && j.size() != 1 && Util::findSubString(aResult->getFile(), j.substr(1)) != string::npos)
               )
            {
                     d->dropped++;
@@ -1713,7 +1708,7 @@ void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aRe
         return;
     }
 
-    QMap<QString, QVariant> map;
+    QVariantMap map;
     getParams(map, aResult);
 
     emit coreSR(map);
