@@ -6,8 +6,12 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
+
 #include <QFileInfo>
 #include <QList>
 #include <QStringList>
@@ -25,17 +29,12 @@
 #include "dcpp/CID.h"
 #include "dcpp/ShareManager.h"
 
-//#define _DEBUG_MODEL_
-
-
-#include <QtDebug>
-
-using namespace dcpp;
-
-#ifdef _DEBUG_MODEL_
+#ifdef _DEBUG_QT_UI
 #include <QtDebug>
 #endif
 
+using namespace dcpp;
+
 void SearchProxyModel::sort(int column, Qt::SortOrder order){
     if (sourceModel())
         sourceModel()->sort(column, order);
@@ -49,7 +48,7 @@ SearchModel::SearchModel(QObject *parent):
 {
     QList<QVariant> rootData;
     rootData << tr("Count") << tr("File") << tr("Ext") << tr("Size")
-             << tr("Exact size") << tr("TTH")   << tr("Path") << tr("Nick")
+             << tr("Exact size") << QString("TTH")   << tr("Path") << tr("Nick")
              << tr("Free slots") << tr("Total slots")
              << tr("IP") << tr("Hub") << tr("Host");
 
@@ -148,7 +147,7 @@ void SearchModel::repaint(){
 Qt::ItemFlags SearchModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
@@ -226,21 +225,21 @@ namespace {
 template <Qt::SortOrder order>
 struct Compare {
     typedef bool (*AttrComp)(const SearchItem * l, const SearchItem * r);
-    
+
     void static sort(unsigned column, QList<SearchItem*>& items) {
         if (column > COLUMN_SF_HOST)
             return;
-        
-        qStableSort(items.begin(), items.end(), attrs[column]);
+
+        std::stable_sort(items.begin(), items.end(), attrs[column]);
     }
 
     QList<SearchItem*>::iterator static insertSorted(unsigned column, QList<SearchItem*>& items, SearchItem* item) {
         if (column > COLUMN_SF_HOST)
             return items.end();
-        
-        return qLowerBound(items.begin(), 
-                           items.end(), 
-                           item, 
+
+        return std::lower_bound(items.begin(),
+                           items.end(),
+                           item,
                            attrs[column]
                           );
     }
@@ -260,7 +259,7 @@ struct Compare {
         }
         template <typename T>
         bool static Cmp(const T& l, const T& r);
-        
+
         static AttrComp attrs[13];
 };
 
@@ -317,7 +316,7 @@ void SearchModel::sort(int column, Qt::SortOrder order) {
     emit layoutChanged();
 }
 
-bool SearchModel::addResultPtr(const QMap<QString, QVariant> &map){
+bool SearchModel::addResultPtr(const QVariantMap &map){
     try {
         return addResult(map["FILE"].toString(),
                   map["SIZE"].toULongLong(),
@@ -332,7 +331,7 @@ bool SearchModel::addResultPtr(const QMap<QString, QVariant> &map){
                   map["CID"].toString(),
                   map["ISDIR"].toBool());
     }
-    catch (SearchListException){
+    catch (SearchListException &) {
         return false;
     }
 }
@@ -367,7 +366,7 @@ bool SearchModel::addResult
     if (size > 0)
         ext = file_info.suffix().toUpper();
 
-    SearchItem * parent = NULL;
+    SearchItem * parent = nullptr;
 
     if (!isDir && tths.contains(tth)) {
         parent = tths[tth];
@@ -456,6 +455,11 @@ void SearchModel::clearModel(){
     reset();
 }
 
+void SearchModel::reset() {
+    beginResetModel();
+    endResetModel();
+}
+
 void SearchModel::removeItem(const SearchItem *item){
     if (!okToFind(item))
         return;
@@ -488,13 +492,14 @@ bool SearchModel::okToFind(const SearchItem *item){
 
         SearchItem *tth_root = tths.value(tth);//try to find item by tth
 
-        foreach (SearchItem *i, tth_root->childItems){
+        for (const auto &i : tth_root->childItems){
             if (item == i)
                 return true;
         }
     }
-    else
+    else {
         return true;
+    }
 
     return false;
 }
@@ -510,6 +515,7 @@ SearchItem::SearchItem(const QList<QVariant> &data, SearchItem *parent) :
 SearchItem::~SearchItem()
 {
     qDeleteAll(childItems);
+    childItems.clear();
 }
 
 void SearchItem::appendChild(SearchItem *item) {
@@ -551,7 +557,7 @@ bool SearchItem::exists(const QString &user_cid) const {
     if (childItems.isEmpty())
         return cid == user_cid;
 
-    foreach(SearchItem *child, childItems) {
+    for (const auto &child : childItems) {
         if (child->cid == user_cid)
             return true;
     }
