@@ -13,6 +13,7 @@
 #include <QListWidget>
 #include <QListWidgetItem>
 #include <QMap>
+#include <QScrollArea>
 
 #include "ui_UISettings.h"
 
@@ -34,7 +35,8 @@ public:
         Logs,
         UserCommands,
         Shortcuts,
-        History
+        History,
+        Advanced
     };
 
     Settings();
@@ -51,6 +53,9 @@ private slots:
 private:
     void init();
 
+    inline void setMouseScroller(QWidget *w);
+    inline QWidget *prepareWidget(QWidget *w);
+
     WidgetMap widgets;
     bool is_dirty;
 };
