@@ -23,7 +23,7 @@ class SettingsConnection :
 {
     Q_OBJECT
 public:
-    SettingsConnection(QWidget* = NULL);
+    SettingsConnection(QWidget* = nullptr);
 
 public slots:
     void ok();
@@ -39,9 +39,13 @@ private:
     void init();
 
     bool validateIp(QString&);
-    void showMsg(QString, QWidget* = NULL);
+    void showMsg(QString, QWidget* = nullptr);
 
     bool dirty;
 
-    int old_tcp, old_udp, old_tls, old_dht;
+    int old_tcp, old_udp, old_tls
+#ifdef WITH_DHT
+        , old_dht
+#endif
+        ;
 };
