@@ -37,7 +37,7 @@ SettingsSharing::SettingsSharing(QWidget *parent):
 {
     setupUi(this);
 
-    model = NULL;
+    model = nullptr;
 
     init();
 }
@@ -71,6 +71,7 @@ void SettingsSharing::ok(){
     SM->set(SettingsManager::HASH_BUFFER_POPULATE, checkBox_MAPPOPULATE->isChecked());
     SM->set(SettingsManager::HASH_BUFFER_PRIVATE, checkBox_MAPPRIVATE->isChecked());
     SM->set(SettingsManager::HASH_BUFFER_SIZE_MB, comboBox_BUFSIZE->currentText().toInt());
+    SM->set(SettingsManager::SHARE_SKIP_ZERO_BYTE, checkBox_SHARE_SKIP_ZERO_BYTE->isChecked());
 
     QStringList list;
     for (int k = 0; k < listWidget_SKIPLIST->count(); ++k)
@@ -108,7 +109,7 @@ void SettingsSharing::init(){
     spinBox_REFRESH_TIME->setValue(SETTING(AUTO_REFRESH_TIME));
     spinBox_HASHING_START_DELAY->setValue(SETTING(HASHING_START_DELAY));
     checkBox_AUTOREMOVE->setChecked(WBGET(WB_APP_REMOVE_NOT_EX_DIRS));
-
+    checkBox_SHARE_SKIP_ZERO_BYTE->setChecked(BOOLSETTING(SHARE_SKIP_ZERO_BYTE));
     checkBox_FASTHASH->setChecked(BOOLSETTING(FAST_HASH));
     groupBox_FASTHASH->setEnabled(BOOLSETTING(FAST_HASH));
 
@@ -151,13 +152,13 @@ void SettingsSharing::updateShareView(){
         treeWidget_SIMPLE_MODE->clear();
 
         StringPairList directories = ShareManager::getInstance()->getDirectories();
-        for (auto it = directories.begin(); it != directories.end(); ++it){
+        for (const auto &pair : directories){
             QTreeWidgetItem *item = new QTreeWidgetItem(treeWidget_SIMPLE_MODE);
 
-            item->setText(0, it->second.c_str());
-            item->setText(1, it->first.c_str());
-            item->setText(2, Util::formatBytes(ShareManager::getInstance()->getShareSize(it->second)).c_str());
-            item->setText(3, QString().setNum(ShareManager::getInstance()->getShareSize(it->second)));
+            item->setText(0, pair.second.c_str());
+            item->setText(1, pair.first.c_str());
+            item->setText(2, Util::formatBytes(ShareManager::getInstance()->getShareSize(pair.second)).c_str());
+            item->setText(3, QString().setNum(ShareManager::getInstance()->getShareSize(pair.second)));
         }
     }
 
@@ -262,7 +263,7 @@ void SettingsSharing::slotSimpleShareModeChanged(){
             treeView->header()->hideSection(2);
 
             if (!WSGET(WS_SHAREHEADER_STATE).isEmpty())
-                treeView->header()->restoreState(QByteArray::fromBase64(WSGET(WS_SHAREHEADER_STATE).toAscii()));
+                treeView->header()->restoreState(QByteArray::fromBase64(WSGET(WS_SHAREHEADER_STATE).toUtf8()));
 
             connect(model, SIGNAL(getName(QModelIndex)), this, SLOT(slotGetName(QModelIndex)));
             connect(model, SIGNAL(expandMe(QModelIndex)), treeView, SLOT(expand(QModelIndex)));
@@ -274,7 +275,7 @@ void SettingsSharing::slotSimpleShareModeChanged(){
         }
     }
     else{
-        treeWidget_SIMPLE_MODE->header()->restoreState(QByteArray::fromBase64((WSGET("settings-simple-share-headerstate").toAscii())));
+        treeWidget_SIMPLE_MODE->header()->restoreState(QByteArray::fromBase64((WSGET("settings-simple-share-headerstate").toUtf8())));
 
         updateShareView();
     }
@@ -282,8 +283,8 @@ void SettingsSharing::slotSimpleShareModeChanged(){
 
 void SettingsSharing::slotContextMenu(const QPoint &){
     QList<QTreeWidgetItem*> selected = treeWidget_SIMPLE_MODE->selectedItems();
-    QMenu *menu = new QMenu();
-    QAction *add_new = NULL, *rem = NULL, *rename = NULL;
+    QMenu *menu = new QMenu(nullptr);
+    QAction *add_new = nullptr, *rem = nullptr, *rename = nullptr;
     WulforUtil *WU = WulforUtil::getInstance();
 
     add_new = new QAction(WU->getPixmap(WulforUtil::eiEDITADD), tr("Add"), menu);
@@ -350,7 +351,7 @@ void SettingsSharing::slotContextMenu(const QPoint &){
         item->setText(3, "");
     }
     else if (res == rem){
-        foreach(QTreeWidgetItem *i, selected)
+        for (const auto &i : selected)
             ShareManager::getInstance()->removeDirectory(i->text(0).toStdString());
     }
     else if (res == rename){
@@ -391,8 +392,8 @@ ShareDirModel::ShareDirModel(QObject *parent){
     QDirModel::setFilter((QDir::AllDirs | QDir::NoDotAndDotDot));
 
     StringPairList directories = ShareManager::getInstance()->getDirectories();
-    for (auto it = directories.begin(); it != directories.end(); ++it){
-        QString path = it->second.c_str();
+    for (const auto &pair : directories){
+        QString path = pair.second.c_str();
 
         if (path.endsWith(QDir::separator()))
             path = path.left(path.lastIndexOf(QDir::separator()));
@@ -415,7 +416,7 @@ Qt::ItemFlags ShareDirModel::flags(const QModelIndex& index) const{
 
     QString fp = filePath(index);
 
-    foreach (const QString &file, checked){
+    for (const QString &file : checked){
         if (fp.startsWith(file) && (fp.split(QDir::separator()).length() != file.split(QDir::separator()).length()) && fp != file){
             f &= ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
 
@@ -436,7 +437,7 @@ QVariant ShareDirModel::data(const QModelIndex& index, int role = Qt::DisplayRol
         case Qt::CheckStateRole:
         {
             if (!index.column()){
-                foreach (const QString &f, checked){
+                for (const QString &f : checked){
                     if (fp.startsWith(f) && fp.length() == f.length())
                         return Qt::Checked;
                 }
@@ -448,7 +449,7 @@ QVariant ShareDirModel::data(const QModelIndex& index, int role = Qt::DisplayRol
         }
         case Qt::ForegroundRole:
         {
-            /*foreach (QString f, checked){
+            /*for (const auto &f : checked){
                 if (f.startsWith(fp))
                     return QColor(0x1F, 0x8F, 0x1F);
             }*/
@@ -461,7 +462,7 @@ QVariant ShareDirModel::data(const QModelIndex& index, int role = Qt::DisplayRol
                 static QFont font;
                 font.setBold(true);
 
-                foreach (const QString &f, checked){
+                for (const QString &f : checked){
                     if (f == fp)
                         return font;
                 }
@@ -536,7 +537,7 @@ void ShareDirModel::setAlias(const QModelIndex &index, const QString &alias){
 }
 
 void ShareDirModel::beginExpanding(){
-    foreach (const QString &f, checked){
+    for (const QString &f : checked){
         QStack<QModelIndex> stack;
         QModelIndex i = index(f);
 
