@@ -28,12 +28,16 @@ friend class dcpp::Singleton<SpellCheck>;
 public:
     bool ok(const QString &word);
     void suggestions(const QString &word, QStringList &list);
+    void setLanguage(const QString &lang);
     void addToDict(const QString &word);
 
 private:
-    SpellCheck(QObject *parent = 0);
+    SpellCheck(QObject *parent = nullptr);
     ~SpellCheck();
 
-    AspellConfig *config;
+    void deleteSpeller();
+    void loadAspellConfig(AspellConfig * const config);
+    AspellConfig *defaultAspellConfig();
+
     AspellSpeller *spell_checker;
 };
