@@ -9,6 +9,10 @@
 
 #include "SpyModel.h"
 
+#include "WulforUtil.h"
+#include "dcpp/stdinc.h"
+#include "dcpp/LogManager.h"
+
 #include <QtDebug>
 
 SpyModel::SpyModel(QObject *parent):
@@ -22,9 +26,7 @@ SpyModel::SpyModel(QObject *parent):
 
 SpyModel::~SpyModel()
 {
-    foreach(SpyItem *i, rootItem->childItems)
-        pool.destroy(i);
-
+    qDeleteAll(rootItem->childItems.begin(), rootItem->childItems.end());
     rootItem->childItems.clear();
 
     delete rootItem;
@@ -72,7 +74,7 @@ QVariant SpyModel::data(const QModelIndex &index, int role) const
 Qt::ItemFlags SpyModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
@@ -139,13 +141,13 @@ namespace {
 template <Qt::SortOrder order>
 struct Compare {
     void static sort(int col, QList<SpyItem*>& items) {
-        qStableSort(items.begin(), items.end(), getAttrComp(col));
+        std::stable_sort(items.begin(), items.end(), getAttrComp(col));
     }
 
     void static insertSorted(int col, QList<SpyItem*>& items, SpyItem* item) {
-        auto it = qLowerBound(items.begin(), items.end(), item, getAttrComp(col));
+        auto it = std::lower_bound(items.begin(), items.end(), item, getAttrComp(col));
         items.insert(it, item);
-#ifdef _DEBUG_MODEL_
+#ifdef _DEBUG_QT_UI
         qDebug() << "Item inserted at " << items.indexOf(*it) << " position";
 #endif
     }
@@ -215,7 +217,7 @@ void SpyModel::addResult(const QString &file, bool isTTH)
 {
     QString _temp;
 
-    foreach (const QChar &ch, file)
+    for (const QChar &ch : file)
         _temp += ((ch.isPrint() || ch == ' ')? ch : ' ');//remove all non-printable chars except space
 
     QString &_file = _temp;
@@ -224,7 +226,7 @@ void SpyModel::addResult(const QString &file, bool isTTH)
         return;
 
     SpyItem *item;
-    SpyItem * parent = NULL;
+    SpyItem *parent = nullptr;
 
     if (hashes.contains(_file))
         parent = hashes[_file];
@@ -234,20 +236,29 @@ void SpyModel::addResult(const QString &file, bool isTTH)
     QList<QVariant> item_data;
 
     item_data << "" << _file;
-    item = pool.construct(item_data, parent);
+    item = new SpyItem(item_data, parent);
 
     item->isTTH = isTTH;
 
     if (parent == rootItem)
         hashes.insert(_file, item);
 
-    if(parent != rootItem){
+    if (parent != rootItem){
         parent->appendChild(item);
         rootItem->moveUp(parent);
-    }else{
+    } else {
         parent->insertChild(item, 0);
     }
 
+    static const auto _zero_up = [](const uint &i) { return (i? i : (uint)1); };
+
+    if (BOOLSETTING(LOG_SPY)){
+        dcpp::StringMap params;
+        params["message"] = _tq(item->data(1).toString());
+        params["count"] = _tq(QString::number(_zero_up(parent->data(0).toUInt())));
+        LOG(LogManager::SPY, params);
+    }
+
     if(isSort)
         sort();
 
@@ -255,11 +266,8 @@ void SpyModel::addResult(const QString &file, bool isTTH)
 }
 
 void SpyModel::clearModel(){
-    QList<SpyItem*> &childs = rootItem->childItems;
-
-    foreach(SpyItem *i, childs)
-        pool.destroy(i);
 
+    qDeleteAll(rootItem->childItems.begin(), rootItem->childItems.end());
     rootItem->childItems.clear();
 
     hashes.clear();
@@ -269,6 +277,11 @@ void SpyModel::clearModel(){
     emit layoutChanged();
 }
 
+void SpyModel::reset() {
+    beginResetModel();
+    endResetModel();
+}
+
 void SpyModel::setSort(bool sort){
     isSort = sort;
 }
