@@ -16,7 +16,6 @@
 #include "Notification.h"
 #include "SearchFrame.h"
 #include "DownloadQueue.h"
-#include "IPFilter.h"
 #include "ArenaWidgetFactory.h"
 
 #include "dcpp/Util.h"
@@ -31,6 +30,8 @@
 #include "dcpp/FavoriteManager.h"
 #include "dcpp/HashManager.h"
 
+#include "extra/ipfilter.h"
+
 #include <QItemSelectionModel>
 #include <QModelIndex>
 #include <QClipboard>
@@ -38,12 +39,10 @@
 #include <QFileInfo>
 #include <QDir>
 
-TransferView::Menu::Menu():
-        menu(NULL),
-        selectedColumn(0)
+TransferView::Menu::Menu(bool showTransferredFilesOnly):
+        menu(new QMenu(nullptr)), selectedColumn(0)
 {
     WulforUtil *WU = WulforUtil::getInstance();
-    menu = new QMenu();
 
     QAction *browse     = new QAction(tr("Browse files"), menu);
     browse->setIcon(WU->getPixmap(WulforUtil::eiFOLDER_BLUE));
@@ -73,7 +72,7 @@ TransferView::Menu::Menu():
     copy_column->addAction(tr("Size"));
     copy_column->addAction(tr("Time left"));
     copy_column->addAction(tr("Filename"));
-    copy_column->addAction(tr("Host"));
+    copy_column->addAction(tr("Hub"));
     copy_column->addAction(tr("IP"));
     copy_column->addAction(tr("Encryption"));
     copy_column->addAction(tr("Magnet"));
@@ -93,6 +92,10 @@ TransferView::Menu::Menu():
     QAction *close = new QAction(tr("Close connection(s)"), menu);
     close->setIcon(WU->getPixmap(WulforUtil::eiCONNECT_NO));
 
+    QAction *show_only_transferred_files = new QAction(tr("Show only transferred files"), menu);
+    show_only_transferred_files->setCheckable(true);
+    show_only_transferred_files->setChecked(showTransferredFilesOnly);
+
     actions.insert(browse, Browse);
     actions.insert(match, MatchQueue);
     actions.insert(send_pm, SendPM);
@@ -102,6 +105,7 @@ TransferView::Menu::Menu():
     actions.insert(force, Force);
     actions.insert(close, Close);
     actions.insert(search, SearchAlternates);
+    actions.insert(show_only_transferred_files, showTransferredFieldsOnly);
 
     menu->addActions(QList<QAction*>() << browse
                                        << search
@@ -115,6 +119,7 @@ TransferView::Menu::Menu():
                                        << sep3
                                        << force
                                        << close
+                                       << show_only_transferred_files
                                        );
 }
 
@@ -139,7 +144,7 @@ TransferView::Menu::Action TransferView::Menu::exec(){
 
 TransferView::TransferView(QWidget *parent):
         QWidget(parent),
-        model(NULL)
+        model(nullptr)
 {
     setupUi(this);
 
@@ -191,7 +196,7 @@ void TransferView::load(){
     if (h >= 0)
         resize(this->width(), h);
 
-    treeView_TRANSFERS->header()->restoreState(QByteArray::fromBase64(WSGET(WS_TRANSFERS_STATE).toAscii()));
+    treeView_TRANSFERS->header()->restoreState(QByteArray::fromBase64(WSGET(WS_TRANSFERS_STATE).toUtf8()));
 }
 
 QSize TransferView::sizeHint() const{
@@ -380,7 +385,7 @@ void TransferView::getParams(TransferView::VarMap &params, const dcpp::Transfer
     if (trf->getType() == Transfer::TYPE_PARTIAL_LIST || trf->getType() == Transfer::TYPE_FULL_LIST)
         params["FNAME"] = tr("File list");
     else if (trf->getType() == Transfer::TYPE_TREE)
-        params["FNAME"] = tr("TTH: ") + _q(Util::getFileName(trf->getPath()));
+        params["FNAME"] = QString("TTH: ") + _q(Util::getFileName(trf->getPath()));
     else
         params["FNAME"] = _q(Util::getFileName(trf->getPath()));
 
@@ -423,7 +428,7 @@ void TransferView::slotContextMenu(const QPoint &){
         return;
 
     Menu::Action act;
-    Menu m;
+    Menu m(model->getShowTranferedFilesOnlyState());
 
     act = m.exec();
 
@@ -435,11 +440,11 @@ void TransferView::slotContextMenu(const QPoint &){
 
     QList<TransferViewItem*> items;
 
-    foreach (const QModelIndex &index, list){
+    for (const auto &index : list){
         TransferViewItem *i = reinterpret_cast<TransferViewItem*>(index.internalPointer());
 
         if (i->childCount() > 0){
-            foreach(TransferViewItem *child, i->childItems)
+            for (const auto &child : i->childItems)
                 items.append(child);
         }
         else if (!items.contains(i))
@@ -457,7 +462,7 @@ void TransferView::slotContextMenu(const QPoint &){
     }
     case Menu::Browse:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             getFileList(i->cid, vstr(i->data(COLUMN_TRANSFER_HOST)));
 
         break;
@@ -466,35 +471,33 @@ void TransferView::slotContextMenu(const QPoint &){
     {
         QStringList tths;
         QString tth_str = "";
-        std::for_each(items.begin(), items.end(), 
-                      [&](const TransferViewItem *item) {
-                          tth_str = getTTHFromItem(item);
-                          if (!tth_str.isEmpty() && !tths.contains(tth_str)){
-                            tths.push_back(tth_str);
-                            searchAlternates(tth_str);
-                          }
-                      }
-                     );
+        for (const auto &item : items) {
+            tth_str = getTTHFromItem(item);
+            if (!tth_str.isEmpty() && !tths.contains(tth_str)){
+                tths.push_back(tth_str);
+                searchAlternates(tth_str);
+            }
+        }
 
         break;
     }
     case Menu::MatchQueue:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             matchQueue(i->cid, vstr(i->data(COLUMN_TRANSFER_HOST)));
 
         break;
     }
     case Menu::AddToFav:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             addFavorite(i->cid);
 
         break;
     }
     case Menu::GrantExtraSlot:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             grantSlot(i->cid, vstr(i->data(COLUMN_TRANSFER_HOST)));
 
         break;
@@ -505,12 +508,12 @@ void TransferView::slotContextMenu(const QPoint &){
         QString data = "";
 
         if (col <= (model->columnCount()-1)){
-            foreach(TransferViewItem *i, items)
+            for (const auto &i : items)
                 data += i->data(col).toString() + "\n";
         }
         else {
             QString tth_str = "";
-            foreach(TransferViewItem *i, items){
+            for (const auto &i : items){
                 QFileInfo fi(i->target);
                 tth_str = getTTHFromItem(i);
 
@@ -534,30 +537,35 @@ void TransferView::slotContextMenu(const QPoint &){
     }
     case Menu::RemoveFromQueue:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             removeFromQueue(i->cid);
 
         break;
     }
     case Menu::Force:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             forceAttempt(i->cid);
 
         break;
     }
+    case Menu::showTransferredFieldsOnly:
+    {
+        model->setShowTranferedFilesOnlyState(!model->getShowTranferedFilesOnlyState());
+        break;
+    }
     case Menu::Close:
     {
-        foreach(TransferViewItem *i, items)
+        for (const auto &i : items)
             closeConection(i->cid, i->download);
 
         break;
     }
     case Menu::SendPM:
     {
-        HubFrame *fr = NULL;
+        HubFrame *fr = nullptr;
 
-        foreach(TransferViewItem *i, items){
+        for (const auto &i : items){
             dcpp::CID cid(_tq(i->cid));
             QString hubUrl = i->data(COLUMN_TRANSFER_HOST).toString();
 
@@ -584,7 +592,7 @@ void TransferView::on(dcpp::DownloadManagerListener::Requesting, dcpp::Download*
     getParams(params, dl);
 
     if (IPFilter::getInstance()){
-        if (!IPFilter::getInstance()->OK(vstr(params["IP"]), eDIRECTION_IN)){
+        if (!IPFilter::getInstance()->OK(vstr(params["IP"]).toStdString(), eDIRECTION_IN)){
             closeConection(vstr(params["CID"]), true);
             return;
         }
@@ -610,8 +618,8 @@ void TransferView::on(dcpp::DownloadManagerListener::Starting, dcpp::Download* d
 }
 
 void TransferView::on(dcpp::DownloadManagerListener::Tick, const dcpp::DownloadList& dls) noexcept{
-    for (auto it = dls.begin(); it != dls.end(); ++it){
-        Download* dl = *it;
+    for (const auto &it : dls){
+        Download* dl = it;
         VarMap params;
         QString str;
 
@@ -621,20 +629,20 @@ void TransferView::on(dcpp::DownloadManagerListener::Tick, const dcpp::DownloadL
         if (dl->getUserConnection().isSecure())
         {
             if (dl->getUserConnection().isTrusted())
-               str += tr("[S]");
+               str += QString("[S]");
             else
-               str += tr("[U]");
+               str += QString("[U]");
         }
 
         if (dl->isSet(Download::FLAG_TTH_CHECK))
-            str += tr("[T]");
+            str += QString("[T]");
         if (dl->isSet(Download::FLAG_ZDOWNLOAD))
-            str += tr("[Z]");
+            str += QString("[Z]");
         
         params["FLAGS"] = str;
 
         str = QString(tr("Downloaded %1")).arg(WulforUtil::formatBytes(dl->getPos()))
-            + QString(tr(" (%1%)")).arg(vdbl(params["PERC"]), 0, 'f', 1);
+            + QString(QString(" (%1%)")).arg(vdbl(params["PERC"]), 0, 'f', 1);
 
         params["STAT"] = str;
 
@@ -775,7 +783,7 @@ void TransferView::on(dcpp::UploadManagerListener::Starting, dcpp::Upload* ul) n
     getParams(params, ul);
 
     if (IPFilter::getInstance()){
-        if (!IPFilter::getInstance()->OK(vstr(params["IP"]), eDIRECTION_OUT)){
+        if (!IPFilter::getInstance()->OK(vstr(params["IP"]).toStdString(), eDIRECTION_OUT)){
             closeConection(vstr(params["CID"]), false);
             return;
         }
@@ -789,8 +797,8 @@ void TransferView::on(dcpp::UploadManagerListener::Starting, dcpp::Upload* ul) n
 }
 
 void TransferView::on(dcpp::UploadManagerListener::Tick, const dcpp::UploadList& uls) noexcept{
-    for (auto it = uls.begin(); it != uls.end(); ++it){
-        Upload* ul = *it;
+    for (const auto &it : uls){
+        Upload* ul = it;
         VarMap params;
         QString stat = "";
 
@@ -799,12 +807,12 @@ void TransferView::on(dcpp::UploadManagerListener::Tick, const dcpp::UploadList&
         if (ul->getUserConnection().isSecure())
         {
             if (ul->getUserConnection().isTrusted())
-                stat += tr("[S]");
+                stat += QString("[S]");
             else
-                stat += tr("[U]");
+                stat += QString("[U]");
         }
         if (ul->isSet(Upload::FLAG_ZUPLOAD))
-            stat += tr("[Z]");
+            stat += QString("[Z]");
         
         params["FLAGS"] = stat;
 
@@ -833,6 +841,8 @@ void TransferView::on(dcpp::UploadManagerListener::Complete, dcpp::Upload* ul) n
 }
 
 void TransferView::on(dcpp::UploadManagerListener::Failed, dcpp::Upload* ul, const std::string& reason) noexcept{
+    Q_UNUSED(reason)
+
     VarMap params;
 
     getParams(params, ul);
