@@ -43,7 +43,7 @@ class TransferView : public QWidget,
 
 friend class dcpp::Singleton<TransferView>;
 
-typedef QMap<QString, QVariant> VarMap;
+typedef QVariantMap VarMap;
 
 class Menu{
 
@@ -59,12 +59,16 @@ public:
         RemoveFromQueue,
         Force,
         Close,
+        showTransferredFieldsOnly,
         None
     };
 
-    Menu();
+    Menu(bool);
     virtual ~Menu();
 
+    Menu(const Menu&) = delete;
+    Menu& operator=(const Menu&) = delete;
+
     Action exec();
     int copyColumn() const {return selectedColumn; }
 
@@ -148,9 +152,9 @@ private Q_SLOTS:
     void slotContextMenu(const QPoint&);
     void slotHeaderMenu(const QPoint&);
     void downloadComplete(QString);
-    \
+
 private:
-    TransferView(QWidget* = NULL);
+    TransferView(QWidget* = nullptr);
     virtual ~TransferView();
 
     void load();
