@@ -11,7 +11,12 @@
 
 #include "WulforUtil.h"
 
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
+
 #include <QFileInfo>
 #include <QList>
 #include <QStringList>
@@ -26,29 +31,27 @@
 #include <QSize>
 #include <QStyleOptionProgressBar>
 #include <QHash>
-#include <QColorGroup>
 
 #include "dcpp/stdinc.h"
 #include "dcpp/ShareManager.h"
 #include "dcpp/Util.h"
 
-#define _DEBUG_ 1
+#include <set>
 
-#if _DEBUG_
+#if _DEBUG_QT_UI
 #include <QtDebug>
 #endif
 
-#include <set>
 
 TransferViewModel::TransferViewModel(QObject *parent)
-    : QAbstractItemModel(parent), iconsScaled(false)
+    : QAbstractItemModel(parent), iconsScaled(false), showTranferedFilesOnly(false)
 {
     QList<QVariant> rootData;
     rootData << tr("Users") << tr("Speed") << tr("Status") << tr("Flags") << tr("Size")
              << tr("Time left") << tr("File name") << tr("Host") << tr("IP")
              << tr("Encryption");
 
-    rootItem = new TransferViewItem(rootData, NULL);
+    rootItem = new TransferViewItem(rootData, nullptr);
 
     column_map.insert("USER", COLUMN_TRANSFER_USERS);
     column_map.insert("SPEED", COLUMN_TRANSFER_SPEED);
@@ -102,8 +105,8 @@ QVariant TransferViewModel::data(const QModelIndex &index, int role) const
         case Qt::DisplayRole:
         {
             if (item->download && index.column() != COLUMN_TRANSFER_SIZE && item->childCount() == 1)//This parent item has hidden child, so just copy child column text into parent
-				return data(createIndex(0, index.column(), reinterpret_cast<void*>(item->childItems.first())), role);
-			
+                                return data(createIndex(0, index.column(), reinterpret_cast<void*>(item->childItems.first())), role);
+
             if (index.column() == COLUMN_TRANSFER_SPEED)
                 return WulforUtil::formatBytes(item->data(COLUMN_TRANSFER_SPEED).toDouble()) + tr("/s");
             else if (index.column() == COLUMN_TRANSFER_SIZE)
@@ -149,11 +152,11 @@ namespace {
 template <Qt::SortOrder order>
 struct Compare {
     void static sort(unsigned col, QList<TransferViewItem*>& items) {
-        qStableSort(items.begin(), items.end(), attrs[col]);
+        std::stable_sort(items.begin(), items.end(), attrs[col]);
     }
 
     void static insertSorted(unsigned col, QList<TransferViewItem*>& items, TransferViewItem* item) {
-        auto it = qLowerBound(items.begin(), items.end(), item, attrs[col]);
+        auto it = std::lower_bound(items.begin(), items.end(), item, attrs[col]);
         items.insert(it, item);
     }
 
@@ -170,7 +173,7 @@ struct Compare {
        }
         template <typename T>
         bool static Cmp(const T& l, const T& r);
-        
+
         static AttrComp attrs[10];
 };
 template <Qt::SortOrder order>
@@ -331,7 +334,7 @@ void TransferViewModel::addConnection(const VarMap &params){
 
     bool bGroup = false;
     TransferViewItem *i;
-    TransferViewItem *to = NULL;
+    TransferViewItem *to = nullptr;
     bool bDownload = vbol(params["DOWN"]);
 
     if (findTransfer(vstr(params["CID"]), vbol(params["DOWN"]), &i)) {
@@ -355,6 +358,13 @@ void TransferViewModel::addConnection(const VarMap &params){
 
     transfer_hash.insertMulti(item->cid, item);
 
+    if (showTranferedFilesOnly){
+        if (vstr(params["FNAME"]).isEmpty() || (tr("File list") == params["FNAME"]) ){
+            return;
+        };
+    };
+
+
     if (!to)
         rootItem->appendChild(item);
     else
@@ -372,11 +382,10 @@ void TransferViewModel::updateTransfer(const VarMap &params){
     if (!findTransfer(vstr(params["CID"]), vbol(params["DOWN"]), &item))
         return;
 
-    auto i = column_map.constBegin();
-
-    for (; i != column_map.constEnd(); ++i){
-        if (params.contains(i.key()))
+    for (auto i = column_map.constBegin(); i != column_map.constEnd(); ++i) {
+        if (params.contains(i.key())) {
             item->updateColumn(i.value(), params[i.key()]);
+        }
     }
 
     qlonglong dpos = vdbl(params["DPOS"]);
@@ -386,7 +395,16 @@ void TransferViewModel::updateTransfer(const VarMap &params){
     item->fail = vbol(params["FAIL"]);
     item->tth = vstr(params["TTH"]);
 
+
+
     if (!vbol(params["DOWN"])){
+
+        if (showTranferedFilesOnly){
+            if (vstr(params["FNAME"]).isEmpty() || (tr("File list") == params["FNAME"]) ){
+                return;
+            };
+        };
+
         if (!rootItem->childItems.contains(item))
             rootItem->appendChild(item);
     }
@@ -455,7 +473,7 @@ bool TransferViewModel::findParent(const QString &target, TransferViewItem **ite
     if (!item)
         return false;
 
-    foreach (TransferViewItem *i, rootItem->childItems){
+    for (const auto &i : rootItem->childItems){
         if ((i->download == download) && i->target == target && i->cid.isEmpty()){
             *item = i;
 
@@ -505,12 +523,20 @@ void TransferViewModel::moveTransfer(TransferViewItem *item, TransferViewItem *f
 }
 
 void TransferViewModel::updateParents(){
-    foreach(TransferViewItem *i, rootItem->childItems)
+    for (const auto &i : rootItem->childItems)
         updateParent(i);
 
     emit layoutChanged();
 }
 
+void TransferViewModel::setShowTranferedFilesOnlyState(bool state){
+    showTranferedFilesOnly = state;
+};
+
+bool TransferViewModel::getShowTranferedFilesOnlyState(){
+    return showTranferedFilesOnly;
+};
+
 void TransferViewModel::updateParent(TransferViewItem *p){
     if (!p || p->childCount() < 1 || p == rootItem)
         return;
@@ -525,7 +551,7 @@ void TransferViewModel::updateParent(TransferViewItem *p){
 
     totalSize = vlng(p->data(COLUMN_TRANSFER_SIZE));
 
-    foreach (TransferViewItem *i, p->childItems){
+    for (const auto &i : p->childItems){
         if (!i->fail){
             active++;
             speed += vdbl(i->data(COLUMN_TRANSFER_SPEED));
@@ -554,17 +580,17 @@ void TransferViewModel::updateParent(TransferViewItem *p){
                    + QString(" (%1%)").arg(progress, 0, 'f', 1);
 
     QString hubs_str;
-    foreach(const QString &s, hubs)
+    for (const QString &s : hubs)
         hubs_str += s + " ";
 
-    if (vstr(p->data(COLUMN_TRANSFER_FNAME)).startsWith(tr("TTH: "))){
+    if (vstr(p->data(COLUMN_TRANSFER_FNAME)).startsWith(QString("TTH: "))){
         QString name = vstr(p->data(COLUMN_TRANSFER_FNAME));
-        name.remove(0, tr("TTH: ").length());
+        name.remove(0, QString("TTH: ").length());
 
         p->updateColumn(COLUMN_TRANSFER_FNAME, name);
     }
 
-    p->updateColumn(COLUMN_TRANSFER_USERS, tr("%1/%2").arg(active).arg(p->childCount()));
+    p->updateColumn(COLUMN_TRANSFER_USERS, QString("%1/%2").arg(active).arg(p->childCount()));
     p->updateColumn(COLUMN_TRANSFER_FLAGS, "");
     p->updateColumn(COLUMN_TRANSFER_TLEFT, timeLeft);
     p->updateColumn(COLUMN_TRANSFER_HOST, hubs_str);
@@ -607,7 +633,7 @@ void TransferViewModel::finishParent(const VarMap &params){
     p->finished = true;
     p->updateColumn(COLUMN_TRANSFER_SPEED, qlonglong(0));
 
-    foreach (TransferViewItem *i, p->childItems){
+    for (const auto &i : p->childItems){
         i->updateColumn(COLUMN_TRANSFER_STATS, tr("Finished"));
         i->percent = 100.0;
         i->finished = true;
@@ -671,10 +697,10 @@ TransferViewItem::TransferViewItem(const QList<QVariant> &data, TransferViewItem
 
 TransferViewItem::~TransferViewItem()
 {
-    if (!childItems.isEmpty())
-        qDeleteAll(childItems);
+    qDeleteAll(childItems);
+    childItems.clear();
 
-    parentItem = NULL;
+    parentItem = nullptr;
 }
 
 void TransferViewItem::appendChild(TransferViewItem *item) {
@@ -731,13 +757,23 @@ TransferViewDelegate::~TransferViewDelegate(){
 void TransferViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const{
     TransferViewItem *item = reinterpret_cast<TransferViewItem*>(index.internalPointer());
 
-    if (index.column() != COLUMN_TRANSFER_STATS || !item){
+    if (index.column() != COLUMN_TRANSFER_STATS || !item) {
         QStyledItemDelegate::paint(painter, option, index);
 
         return;
     }
 
-    QStyleOptionProgressBarV2 progressBarOption;
+#if defined(USE_PROGRESS_BARS)
+    QPalette pal = option.palette;
+    if (item->download && download_bar_color.isValid())
+        pal.setColor(QPalette::Highlight, download_bar_color);
+    else if (!item->download && upload_bar_color.isValid())
+        pal.setColor(QPalette::Highlight, upload_bar_color);
+
+    const double percent = item->percent;
+    const QString status = item->data(COLUMN_TRANSFER_STATS).toString();
+
+    QStyleOptionProgressBar progressBarOption;
     progressBarOption.state = QStyle::State_Enabled;
     progressBarOption.direction = QApplication::layoutDirection();
     progressBarOption.rect = option.rect;
@@ -746,19 +782,7 @@ void TransferViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
     progressBarOption.maximum = 100;
     progressBarOption.textAlignment = Qt::AlignCenter;
     progressBarOption.textVisible = true;
-
-    QPalette pal = option.palette;
-
-    if (item->download && download_bar_color.isValid())
-        pal.setColor(QPalette::Highlight, download_bar_color);
-    else if (!item->download && upload_bar_color.isValid())
-        pal.setColor(QPalette::Highlight, upload_bar_color);
-
     progressBarOption.palette = pal;
-
-    double percent = item->percent;
-    QString status = item->data(COLUMN_TRANSFER_STATS).toString();
-
     progressBarOption.text = status;
     progressBarOption.progress = static_cast<int>(percent);
 
@@ -766,6 +790,15 @@ void TransferViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
         painter->fillRect(option.rect, option.palette.highlight());
 
     QApplication::style()->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
+#else
+    const QString status = item->data(COLUMN_TRANSFER_STATS).toString();
+
+    QStyleOptionViewItem plainTextOption = option;
+    plainTextOption.text = status;
+    plainTextOption.displayAlignment = Qt::AlignCenter;
+
+    QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &plainTextOption, painter);
+#endif
 }
 
 void TransferViewDelegate::wsVarValueChanged(const QString &key, const QVariant &val){
