@@ -55,7 +55,6 @@ static const QString & WS_FTRANSFERS_FILES_STATE  = "finished-f-state";
 static const QString & WS_FAV_HUBS_STATE          = "fav-hubs-state";
 static const QString & WS_ADLS_STATE              = "adls-state";
 static const QString & WS_APP_THEME               = "app-theme-name";
-static const QString & WS_APP_FONT                = "app-font-name";
 static const QString & WS_APP_ENABLED_SCRIPTS     = "app-enabled-scripts";
 static const QString & WS_NOTIFY_SOUNDS           = "notify-sound-files";
 static const QString & WS_NOTIFY_SND_CMD          = "notify-sound-cmd";
@@ -91,7 +90,6 @@ static const QString & WB_SEARCH_DONTHIDEPANEL    = "search-panel-dont-hide";
 static const QString & WB_ANTISPAM_ENABLED        = "antispam-enabled";
 static const QString & WB_ANTISPAM_AS_FILTER      = "antispam-as-filter";
 static const QString & WB_ANTISPAM_FILTER_OPS     = "antispam-filter-ops";
-static const QString & WB_IPFILTER_ENABLED        = "ipfilter-enabled";
 static const QString & WB_TRAY_ENABLED            = "systemtray-enabled";
 static const QString & WB_EXIT_CONFIRM            = "exit-confirm";
 static const QString & WB_SHOW_IP_IN_CHAT         = "show-ip-in-chat";
@@ -173,7 +171,7 @@ public:
     void loadTranslation();
     void loadTheme();
 
-    void    parseCmd(const QString &, QString &);
+    void parseCmd(const QString &, QString &);
 
     bool hasKey(const QString&) const;
 
@@ -183,10 +181,10 @@ public Q_SLOTS:
     bool     getBool(const QString&, const bool &default_value = false);
     QVariant getVar(const QString&, const QVariant &default_value = QVariant());
 
-    void    setStr (const QString&, const QString&);
-    void    setInt (const QString&, int) ;
-    void    setBool(const QString&, bool);
-    void    setVar (const QString&, const QVariant &);
+    void setStr (const QString&, const QString&);
+    void setInt (const QString&, int) ;
+    void setBool(const QString&, bool);
+    void setVar (const QString&, const QVariant &);
 
 Q_SIGNALS:
     void fontChanged(const QString &key, const QString &value);
@@ -194,14 +192,16 @@ Q_SIGNALS:
     void strValueChanged(const QString &key, const QString &value);
     void varValueChanged(const QString &key, const QVariant &value);
 
-private Q_SLOTS:
-    void slotFontChanged(const QString &key, const QString &value);
-
 private:
     WulforSettings();
     virtual ~WulforSettings();
 
-    void loadOldConfig();//load old version of config
+    void loadOldConfig(); //load old version of config
+    void loadQtTranslation(const QString &lcName);
+    void installTranslator(QTranslator &translator,
+                           const QString &defualtName,
+                           const QString &fallbackName,
+                           const QString &path);
 
     QSettings settings;
 
@@ -212,8 +212,9 @@ private:
     WIntMap intmap;
     WStrMap strmap;
 
-    QTranslator tor;
+    QTranslator appTranslator;
     QTranslator qtTranslator;
+    QTranslator qtBaseTranslator;
 };
 
 static const auto WSGET = [](const QString &key, const QString &default_value = "") -> QString { return WulforSettings::getInstance()->getStr(key, default_value); };
