@@ -17,8 +17,8 @@
 #include <QTextCodec>
 #include <QTreeView>
 #include <QAbstractItemModel>
-#include <QHttp>
-#include <QHttpHeader>
+//#include <QHttp>
+//#include <QHttpHeader>
 
 #include "dcpp/stdinc.h"
 #include "dcpp/Singleton.h"
@@ -39,7 +39,7 @@ using namespace dcpp;
 static const auto _q = [](const std::string &s) { return QString::fromStdString(s); };
 static const auto _tq = [](const QString &s) { return s.toStdString(); };
 
-typedef QMap<QString, QVariant> VarMap;
+typedef QVariantMap VarMap;
 
 class WulforUtil :
         public QObject,
@@ -92,6 +92,7 @@ public:
         eiHIDEWINDOW,
         eiHUBMSG,
         eiICON_APPL,
+        eiMAGNET,
         eiMESSAGE,
         eiMESSAGE_TRAY_ICON,
         eiOPENLIST,
@@ -138,7 +139,11 @@ public:
 
     QString getNicks(const CID &cid, const QString& = "");
 
-    const QString &getIconsPath() { return app_icons_path; }
+    QString getAppIconsPath() const;
+    QString getEmoticonsPath() const;
+    QString getClientIconsPath() const;
+    QString getTranslationsPath() const;
+    QString getAspellDataPath() const;
 
     const QPixmap &getPixmapForFile(const QString&);
 
@@ -171,12 +176,14 @@ public:
 
     QString compactToolTipText(QString, int, QString);
 
-    QMenu *buildUserCmdMenu(const std::string &hub_url, int ctx, QWidget* = 0);
-    QMenu *buildUserCmdMenu(const StringList& hub_list, int ctx, QWidget* = 0);
-    QMenu *buildUserCmdMenu(const QList<QString> &hub_list, int ctx, QWidget* = 0);
+    QMenu *buildUserCmdMenu(const std::string &hub_url, int ctx, QWidget* = nullptr);
+    QMenu *buildUserCmdMenu(const StringList& hub_list, int ctx, QWidget* = nullptr);
+    QMenu *buildUserCmdMenu(const QList<QString> &hub_list, int ctx, QWidget* = nullptr);
 
     static bool isTTH(const QString &text);
 
+    QString getNickViaOnlineUser(const QString &cid, const QString &hintUrl);
+
 public Q_SLOTS:
     const QPixmap &getPixmap(Icons);
     QString getNicks(const QString&,const QString& = "");
@@ -191,8 +198,6 @@ private:
     void clearUserIconCache();
     void initFileTypes();
 
-    static QString formatBytes(int64_t bytes, int base);
-
     QPixmap loadPixmap(const QString& file);
 
     PixmapMap m_PixmapMap;
@@ -201,10 +206,12 @@ private:
     QPixmap FROMTHEME(const QString &name, bool resource);
     QPixmap FROMTHEME_SIDE(const QString &name, bool resource, const int side);
 
-    QString findAppIconsPath();
+    QString findAppIconsPath() const;
+    QString findUserIconsPath() const;
+    QString getClientResourcesPath() const;
 
-    QString app_icons_path;
     QString bin_path;
+    QString app_icons_path;
 
     QPixmap *userIconCache[USERLIST_XPM_COLUMNS][USERLIST_XPM_ROWS];
     QImage  *userIcons;
