@@ -21,30 +21,32 @@ bool magnet::parseUri(const string& uri, StringMap& params) {
                 return false;
         }
 
-        // official types that are of interest to us
-        //  xt = exact topic
-        //  xs = exact substitute
-        //  as = acceptable substitute
-        //  dn = display name
-        //  kt = keyword topic
-        //  xl = exact length
-        //  dl = display length
-        //  mt (Manifest Topic) — Ссылка на метафайл, который содержит список магнетов (MAGMA)
+        // Widely used parameters:
+        // xt = eXact Topic                — URN containing file hash
+        // xs = eXact Source               — P2P link
+        // as = Acceptable Source          — web link to file on the Internet
+        // dn = Display Name               — file name
+        // kt = Keyword Topic              — search keywords
+        // xl = eXact Length               — real file size in bytes
+        // dl = Display Length             — size in bytes which should be displayed to user
+        // mt = Manifest Topic             — link to a metafile that contains a list of magnets (MAGMA)
+        // tr = TRacker                    — tracker address for BitTorrent clients
 
         StringTokenizer<string> mag(uri.substr(8), '&');
         StringMap hashes;
         string type, param;
-        TStringList searchlist = mag.getTokens();
-        for (auto idx = searchlist.begin(); idx != searchlist.end(); ++idx) {
-            auto pos = idx->find('=');
+        for(auto& idx : mag.getTokens()) {
+            auto pos = idx.find('=');
             if(pos != string::npos) {
-                type = Text::toLower(Util::encodeURI(idx->substr(0, pos), true));
-                param = Util::encodeURI(idx->substr(pos + 1), true);
+                type = Text::toLower(Util::encodeURI(idx.substr(0, pos), true));
+                param = Util::encodeURI(idx.substr(pos + 1), true);
             } else {
-                type = Util::encodeURI(*idx, true);
+                type = Util::encodeURI(idx, true);
                 param.clear();
             }
 
+            static const StringSet supportedParams = { "dn", "kt", "xl", "dl", "mt", "tr" };
+
             // extract what is of value
             if(param.size() == 85 && ::strncmp(param.c_str(), "urn:bitprint:", 13) == 0) {
                     hashes[type] = param.substr(46);
@@ -54,21 +56,22 @@ bool magnet::parseUri(const string& uri, StringMap& params) {
                     hashes[type] = param.substr(16);
             } else if(param.size() == 59 && ::strncmp(param.c_str(), "urn:tree:tiger/1024:", 20) == 0) {
                     hashes[type] = param.substr(20);
-            } else if(type.size() == 2 && ::strncmp(type.c_str(), "dn", 2) == 0) {
-                    params["dn"] = param;
-            } else if(type.size() == 2 && ::strncmp(type.c_str(), "kt", 2) == 0) {
-                    params["kt"] = param;
-            } else if(type.size() == 2 && ::strncmp(type.c_str(), "xl", 2) == 0) {
-                params["xl"] = param;
+            } else if(param.size() == 49 && ::strncmp(param.c_str(), "urn:btih:", 9) == 0) {
+                    hashes[type] = param.substr(9);
+            } else if(param.size() == 77 && ::strncmp(param.c_str(), "urn:btmh:", 9) == 0) {
+                    hashes[type] = param.substr(9);
+            } else if(type.size() == 2 && supportedParams.find(type) != supportedParams.end()) {
+                    params[type] = param;
             }
         }
 
-        if(hashes.find("xt") != hashes.end()) {
-            params["xt"] = hashes["xt"];
-        } else if(hashes.find("xs") != hashes.end()) {
-            params["xs"] = hashes["xs"];
-        } else if(hashes.find("as") != hashes.end()) {
-            params["as"]= hashes["as"];
+        static const StringSet specialParams = { "xt", "xs", "as" };
+
+        // add special params
+        for(auto& key : specialParams) {
+            if(hashes.find(key) != hashes.end()) {
+                params[key] = hashes[key];
+            }
         }
 
         if(!params["xt"].empty() || !params["xs"].empty() || !params["as"].empty() || !params["kt"].empty()) {
