@@ -1,6 +1,6 @@
 /*
  *  JsonRpc-Cpp - JSON-RPC implementation.
- *  Copyright (C) 2008-2011 Sebastien Vincent <sebastien.vincent@cppextrem.com>
+ *  Copyright (C) 2011-2014 Eugene Petrov <dhamp@ya.ru>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -13,12 +13,12 @@
  *  GNU Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /**
  * \file jsonrpc_httpserver.h
- * \brief JSON-RPC HTTPServer.
+ * \brief JSON-RPC HTTPServer. Based on JSON-RPC Server.
  * \author Eugene Petrov
  */
 
@@ -54,7 +54,7 @@ namespace Json
 
         bool startPolling();
         bool stopPolling();
-        bool onRequest(const char* request, void* addInfo);
+        bool onRequest(const std::string &str, void* addInfo);
         bool sendResponse(std::string& response, void* addInfo = NULL);
 
         /**
@@ -81,7 +81,7 @@ namespace Json
          */
         void DeleteMethod(const std::string& method);
 
-      protected:
+    protected:
 
         /**
          * \brief JSON-RPC handler.
